@@ -4,7 +4,7 @@ ad_library {
 
     @creation-date 29 September 2000
     @author Bryan Quinn (bquinn@arsdigita.com)
-    @cvs-id $Id: apm-admin-procs.tcl,v 1.18.8.15 2014/09/06 21:11:56 gustafn Exp $
+    @cvs-id $Id: apm-admin-procs.tcl,v 1.20.2.5 2015/09/25 11:53:03 gustafn Exp $
 
 }
 
@@ -95,13 +95,15 @@ ad_proc apm_shell_wrap { cmd } {
 
 ad_proc -private apm_package_selection_widget {
     pkg_info_list
-    {to_install ""} 
+    {to_install ""}
+    {operation "all"}
 } {
 
     Provides a widget for selecting packages.  Displays dependency information if available.
 
     @param pkg_info_list list of package infos for all packages to be listed
     @param to_install list of package_keys to install
+    @param operation filter for added operations (all, upgrade, install)
 } {
     if {$pkg_info_list eq ""} {
         return ""
@@ -133,24 +135,24 @@ ad_proc -private apm_package_selection_widget {
                 <td align='center'><input type='checkbox' name='package_key' value='$package_key' "
             }
             
-            append widget "></td>
-            <td>$package(package-name) $package(name)</td>
-            <td>$package_key</td>
-            <td><font color='green'>Dependencies satisfied.</font></td>
-            </tr> "
+            append widget [subst {></td>
+                <td>$package(package-name) $package(name)</td>
+                <td>$package_key</td>
+                <td><span style='color:green'>Dependencies satisfied.</span></td>
+                </tr> }]
         } elseif { [pkg_info_dependency_p $pkg_info] == "f" } {
             #Dependency failed.
-            append widget "
-            <td align=center><input type='checkbox' name='package_key' value='$package_key' ></td>
-            <td>$package(package-name) $package(name)</td>
-            <td>$package_key</td>
-            <td><font color='red'>
-            "
+            append widget [subst {
+                <td align=center><input type='checkbox' name='package_key' value='$package_key' ></td>
+                <td>$package(package-name) $package(name)</td>
+                <td>$package_key</td>
+                <td><span style='color:red'>
+            }]
             foreach comment [pkg_info_comment $pkg_info] {
                 append widget "$comment<br>"
             }
             append widget "
-            </font></td>
+            </span></td>
             </tr>
             "
         } else {
@@ -162,8 +164,10 @@ ad_proc -private apm_package_selection_widget {
                 set higher_version_p 2
             }
             if {$higher_version_p == 2 } {
+                if {$operation eq "upgrade"} continue
                 set comment "New install."
             } elseif {$higher_version_p == 1 } {
+                if {$operation eq "install"} continue
                 set comment "Upgrade."
             } elseif {$higher_version_p == 0} {
                 set comment "Package version already installed."
@@ -218,7 +222,7 @@ ad_proc -private apm_higher_version_installed_p {
 ad_proc -private apm_build_repository {
     {-debug:boolean 0} 
     {-channels *} 
-    {-head_channel 5-9} 
+    {-head_channel 5-10} 
 } {    
 
     Rebuild the repository on the local machine.  
@@ -246,11 +250,11 @@ ad_proc -private apm_build_repository {
     set repository_dir         $::acs::rootdir/www/repository/
     set repository_url         http://openacs.org/repository/
 
-    set channel_index_template /packages/acs-admin/www/apm/repository-channel-index
-    set index_template         /packages/acs-admin/www/apm/repository-index
-
     set exclude_package_list {}
 
+    set channel_index_template [template::themed_template /packages/acs-admin/www/apm/repository-channel-index]
+    set index_template         [template::themed_template /packages/acs-admin/www/apm/repository-index]
+
     #----------------------------------------------------------------------
     # Prepare output
     #----------------------------------------------------------------------
@@ -392,18 +396,18 @@ ad_proc -private apm_build_repository {
                         
                         append manifest \
                             "  <package>" \n \
-                            "    <package-key>[ad_quotehtml $pkg_info(package.key)]</package-key>\n" \
-                            "    <version>[ad_quotehtml $pkg_info(name)]</version>\n" \
-                            "    <pretty-name>[ad_quotehtml $pkg_info(package-name)]</pretty-name>\n" \
-                            "    <package-type>[ad_quotehtml $pkg_info(package.type)]</package-type>\n" \
-                            "    <summary>[ad_quotehtml $pkg_info(summary)]</summary>\n" \
-                            "    <description format=\"[ad_quotehtml $pkg_info(description.format)]\">" \
-                            [ad_quotehtml $pkg_info(description)] "</description>\n" \
-                            "    <release-date>[ad_quotehtml $pkg_info(release-date)]</release-date>\n" \
-                            "    <vendor url=\"[ad_quotehtml $pkg_info(vendor.url)]\">" \
-                            [ad_quotehtml $pkg_info(vendor)] "</vendor>\n" \
-                            "    <license url=\"[ad_quotehtml $pkg_info(license.url)]\">" \
-                            [ad_quotehtml $pkg_info(license)] "</license>\n" \
+                            "    <package-key>[ns_quotehtml $pkg_info(package.key)]</package-key>\n" \
+                            "    <version>[ns_quotehtml $pkg_info(name)]</version>\n" \
+                            "    <pretty-name>[ns_quotehtml $pkg_info(package-name)]</pretty-name>\n" \
+                            "    <package-type>[ns_quotehtml $pkg_info(package.type)]</package-type>\n" \
+                            "    <summary>[ns_quotehtml $pkg_info(summary)]</summary>\n" \
+                            "    <description format=\"[ns_quotehtml $pkg_info(description.format)]\">" \
+                            [ns_quotehtml $pkg_info(description)] "</description>\n" \
+                            "    <release-date>[ns_quotehtml $pkg_info(release-date)]</release-date>\n" \
+                            "    <vendor url=\"[ns_quotehtml $pkg_info(vendor.url)]\">" \
+                            [ns_quotehtml $pkg_info(vendor)] "</vendor>\n" \
+                            "    <license url=\"[ns_quotehtml $pkg_info(license.url)]\">" \
+                            [ns_quotehtml $pkg_info(license)] "</license>\n" \
                             "    <maturity>$pkg_info(maturity)</maturity>\n"
 
                         foreach e $pkg_info(install) {
@@ -460,14 +464,14 @@ ad_proc -private apm_build_repository {
                         append manifest "    <download-url>$apm_url</download-url>\n"
                         foreach elm $pkg_info(provides) {
                             append manifest "    <provides " \
-                                "url=\"[ad_quotehtml [lindex $elm 0]]\" " \
-                                "version=\"[ad_quotehtml [lindex $elm 1]]\" />\n"
+                                "url=\"[ns_quotehtml [lindex $elm 0]]\" " \
+                                "version=\"[ns_quotehtml [lindex $elm 1]]\" />\n"
                         }
                         
                         foreach elm $pkg_info(requires) {
                             append manifest "    <requires " \
-                                "url=\"[ad_quotehtml [lindex $elm 0]]\" " \
-                                "version=\"[ad_quotehtml [lindex $elm 1]]\" />\n"
+                                "url=\"[ns_quotehtml [lindex $elm 0]]\" " \
+                                "version=\"[ns_quotehtml [lindex $elm 1]]\" />\n"
                         }
                         append manifest "  </package>\n"
                     }
@@ -487,7 +491,7 @@ ad_proc -private apm_build_repository {
         set fw [open "${channel_dir}index.adp" w]
         set packages [lsort $packages]
         puts $fw "<master>\n<property name=\"doc(title)\">OpenACS $channel Compatible Packages</property>\n\n"
-        puts $fw "<h2>OpenACS $channel Core and compatibile packages</h2>
+        puts $fw "<h1>OpenACS $channel Core and compatibile packages</h1>
            <p>Packages can be installed with the OpenACS Automated Installer on
            your OpenACS site at <code>/acs-admin/install</code>.  Only packages
            designated compatible with your OpenACS kernel will be shown.</p>
@@ -571,11 +575,19 @@ ad_proc -private apm_build_repository {
 
     ns_log Notice "Repository: Finishing Repository"
 
+    foreach channel [array names channel_tag] {
+        regexp {^([1-9][0-9]*)-([0-9]+)$} $channel . major minor
+        set tag_order([format %.3d $major]-[format %.3d $minor]) $channel
+        set tag_label($channel) "OpenACS $major.$minor"
+    }
+
+    
     # Write the index page
     ns_log Notice "Repository: Writing repository index page to ${work_dir}repository/index.adp"
-    template::multirow create channels name tag
-    foreach channel [lsort -decreasing [array names channel_tag]] {
-        template::multirow append channels $channel $channel_tag($channel)
+    template::multirow create channels name tag label
+    foreach key [lsort -decreasing [array names tag_order]] {
+        set channel $tag_order($key)
+        template::multirow append channels $channel $channel_tag($channel) $tag_label($channel)
     }
     set fw [open "${work_dir}repository/index.adp" w]
     puts $fw "<master>\n<property name=\"doc(title)\">OpenACS Package Repository</property>\n\n"
