@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date Fri Oct 13 08:45:58 2000
-    @cvs-id $Id: package-deinstall.tcl,v 1.2.20.2 2013/09/28 12:09:59 gustafn Exp $
+    @cvs-id $Id: package-deinstall.tcl,v 1.3.2.2 2015/09/18 07:39:03 gustafn Exp $
 } {
     version_id:naturalnum
 }
@@ -25,7 +25,7 @@ db_transaction {
 } on_error {
     if {![apm_version_installed_p $version_id] } {
 	ad_return_complaint 1 "Database Error: The database returned the following error
-	message <pre><blockquote>[ad_quotehtml $errmsg]</blockquote></pre>"
+	message <pre><blockquote>[ns_quotehtml $errmsg]</blockquote></pre>"
     }
 }
 
@@ -37,3 +37,9 @@ ad_return_template apm
 
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
