@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date Fri Oct 13 08:42:50 2000
-    @cvs-id $Id: package-delete-2.tcl,v 1.7.12.2 2013/09/28 12:09:59 gustafn Exp $
+    @cvs-id $Id: package-delete-2.tcl,v 1.8.2.2 2015/09/18 07:39:03 gustafn Exp $
 } {
     version_id:naturalnum
     {remove_files:boolean 0}
@@ -31,7 +31,7 @@ if {![apm_version_installed_p $version_id]} {
 		     -callback apm_body_callback $package_key} errmsg] } {
 	append body [subst {
 	    We encountered the following error when deleting package "$package_key":
-	    <pre><blockquote>[ad_quotehtml $errmsg]</blockquote></pre>
+	    <pre><blockquote>[ns_quotehtml $errmsg]</blockquote></pre>
 	}]
 	append body $::__apm_body
 	
@@ -49,3 +49,9 @@ ad_return_template apm
 
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
