@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date Mon Oct  9 00:15:52 2000
-    @cvs-id $Id: packages-install-3.tcl,v 1.14.8.5 2014/08/17 11:36:55 gustafn Exp $
+    @cvs-id $Id: packages-install-3.tcl,v 1.17 2015/06/19 19:51:16 gustafn Exp $
 } {
 
 }
@@ -70,15 +70,17 @@ foreach pkg_info [ad_get_client_property apm pkg_install_list] {
              && $version(package.type) eq "apm_application" 
          } {
             set mount_html [subst {
-                <input type="checkbox" name="mount_p" value="$version(package.key)" checked> 
+                <div>
+                <input type="checkbox" name="mount_packages" value="$version(package.key)" checked> 
                 Mount package under the main site at path 
                 <input type="text" name="mount_path.$version(package.key)" value="$version(package.key)">
+                </div>
             }]
         } else {
             set mount_html ""
         }
         append body [subst {
-            Select what data files to load for $version(package-name) $final_version_name
+            <p>Select what data files to load for $version(package-name) $final_version_name
             <blockquote>
             <table cellpadding='3' cellspacing='3' class='list-table'>
             <tr>
