@@ -3,15 +3,28 @@ ad_page_contract {
     Select, dependency check, install and enable packages.
 
     @author Bryan Quinn (bquinn@arsdigita.com)
-    @cvs-id $Id: packages-install.tcl,v 1.22.4.10 2014/08/28 10:00:43 victorg Exp $
+    @cvs-id $Id: packages-install.tcl,v 1.24.2.2 2015/09/25 11:53:03 gustafn Exp $
 
 } {
     {checked_by_default_p:boolean 0}
+    {operation:word all}
 }
 
 set title "Package Installation"
 set context [list [list "/acs-admin/apm/" "Package Manager"] $title]
 
+set dimensional_list {
+    {
+        operation "Operation:" all {
+	    { upgrade "Upgrade" {} }
+	    { install "Install" {} }
+	    { all "All" {} }
+	}
+    }
+}
+
+set dimensional_list [ad_dimensional $dimensional_list]
+
 
 ### Get all the spec files
 #
@@ -83,29 +96,35 @@ if { $spec_files eq "" } {
     append body {
         <h2>Select Packages to Install</h2><p>
         <p>Please select the set of packages you'd like to install.</p>
-    }
-
+    } [subst {
+        <div style="margin: 0 auto;">
+        $dimensional_list
+        </div>
+    }]
+    
     set formName "pkgsForm"
     append body [subst {
 
         <script type="text/javascript">
         function uncheckAll() {
             var install_form = document.getElementsByName('$formName')\[0\];
-            for (var i = 0; i < [llength $spec_files]; ++i)
-            install_form.elements\[i\].checked = false;
-            this.href='';
+            for (var i = 0; i < install_form.length; ++i) {
+                install_form.elements\[i\].checked = false;
+            }
         }
         function checkAll() {
             var install_form = document.getElementsByName('$formName')\[0\];
-            for (var i = 0; i < [llength $spec_files]; ++i)
-            install_form.elements\[i\].checked = true;
-            this.href='';
+            for (var i = 0; i < install_form.length; ++i) {
+                install_form.elements\[i\].checked = true;
+                //install_form.elements\[i\].href = '';
+            }
         }
         </script>
-        <a href="packages-install?checked_by_default_p=0" onclick="javascript:uncheckAll();return false"><b>uncheck all boxes</b></a> |
-        <a href="packages-install?checked_by_default_p=1" onclick="javascript:checkAll(); return false"><b>check all boxes</b></a>
+        <a href="#" onclick="javascript:uncheckAll();return false;"><b>uncheck all boxes</b></a> |
+        <a href="#" onclick="javascript:checkAll();return false;"><b>check all boxes</b></a>
     }]
-
+    #packages-install?checked_by_default_p=1
+    
     append body "<form name='$formName' action='packages-install-2' method='post'>\n"
 
     # Client properties do not deplete the limited URL variable space.
@@ -123,7 +142,7 @@ if { $spec_files eq "" } {
             array set package [apm_read_package_info_file $spec_file]
         } errmsg] } {
             lappend errors "<li>Unable to parse $spec_file.  The following error was generated:
-        <blockquote><pre>[ad_quotehtml $errmsg]</pre></blockquote><p>"
+        <blockquote><pre>[ns_quotehtml $errmsg]</pre></blockquote><p>"
         } else {
             apm_log APMDebug "APM: Adding $package(package.key) to list for installation." 
             lappend pkg_info_list [pkg_info_new $package(package.key) $spec_file \
@@ -133,9 +152,9 @@ if { $spec_files eq "" } {
     }
     
     if { $checked_by_default_p } {
-        set widget [apm_package_selection_widget $pkg_info_list $pkg_key_list]
+        set widget [apm_package_selection_widget $pkg_info_list $pkg_key_list $operation]
     } else {
-        set widget [apm_package_selection_widget $pkg_info_list]
+        set widget [apm_package_selection_widget $pkg_info_list "" $operation]
     }
 
     if {$widget eq ""} {
@@ -145,7 +164,7 @@ if { $spec_files eq "" } {
 
     append body $widget
     append body [subst {
-        <input type="submit" value="Next -->">
+        <div><input type="submit" value="Next -->"></div>
         </form>
     }]
     
