@@ -2,7 +2,7 @@ ad_page_contract {
     Adds a parameter to a version.
     @author Todd Nightingale [tnight@arsdigita.com]
     @creation-date 17 April 2000
-    @cvs-id $Id: parameter-add.tcl,v 1.9.4.6 2013/09/28 12:10:00 gustafn Exp $
+    @cvs-id $Id: parameter-add.tcl,v 1.10.2.2 2015/09/18 07:39:03 gustafn Exp $
 } {
     version_id:naturalnum,notnull
     {section_name ""}
@@ -64,7 +64,7 @@ plain text string that identifies the parameter.
 
 <tr valign="top">
   <th align="right"><br>Section Name:</th>
-<td><input name="section_name" size="50" value="[ad_quotehtml $section_name]"><br>
+<td><input name="section_name" size="50" value="[ns_quotehtml $section_name]"><br>
 </td>
 </tr>
 
@@ -117,3 +117,9 @@ plain text string that identifies the parameter.
 
 ad_return_template apm
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
