@@ -3,7 +3,7 @@ ad_page_contract {
     @author Todd Nightingale (tnight@arsdigita.com)
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date 10 September 2000
-    @cvs-id $Id: parameter-edit-2.tcl,v 1.6.10.2 2013/10/11 11:43:46 gustafn Exp $
+    @cvs-id $Id: parameter-edit-2.tcl,v 1.7.2.2 2015/09/18 07:39:03 gustafn Exp $
 } {
     version_id:naturalnum,notnull
     parameter_id:naturalnum,notnull
@@ -35,7 +35,7 @@ db_transaction {
 } on_error {
     ad_return_error "Database Error" "The parameter could not be updated.  
 The database returned the following error:<p>
- <blockquote><pre>[ad_quotehtml $errmsg]</pre></blockquote>"
+ <blockquote><pre>[ns_quotehtml $errmsg]</pre></blockquote>"
 } 
 
 # LARS hack
@@ -49,3 +49,9 @@ foreach section $sections {
 
 ad_returnredirect [export_vars -base "version-parameters" { version_id section_name }]
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
