@@ -3,7 +3,7 @@ ad_page_contract {
 
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 11 September 2003
-    @cvs-id $Id: version-callback-invoke.tcl,v 1.3.22.1 2014/07/29 11:23:55 gustafn Exp $
+    @cvs-id $Id: version-callback-invoke.tcl,v 1.5.2.2 2015/09/10 08:21:03 gustafn Exp $
 } {
     version_id:naturalnum,notnull    
     type:notnull
@@ -11,7 +11,7 @@ ad_page_contract {
 
 db_1row package_version_info "select pretty_name, version_name from apm_package_version_info where version_id = :version_id"
 
-set return_url "version-callbacks?[export_vars { version_id }]"
+set return_url [export_vars -base version-callbacks { version_id }]
 
 # Set default values for type and proc name
 set proc_value [apm_get_callback_proc -type $type -version_id $version_id]
@@ -24,8 +24,13 @@ set context [list \
                  [list $return_url "Tcl Callbacks"] $page_title]
 
 if { [catch $proc_value result] } {
-    global errorInfo
-    ns_log Error "Error invoking callback $proc_value: $result\n$errorInfo"
+    ns_log Error "Error invoking callback $proc_value: $result\n$::errorInfo"
 }
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
