@@ -2,7 +2,7 @@ ad_page_contract {
     Adds a dependency to a version of a package.
     @author Jon Salz [jsalz@arsdigita.com]
     @creation-date 17 April 2000
-    @cvs-id $Id: version-dependency-add.tcl,v 1.4.6.2 2014/08/05 10:08:54 gustafn Exp $
+    @cvs-id $Id: version-dependency-add.tcl,v 1.6.2.1 2015/09/10 08:21:04 gustafn Exp $
 } {
     {version_id:naturalnum,notnull}
     dependency_type
@@ -23,7 +23,7 @@ set body [subst {
     <form action='version-dependency-add-2' method='post'>
     [export_vars -form {version_id dependency_type dependency_id {our_package_key $package_key}}]
 
-    $pretty_name ${dependency_type}s the following service:
+    <p>$pretty_name ${dependency_type}s the following service:
     <p>
     <select name="service" size="20">
 }]
@@ -38,6 +38,13 @@ append body [subst {
     </select>
     <br>
     <input type="submit" value="Add Dependency">
+    </form>
 }]
 
 ad_return_template apm
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
