@@ -2,7 +2,7 @@ ad_page_contract {
     Adds a dependency to a version of a package. 
     @author Jon Salz (jsalz@arsdigita.com)
     @creation-date 17 April 2000
-    @cvs-id $Id: version-dependency-remove.tcl,v 1.5.4.3 2014/08/05 10:08:54 gustafn Exp $
+    @cvs-id $Id: version-dependency-remove.tcl,v 1.8.2.2 2015/09/18 07:39:04 gustafn Exp $
 } {
     {version_id:naturalnum,notnull}
     {dependency_id:naturalnum,notnull}
@@ -29,8 +29,14 @@ db_transaction {
     apm_package_install_spec $version_id
 } on_error {
     ad_return_complaint 1 "Database Error: The database returned the following error:
-	<blockquote><pre>[ad_quotehtml $errmsg]</pre></blockquote>"
+	<blockquote><pre>[ns_quotehtml $errmsg]</pre></blockquote>"
 }
 
-ad_returnredirect "version-dependencies?[export_vars -url {version_id}]"
+ad_returnredirect [export_vars -base version-dependencies {version_id}]
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
