@@ -2,7 +2,7 @@ ad_page_contract {
     Edit a package version
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date 17 April 2000
-    @cvs-id $Id: version-edit-2.tcl,v 1.11.10.1 2014/08/25 09:27:10 gustafn Exp $
+    @cvs-id $Id: version-edit-2.tcl,v 1.13.2.1 2015/09/10 08:21:04 gustafn Exp $
 
 } {
     version_id:naturalnum,notnull
@@ -17,7 +17,7 @@ ad_page_contract {
     vendor_uri
     {auto_mount ""}
     {release_date ""}
-    { upgrade_p 0 }
+    { upgrade_p:boolean 0 }
 }
 
 # Validate dynamic package version attributes
@@ -92,3 +92,9 @@ I was unable to update your version for the following reason:
 }
 
 ad_returnredirect "version-generate-info?version_id=$version_id&write_p=1"
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
