@@ -2,15 +2,16 @@ ad_page_contract {
     Generates package specs for every enabled version.
     @author Jon Salz (jsalz@arsdigita.com)
     @creation-date 17 April 2000
-    @cvs-id $Id: write-all-specs.tcl,v 1.6.10.3 2014/09/09 20:08:59 gustafn Exp $
+    @cvs-id $Id: write-all-specs.tcl,v 1.7.2.2 2015/09/12 16:47:24 gustafn Exp $
 } {
 }
 
 set title "Generate Package Specifications"
 set context [list [list "." "Package Manager"] $title]
-set template [parameter::get -package_id [ad_conn subsite_id] -parameter StreamingHead] 
-ad_return_top_of_page [ad_parse_template -params [list context title] $template]
 
+ad_return_top_of_page [ad_parse_template \
+                           -params [list context title] \
+                           [template::streaming_template]]
 ns_write {
     Regenerating all package specifications for locally maintained packages.
     <ul>
@@ -41,3 +42,9 @@ db_foreach apm_get_all_packages {
 ns_write [subst {</ul>
 <a href="./">Return to the Package Manager</a>
 }]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
