@@ -17,7 +17,7 @@ if {[catch {set pair [ns_cache get util_memoize $key]} errmsg]} {
 	    set pair [ns_cache get util_memoize $name]
 	    set raw_time [lindex $pair 0]
 	    if {$raw_time == $raw_date} {
-		set value [ad_quotehtml [lindex $pair 1]]
+		set value [ns_quotehtml [lindex $pair 1]]
 		set time [clock format $raw_time]
 		set key $name
 		break
@@ -25,7 +25,7 @@ if {[catch {set pair [ns_cache get util_memoize $key]} errmsg]} {
 	}
     }
 
-    if {![info exists value] || [string equal "" $value]} {
+    if {![info exists value] || "" eq $value} {
 	ad_return_complaint 1 "Could not retrieve"
     }
 }
@@ -34,3 +34,9 @@ if {[catch {set pair [ns_cache get util_memoize $key]} errmsg]} {
 ns_cache flush util_memoize $key
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
