@@ -3,14 +3,14 @@ ad_page_contract {
 
     @author Hiro Iwashima <iwashima@mit.edu>
     @creation-date 23 Aug 2000
-    @cvs-id $Id: send-email.tcl,v 1.4.6.1 2013/10/11 11:43:46 gustafn Exp $
+    @cvs-id $Id: send-email.tcl,v 1.6.2.2 2015/09/18 07:39:03 gustafn Exp $
 } {
     email
     email_from
     subject
     message
     return_url
-    {show_sent_message_p "f"}
+    {show_sent_message_p:boolean "f"}
     {sent_title "Email sent"}
     {sent_subject "Email sent"}
     {sent_message "Email was successfully sent"}
@@ -25,7 +25,7 @@ ad_page_contract {
 
 if {[catch {acs_mail_lite::send -send_immediately -to_addr $email -from_addr $email_from -subject $subject -body $message} errmsg]} {
     ad_return_error $error_subject "<p>$error_message</p>
-    <div><code>[ad_quotehtml $errmsg]</code></div>"
+    <div><code>[ns_quotehtml $errmsg]</code></div>"
     ad_script_abort
 }
 
@@ -34,3 +34,9 @@ if { $show_sent_message_p != "t" } {
     ad_returnredirect $return_url
     ad_script_abort
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
