@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author Peter Marklund (peter@collaboraid.biz)
     @creation-date 27:th of March 2003
-    @cvs-id $Id: server-restart.tcl,v 1.4 2003/10/28 08:54:44 lars Exp $
+    @cvs-id $Id: server-restart.tcl,v 1.4.24.1 2015/09/10 08:21:01 gustafn Exp $
 }
 
 set page_title "Restarting Server"
@@ -15,3 +15,9 @@ set context [list $page_title]
 # We do this as a schedule proc, so the server will have time to serve the page
 
 ad_schedule_proc -thread t -once t 2 ns_shutdown
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
