@@ -10,7 +10,7 @@ ns_write "<li>Set client property..."
 
 set result [ad_get_client_property test MyName]
 
-if { [string compare $result MyValue] == 0 } {
+if { $result eq "MyValue"  } {
     ns_write "<li>Success: Client property successfully retrieved..."
 } else {
     ns_write "<li>Failure: Client property was incorrectly retrieved, expected MyValue, instead got $result..."
@@ -18,4 +18,9 @@ if { [string compare $result MyValue] == 0 } {
 
 ns_write "
 </ul>
-[ad_footer]"
\ No newline at end of file
+[ad_footer]"
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
