@@ -10,7 +10,7 @@ ad_page_contract {
     it gets reparsed; it is RDBMS load that was slowing stuff down.  We also  
     want programmers to have an easy way to edit this page.
 
-    @cvs-id $Id: index.tcl,v 1.5 2003/11/03 17:04:12 lars Exp $
+    @cvs-id $Id: index.tcl,v 1.5.24.3 2015/09/10 11:23:49 gustafn Exp $
     @author Multiple
 }
 
@@ -22,17 +22,19 @@ db_1row users_deleted_users {}
 set n_users [util_commify_number $n_users]
 set last_registration [lc_time_fmt $last_registration "%q"]
 
-set groups [db_html_select_value_options groups_select {
-    select groups.group_id, 
-           groups.group_name, 
-           m.num as n_members, 
-           c.num as n_components 
-    from   groups, 
-           (select group_id, count(*) as num 
-            from group_member_map group by group_id) m, 
-           (select group_id, count(*) as num 
-            from group_component_map group by group_id) c 
-    where  groups.group_id=m.group_id 
-    and    groups.group_id = c.group_id
-    order  by group_name
+set groups "<option value='' selected>--</option>\n"
+append groups [db_html_select_value_options groups_select {
+    select groups.group_id, groups.group_name
+    from groups, 
+       (select distinct group_id from group_member_map) m, 
+       (select distinct group_id from group_component_map) c 
+    where groups.group_id = m.group_id 
+      and groups.group_id = c.group_id
+    order by group_name
 } ]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
