@@ -4,7 +4,7 @@ ad_page_contract {
     makes heavy use of procedures in /tcl/ad-user-contributions-summary.tcl
     modified by mobin January 27, 2000 5:08 am
     
-    @cvs-id $Id: one.tcl,v 1.16.8.3 2014/08/05 10:08:57 gustafn Exp $
+    @cvs-id $Id: one.tcl,v 1.17.2.2 2015/10/08 19:28:03 gustafn Exp $
 } {
     user_id:naturalnum,notnull
 }
@@ -34,8 +34,14 @@ set site_wide_admin_p [acs_user::site_wide_admin_p -user_id $user_id]
 set warning_p 0
 set ad_conn_user_id [ad_conn user_id]
 
+#
+# Define the url for switching side-wide admin priviledges with a timeout of 60 seconds
+#
 if { $site_wide_admin_p } {
+    set modify_admin_url [export_vars -base modify-admin-privileges {user_id:sign(max_age=60) {action:sign revoke}}]
     set warning_p 1
+} else {
+    set modify_admin_url [export_vars -base modify-admin-privileges {user_id:sign(max_age=60) {action:sign grant}}]
 }
 
 
@@ -100,3 +106,9 @@ ad_return_template
 
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
