@@ -5,7 +5,7 @@ ad_page_contract {
     ast_name_from_search, and email_from_search, and passing along all
     form variables listed in "passthrough".
     
-    @cvs-id $Id: search.tcl,v 1.6.10.6 2014/08/05 10:08:57 gustafn Exp $
+    @cvs-id $Id: search.tcl,v 1.9.2.1 2015/09/10 08:21:10 gustafn Exp $
 
     @param email search string
     @param last_name search string
@@ -24,7 +24,7 @@ ad_page_contract {
     target
     {passthrough ""}
     {limit_to_users_in_group_id:naturalnum ""}
-    {only_authorized_p:integer 1}
+    {only_authorized_p:boolean 1}
     {limit_to_user_id:naturalnum ""}
     {from_user_id:naturalnum ""}
 } -properties {
@@ -148,11 +148,11 @@ db_foreach user_search_admin $query {
     set user_search:[set rowcount](first_names) $first_names
     set user_search:[set rowcount](last_name) $last_name
     set user_search:[set rowcount](email) $email
-    set user_search:[set rowcount](export_vars) [export_vars -url {user_id_from_search first_names_from_search last_name_from_search email_from_search}]
+    set user_search:[set rowcount](export_vars) [export_vars {user_id_from_search first_names_from_search last_name_from_search email_from_search}]
     set user_search:[set rowcount](member_state) $member_state
     
     if { $member_state ne "approved" } {
-	set user_search:[set rowcount](user_finite_state_links) [join [ad_registration_finite_state_machine_admin_links $member_state $email_verified_p $user_id_from_search "search?[export_vars -url {email last_name keyword target passthrough limit_to_users_in_group_id only_authorized_p}]"] " | "]
+	set user_search:[set rowcount](user_finite_state_links) [join [ad_registration_finite_state_machine_admin_links $member_state $email_verified_p $user_id_from_search [export_vars -base search {email last_name keyword target passthrough limit_to_users_in_group_id only_authorized_p}]] " | "]
     } else {
 	set user_search:[set rowcount](user_finite_state_links) ""
     }
@@ -174,3 +174,9 @@ if { $limit_to_users_in_group_id ne ""
 set export_authorize [export_ns_set_vars {url} {only_authorized_p}]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
