@@ -1,4 +1,4 @@
-# $Id: session-history.tcl,v 1.3 2007/01/10 21:22:00 gustafn Exp $
+# $Id: session-history.tcl,v 1.4.2.1 2015/09/10 08:21:10 gustafn Exp $
 
 append whole_page "[ad_admin_header "Session History"]
 
@@ -37,12 +37,12 @@ while { [ns_db getrow $db $selection] } {
 	}
 	set last_year $pretty_year
     }
-    append whole_page "<tr>
-<td><a href=\"sessions-one-month?[export_url_vars pretty_month pretty_year]\">$pretty_month $pretty_year</a>
-<td align=right>[util_commify_number $total_sessions]</td>
-<td align=right>[util_commify_number $total_repeats]</td>
-</tr>
-"
+    set href [export_vars -base sessions-one-month {pretty_month pretty_year}]
+    append whole_page [subst {<tr>
+<td><a href="[ns_quotehtml $href]">$pretty_month $pretty_year</a>
+<td align="right">[util_commify_number $total_sessions]</td>
+<td align="right">[util_commify_number $total_repeats]</td>
+</tr>\n}]
 }
 
 append whole_page "
@@ -57,3 +57,9 @@ inflated to the extent that users have disabled cookies."]
 "
 db_release_unused_handles
 ns_return 200 text/html $whole_page
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
