@@ -1,6 +1,6 @@
 ad_page_contract {
     Interface for specifying a list of users to sign up as a batch
-    @cvs-id $Id: user-batch-add-2.tcl,v 1.6.6.1 2013/09/30 11:12:56 gustafn Exp $
+    @cvs-id $Id: user-batch-add-2.tcl,v 1.7.2.2 2015/09/18 07:39:04 gustafn Exp $
 } -query {
     userlist
     from
@@ -83,7 +83,7 @@ from parties where email = lower(:email)"]
     if {[catch {acs_mail_lite::send -send_immediately -to_addr $email -from_addr $from -subject $subject -body $sub_message} errmsg]} {
 	ad_return_error "Mail Failed" "<p>The system was unable to send email.  Please notify the user personally.  This problem is probably caused by a misconfiguration of your email system.  Here is the error:</p> 
 <div><code>
-[ad_quotehtml $errmsg]
+[ns_quotehtml $errmsg]
 </code></div>"
         return
     }
@@ -93,3 +93,9 @@ from parties where email = lower(:email)"]
 ad_return_template
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
