@@ -5,7 +5,7 @@ ad_library {
     @author Jon Salz (jsalz@mit.edu)
     @author Lars Pind (lars@arsdigita.com)
     @creation-date 21 Jun 2000
-    @cvs-id $Id: acs-api-documentation-procs.tcl,v 1.27.8.26 2014/09/23 11:07:04 gustafn Exp $
+    @cvs-id $Id: acs-api-documentation-procs.tcl,v 1.30.2.5 2015/10/09 13:27:35 gustafn Exp $
 
 }
 
@@ -105,7 +105,7 @@ ad_proc -public api_read_script_documentation {
         regsub -all {\#.*$} $line "" line
         set line [string trim $line]
         if { $line ne "" } {
-            set has_contract_p [regexp {(^ad_page_contract\s)|( initialize )} $line match]
+            set has_contract_p [regexp {(^ad_(page|include)_contract\s)|(Package initialize )} $line]
             break
         }
     }
@@ -128,7 +128,7 @@ ad_proc -public api_read_script_documentation {
         if {[regexp {^ad_page_contract documentation} $::errorInfo] } {
             array set doc_elements $error
         }
-        if { [info exists doc_elements] } {
+        if { [array exists doc_elements] } {
             return [array get doc_elements]
         }
         return [list]
@@ -167,12 +167,12 @@ ad_proc -public api_script_documentation {
         } else {
             set preview ""
         }
-        append out "<blockquote><i>Delivered as $mime_type</i>$preview</blockquote>\n"
+        append out "<blockquote><p><i>Delivered as $mime_type</i>$preview</blockquote>\n"
         return $out
     }
 
     if { [catch { array set doc_elements [api_read_script_documentation $path] } error] } {
-        append out "<blockquote><i>Unable to read $path: [ns_quotehtml $error]</i></blockquote>\n"
+        append out "<blockquote><p><i>Unable to read $path: [ns_quotehtml $error]</i></blockquote>\n"
         return $out
     }
 
@@ -188,9 +188,9 @@ ad_proc -public api_script_documentation {
     
     append out "<blockquote>"
     if { [info exists doc_elements(main)] } {
-        append out [lindex $doc_elements(main) 0]
+        append out <p>[lindex $doc_elements(main) 0]
     } else {
-        append out "<i>Does not contain a contract.</i>"
+        append out "<p><i>Does not contain a contract.</i>"
     }
     append out "<dl>\n"
     # XXX: This does not work at the moment. -bmq
@@ -250,15 +250,15 @@ ad_proc -public api_library_documentation {
         return -code error "Only text/html documentation is currently supported"
     }
 
-    set out "<h3>[file tail $path]</h3>"
+    set out "<h3>[ns_quotehtml [file tail $path]]</h3>"
     
     if { [nsv_exists api_library_doc $path] } {
         array set doc_elements [nsv_get api_library_doc $path]
-        append out "<blockquote>\n"
+        append out "<blockquote><p>\n"
         append out [lindex $doc_elements(main) 0]
 
         append out "<dl>\n"
-        append out "<dt><b>Location:</b>\n<dd>$path\n"
+        append out "<dt><b>Location:</b>\n<dd>[ns_quotehtml $path]\n"
         if { [info exists doc_elements(creation-date)] } {
             append out "<dt><b>Created:</b>\n<dd>[lindex $doc_elements(creation-date) 0]\n"
         }
@@ -269,7 +269,10 @@ ad_proc -public api_library_documentation {
             }
         }
         if { [info exists doc_elements(cvs-id)] } {
-            append out "<dt><b>CVS Identification:</b>\n<dd><code>[ns_quotehtml [lindex $doc_elements(cvs-id) 0]]</code>\n"
+            append out [subst {
+                <dt><b>CVS Identification:</b>
+                <dd><code>[ns_quotehtml [lindex $doc_elements(cvs-id) 0]]</code>
+            }]
         }
         append out "</dl>\n"
         append out "</blockquote>\n"
@@ -441,7 +444,7 @@ ad_proc -public api_proc_documentation {
     append out [util_wrap_list $command_line] "\n<blockquote>\n"
     
     if { $script_p } {
-        append out [subst {Defined in 
+        append out [subst {<p>Defined in 
             <a href="/api-doc/procs-file-view?path=[ns_urlencode $doc_elements(script)]">$doc_elements(script)</a>
             <p>}]
     }
@@ -454,89 +457,109 @@ ad_proc -public api_proc_documentation {
         append out "</i></b><p>\n"
     }
 
-    append out "[lindex $doc_elements(main) 0]\n<p>\n<dl>\n"
+    append out "<p>[lindex $doc_elements(main) 0]\n<p>\n"
+    set haveBlocks [expr {
+                          [info exists doc_elements(param)]
+                          || [llength $doc_elements(switches)] > 0
+                          || [llength $doc_elements(positionals)] > 0
+                          || [info exists doc_elements(option)]
+                          || [info exists doc_elements(return)]
+                          || [info exists doc_elements(error)]
+                          || [info exists doc_elements(author)]
+                          || [info exists doc_elements(creation-date)]
+                          || [info exists doc_elements(change-log)]
+                          || [info exists doc_elements(cvs-id)]
+                          || [info exists doc_elements(see)]
+                      }]
+    if {$haveBlocks} {
+        append out "<dl>\n"
 
-    if { [info exists doc_elements(param)] } {
-        foreach param $doc_elements(param) {
-            if { [regexp {^([^ \t\n]+)[ \t\n]+(.*)$} $param "" name value] } {
-                set params($name) $value
-            }
-        }
-    }
-    
-    if { [llength $doc_elements(switches)] > 0 } {
-        append out "<dt><b>Switches:</b></dt><dd><dl>\n"
-        foreach switch $doc_elements(switches) {
-            append out "<dt><b>-$switch</b>"
-            if {"boolean" in $flags($switch)} {
-                append out " (boolean)"
-            } 
-            
-            if { [info exists default_values($switch)]
-                 && $default_values($switch) ne "" 
-             } {
-                append out " (defaults to <code>\"[ns_quotehtml $default_values($switch)]\"</code>)"
-            } 
-            
-            if {"required" in $flags($switch)} {
-                append out " (required)"
-            } else {
-                append out " (optional)"
-            }
-            append out "</dt>"
-            if { [info exists params($switch)] } {
-                append out "<dd>$params($switch)</dd>"
-            }
-        }
-        append out "</dl></dd>\n"
-    }
-    
-    if { [llength $doc_elements(positionals)] > 0 } {
-        append out "<dt><b>Parameters:</b></dt><dd>\n"
-        foreach positional $doc_elements(positionals) {
-            append out "<b>$positional</b>"
-            if { [info exists default_values($positional)] } {
-                if { $default_values($positional) eq "" } {
-                    append out " (optional)"
-                } else {
-                    append out " (defaults to <code>\"$default_values($positional)\"</code>)"
+        if { [info exists doc_elements(param)] } {
+            foreach param $doc_elements(param) {
+                if { [regexp {^([^ \t\n]+)[ \t\n]+(.*)$} $param "" name value] } {
+                    set params($name) $value
                 }
             }
-            if { [info exists params($positional)] } {
-                append out " - $params($positional)"
-            }
-            append out "<br>\n"
         }
-        append out "</dd>\n"
-    }
     
-
-    # @option is used in  template:: and cms:: (and maybe should be used in some other 
-    # things like ad_form which have internal arg parsers.  although an option 
-    # and a switch are the same thing, just one is parsed in the proc itself rather than 
-    # by ad_proc.
-
-    if { [info exists doc_elements(option)] } {
-        append out "<b>Options:</b><dl>"
-        foreach param $doc_elements(option) {
-            if { [regexp {^([^ \t]+)[ \t](.+)$} $param "" name value] } {
-                append out "<dt><b>-$name</b></dt><dd>$value<br></dd>"
+        if { [llength $doc_elements(switches)] > 0 } {
+            append out "<dt><b>Switches:</b></dt><dd><dl>\n"
+            foreach switch $doc_elements(switches) {
+                append out "<dt><b>-$switch</b>"
+                if {"boolean" in $flags($switch)} {
+                    append out " (boolean)"
+                } 
+                
+                if { [info exists default_values($switch)]
+                     && $default_values($switch) ne "" 
+                 } {
+                    append out " (defaults to <code>\"[ns_quotehtml $default_values($switch)]\"</code>)"
+                } 
+                
+                if {"required" in $flags($switch)} {
+                    append out " (required)"
+                } else {
+                    append out " (optional)"
+                }
+                append out "</dt>"
+                if { [info exists params($switch)] } {
+                    append out "<dd>$params($switch)</dd>"
+                }
             }
+            append out "</dl></dd>\n"
         }
-        append out "</dl>"
-    }
-    
+        
+        if { [llength $doc_elements(positionals)] > 0 } {
+            append out "<dt><b>Parameters:</b></dt><dd>\n"
+            foreach positional $doc_elements(positionals) {
+                append out "<b>$positional</b>"
+                if { [info exists default_values($positional)] } {
+                    if { $default_values($positional) eq "" } {
+                        append out " (optional)"
+                    } else {
+                        append out " (defaults to <code>\"$default_values($positional)\"</code>)"
+                    }
+                }
+                if { [info exists params($positional)] } {
+                    append out " - $params($positional)"
+                }
+                append out "<br>\n"
+            }
+            append out "</dd>\n"
+        }
+        
 
-    if { [info exists doc_elements(return)] } {
-        append out "<dt><b>Returns:</b></dt><dd>[join $doc_elements(return) "<br>"]</dd>\n"
+        # @option is used in  template:: and cms:: (and maybe should be used in some other 
+        # things like ad_form which have internal arg parsers.  although an option 
+        # and a switch are the same thing, just one is parsed in the proc itself rather than 
+        # by ad_proc.
+
+        if { [info exists doc_elements(option)] } {
+            append out "<b>Options:</b><dl>"
+            foreach param $doc_elements(option) {
+                if { [regexp {^([^ \t]+)[ \t](.+)$} $param "" name value] } {
+                    append out "<dt><b>-$name</b></dt><dd>$value<br></dd>"
+                }
+            }
+            append out "</dl>"
+        }
+        
+
+        if { [info exists doc_elements(return)] } {
+            append out "<dt><b>Returns:</b></dt><dd>[join $doc_elements(return) "<br>"]</dd>\n"
+        }
+    
+        if { [info exists doc_elements(error)] } {
+            append out "<dt><b>Error:</b></dt><dd>[join $doc_elements(error) "<br>"]</dd>\n"
+        }
+
+        append out [::apidoc::format_common_elements doc_elements]
+
+        append out "</dl>\n"
     }
-    
-    if { [info exists doc_elements(error)] } {
-        append out "<dt><b>Error:</b></dt><dd>[join $doc_elements(error) "<br>"]</dd>\n"
-    }
-    
-    append out [::apidoc::format_common_elements doc_elements]
-    
+
+
+
     if { $source_p } {
         if {[parameter::get_from_package_key \
                  -package_key acs-api-browser \
@@ -544,12 +567,12 @@ ad_proc -public api_proc_documentation {
                  -default 1]} {
             append out [subst {<dt><b>Source code:</b></dt><dd>
                 <pre class="code">[::apidoc::tcl_to_html $proc_name]</pre>
-                </dd><p>
+                </dd>
             }]
         } else {
             append out [subst {<dt><b>Source code:</b></dt><dd>
                 <pre class="code">[ns_quotehtml [api_get_body $proc_name]]</pre>
-                </dd><p>
+                </dd>
             }]
         }
     }
@@ -563,11 +586,12 @@ ad_proc -public api_proc_documentation {
         if { [file exists $::acs::rootdir/$xql_fn] } {
             set content [apidoc::get_xql_snippet -proc_name $proc_name -xql_file $xql_fn]
             if {$content ne ""} {set content "<pre class='code'>$content</pre>"}
-            append there [subst {<dt><b>Generic XQL file:</b> <dt>
-                <blockquote>$content
-                <a href="content-page-view?[export_vars {{source_p 1} {path $xql_fn}}]">$xql_fn</a>
-                </blockquote>
+            append there [subst {<dt><b>Generic XQL file:</b> </dt>
+                <dd>$content
+                <a href="[ns_quotehtml [export_vars -base content-page-view {{source_p 1} {path $xql_fn}}]]">$xql_fn</a>
                 <p>
+                </dd>
+
             }]
         } else {
             lappend missing Generic
@@ -577,10 +601,10 @@ ad_proc -public api_proc_documentation {
             set content [apidoc::get_xql_snippet -proc_name $proc_name -xql_file $xql_fn]
             if {$content ne ""} {set content "<pre class='code'>$content</pre>"}
             append there [subst {<dt><b>PostgreSQL XQL file:</b></dt>
-                <blockquote>$content
-                <a href="content-page-view?[export_vars {{source_p 1} {path $xql_fn}}]">$xql_fn</a>
-                </blockquote>
+                <dd>$content
+                <a href="[ns_quotehtml [export_vars -base content-page-view {{source_p 1} {path $xql_fn}}]]">$xql_fn</a>
                 <p>
+                </dd>
             }]
         } else {
             lappend missing PostgreSQL
@@ -591,10 +615,10 @@ ad_proc -public api_proc_documentation {
             set content [apidoc::get_xql_snippet -proc_name $proc_name -xql_file $xql_fn]
             if {$content ne ""} {set content "<pre class='code'>$content</pre>"}
             append there [subst {<dt><b>Oracle XQL file:</b></dt>
-                <blockquote>$content
-                <a href="content-page-view?[export_vars {{source_p 1} {path $xql_fn}}]">$xql_fn</a>
-                </blockquote>
+                <dd>$content
+                <a href="[ns_quotehtml [export_vars -base content-page-view {{source_p 1} {path $xql_fn}}]]">$xql_fn</a>
                 <p>
+                </dd>
             }]
         } else {
             lappend missing Oracle
@@ -606,8 +630,7 @@ ad_proc -public api_proc_documentation {
     }
 
     # No "see also" yet.
-    
-    append out "</dl></blockquote>"
+    append out "</blockquote>"
     
     return $out
 }
@@ -625,7 +648,7 @@ ad_proc api_proc_pretty_name {
         set label $proc
     }
     if { $link_p } {
-        append out "<a href=\"[api_proc_url $proc]\">$label</a>"
+        append out "<a href=\"[ns_quotehtml [api_proc_url $proc]]\">$label</a>"
     } else {    
         append out "$label"
     }
@@ -741,26 +764,42 @@ namespace eval ::apidoc {
     }
 
     ad_proc -public format_see { see } {
+        Takes the value in the argument "see" and possibly formats it
+        into a link that will give the user more info about that
+        resource
+
+        @param see a string expected to comtain the resource to format
+        @return the html string representing the resource
+    } {
         regsub -all {proc *} $see {} see
         set see [string trim $see]
         if {[nsv_exists api_proc_doc $see]} {
-            return "<a href=\"proc-view?proc=[ns_urlencode ${see}]\">$see</a>"
+            set href [export_vars -base proc-view {{proc $see}}]
+            return [subst {<a href="[ns_quotehtml $href]">$see</a>}]
         }
-        if {[string match "/doc/*.html" $see]
+        if {[string match "/doc/*" $see]
             || [util_url_valid_p $see]} { 
-            return "<a href=\"${see}]\">$see</a>"
+            return [subst {<a href="[ns_quotehtml $see]">$see</a>}]
         }
         if {[file exists "$::acs::rootdir${see}"]} {
-            return "<a href=\"content-page-view?source_p=1&path=[ns_urlencode $see]\">$see</a>"
+            set href [export_vars -base content-page-view {{source_p 1} {path $see}}]
+            return [subst {<a href="[ns_quotehtml $href]">$see</a>}]
         }
         return ${see}
     }
 
     ad_proc -public format_author { author_string } {
+
+        Extracts information about the author and formats it into an
+        HTML string.
+
+        @param author_string author information to format
+        @return the formatted result
+    } {
         if { [regexp {^[^ \n\r\t]+$} $author_string] 
              && [string first "@" $author_string] >= 0 
              && [string first ":" $author_string] < 0 } {
-            return "<a href=\"mailto:$author_string\">$author_string</a>"
+            return [subst {<a href="mailto:$author_string">$author_string</a>}]
         } elseif { [regexp {^([^\(\)]+)\s+\((.+)\)$} [string trim $author_string] {} name email] } {
             return "$name &lt;<a href=\"mailto:$email\">$email</a>&gt;"
         }
@@ -948,15 +987,15 @@ namespace eval ::apidoc {
         Given a proc name, formats it as HTML, including highlighting syntax in
         various colors and creating hyperlinks to other proc definitions.<BR>
         The inspiration for this proc was the tcl2html script created by Jeff Hobbs.
-        <P>
+        <p>
         Known Issues:
-        <OL>
-        <LI> This proc will mistakenly highlight switch strings that look like commands as commands, etc.
-        <LI> There are many undocumented AOLserver commands including all of the commands added by modules.
-        <LI> When a proc inside a string has explicitly quoted arguments, they are not formatted.
-        <LI> regexp and regsub are hard to parse properly.  E.g. If we use the start option, and we quote its argument,
+        <ol>
+        <li> This proc will mistakenly highlight switch strings that look like commands as commands, etc.
+        <li> There are many undocumented AOLserver commands including all of the commands added by modules.
+        <li> When a proc inside a string has explicitly quoted arguments, they are not formatted.
+        <li> regexp and regsub are hard to parse properly.  E.g. If we use the start option, and we quote its argument,
         and we have an ugly regexp, then this code might highlight it incorrectly.
-        </OL>
+        </ol>
 
         @author Jamie Rasmussen (jrasmuss@mle.ie)
 
@@ -1212,7 +1251,7 @@ namespace eval ::apidoc {
                              && $had_colons in $::apidoc::KEYWORDS)} {
 
                             set url "/api-doc/proc-view?proc=$proc_name"
-                            append html "<a href='$url' title='Tcl command'>" \
+                            append html "<a href='[ns_quotehtml $url]' title='Tcl command'>" \
                                 [pretty_token keyword $proc_name] </a>
 
                             #append html [pretty_token keyword $proc_name]
@@ -1224,12 +1263,12 @@ namespace eval ::apidoc {
                             set url [::xotcl::api object_url \
                                          -show_source 1 -show_methods 2 \
                                          $scope $proc_name]
-                            append html "<a href='$url' title='XOTcl object'>" \
+                            append html "<a href='[ns_quotehtml $url]' title='XOTcl object'>" \
                                 [pretty_token object $proc_name] </a>
 
                         } elseif {[string match "ns*" $proc_name]} {
                             set url "/api-doc/tcl-proc-view?tcl_proc=$proc_name"
-                            append html "<a href='$url' title='[ns_info name] command'>" \
+                            append html "<a href='[ns_quotehtml $url]' title='[ns_info name] command'>" \
                                 [pretty_token proc $proc_name] </a>
 
                         } elseif {[string match "*__arg_parser" $proc_name]} {
@@ -1238,12 +1277,12 @@ namespace eval ::apidoc {
                         } elseif {$proc_namespace ne "" 
                                   && [info commands ::${proc_namespace}::${proc_name}] ne ""}  {
                             set url [api_proc_url ${proc_namespace}::${proc_name}]
-                            append html "<a href='$url' title='API command'>" \
+                            append html "<a href='[ns_quotehtml $url]' title='API command'>" \
                                 [pretty_token proc $proc_name] </a>
 
                         } elseif {[info commands ::$proc_name] ne ""}  {
                             set url [api_proc_url $proc_name]
-                            append html "<a href='$url' title='API command'>" \
+                            append html "<a href='[ns_quotehtml $url]' title='API command'>" \
                                 [pretty_token proc $proc_name] </a>
 
                         } else {
@@ -1295,7 +1334,7 @@ namespace eval ::apidoc {
     } {
         
         set linkList [list]
-        set filename "$::acs::rootdir/$path"
+        set filename $::acs::rootdir/$path
         set path_dirname [file dirname $path]
         set file_dirname [file dirname $filename]
         set file_rootname [file rootname [file tail $filename]]
@@ -1309,7 +1348,7 @@ namespace eval ::apidoc {
         foreach file $files {
             lappend linkList [list \
                                   filename $file \
-                                  link "content-page-view?source_p=1&path=[ns_urlencode "$path_dirname/[file tail $file]"]" \
+                                  link "content-page-view?source_p=1&path=[ns_urlencode $path_dirname/[file tail $file]]" \
                                  ]
             
         }
@@ -1374,7 +1413,7 @@ ad_proc api_proc_link { proc } {
     @author Lars Pind (lars@pinds.com)
     @creation-date 14 July 2000
 } {
-    return "<a href=\"[api_proc_url $proc]\">$proc</a>"
+    return "<a href=\"[ns_htmlencode [api_proc_url $proc]]\">$proc</a>"
 }
 
 
