@@ -7,12 +7,12 @@ ad_page_contract {
         <code>procs</code> or <code>content</code>.
     @author Jon Salz (jsalz@mit.edu)
     @creation-date 3 Jul 2000
-    @cvs-id $Id: package-view.tcl,v 1.7.2.8 2014/09/10 20:19:27 gustafn Exp $
+    @cvs-id $Id: package-view.tcl,v 1.9.2.4 2015/10/09 13:26:12 gustafn Exp $
 } {
     version_id:naturalnum,notnull
-    { public_p "" }
-    { kind "procs_files" }
-    { about_package_key ""}
+    { public_p:boolean "" }
+    { kind:word "procs_files" }
+    { about_package_key:token ""}
 } -properties {
     title:onevalue
     context:onevalue
@@ -79,7 +79,12 @@ switch $kind {
                 set first_sentence [::apidoc::first_sentence [lindex $doc_elements(main) 0]]
                 set view procs-file-view
             } else {
-                set first_sentence ""
+                array set doc_elements [api_read_script_documentation $full_path]
+                if { [info exists doc_elements(main)] } {
+                    set first_sentence [::apidoc::first_sentence [lindex $doc_elements(main) 0]]
+                } else {
+                    set first_sentence ""
+                }
                 set view content-page-view
             }
 
@@ -171,3 +176,9 @@ switch $kind {
         }
     }
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
