@@ -8,10 +8,10 @@ ad_page_contract {
 
     @author Michael Yoon (michael@arsdigita.com)
     @creation-date 2000-03-05
-    @cvs-id $Id: plsql-subprogram-one.tcl,v 1.3.26.1 2013/09/09 16:44:18 gustafn Exp $
+    @cvs-id $Id: plsql-subprogram-one.tcl,v 1.6.2.1 2015/09/10 08:21:11 gustafn Exp $
 } {
-    name
-    type
+    name:token
+    type:token
 } -properties {
     title:onevalue
     context:onevalue
@@ -33,12 +33,14 @@ order by line" {
 switch $type {
     "PACKAGE" {
 	set type "PACKAGE BODY"
-	set package_slider_list [list "package" "<a href=\"[ad_conn url]?[export_vars -url {type name}]\">package body</a>"]
+	set href [export_vars -base [ad_conn url] {type name}]
+	set package_slider_list [list "package" [subst {<a href="[ns_quotehtml $href]">package body</a>}]]
     }
 
     "PACKAGE BODY" {
 	set type "PACKAGE"
-	set package_slider_list [list "<a href=\"[ad_conn url]?[export_vars -url {type name}]\">package</a>" "package body"]
+	set href [export_vars -base [ad_conn url] {type name}]
+	set package_slider_list [list [subst {<a href="[ns_quotehtml $href]">package</a>}] "package body"]
     }
 
     default {
@@ -52,3 +54,9 @@ set name [string tolower $name]
 
 db_release_unused_handles
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
