@@ -11,15 +11,15 @@ ad_page_contract {
 
     @author Todd Nightingale (tnight@arsdigita.com)
     @creation-date Jul 14, 2000
-    @cvs-id $Id: proc-search.tcl,v 1.12.10.3 2014/09/09 07:41:10 gustafn Exp $
+    @cvs-id $Id: proc-search.tcl,v 1.15.2.1 2015/09/10 08:21:11 gustafn Exp $
 } {
     {name_weight:optional 0}
-    {doc_weight:optional 0}
-    {param_weight:optional 0}
-    {source_weight:optional 0}
+    {doc_weight:integer,optional 0}
+    {param_weight:integer,optional 0}
+    {source_weight:integer,optional 0}
     {search_type:optional 0}
-    {show_deprecated_p 0}
-    {show_private_p 0}
+    {show_deprecated_p:boolean 0}
+    {show_private_p:boolean 0}
     query_string
 } -properties {
     title:onevalue
@@ -46,7 +46,7 @@ if {$quick_view && [nsv_exists api_proc_doc $query_string]} {
 
 ###########################
 # No weighting use default:
-if { ($name_weight == 0) && ($doc_weight == 0) && ($param_weight == 0) && ($source_weight ==0) } {
+if { ($name_weight == 0) && ($doc_weight == 0) && ($param_weight == 0) && ($source_weight == 0) } {
     set name_weight 1
 }
 
@@ -72,7 +72,7 @@ foreach proc [nsv_array names api_proc_doc] {
     ###############
     ## Name Search:
     ###############
-    if {$name_weight} {
+    if {$name_weight != 0 && [string is integer -strict $name_weight]} {
         # JCD: this was a little perverse since exact matches were
         # actually worth less than matches in the name (if there were
         # 2 or more, which happens with namespaces) so I doubled the
@@ -97,7 +97,7 @@ foreach proc [nsv_array names api_proc_doc] {
     ##############
     ## Doc Search:
     ##############
-    if {$doc_weight} {
+    if {$doc_weight > 0} {
         
         set doc_string [lindex $doc_elements(main) 0]
         if {[info exists doc_elements(param)]} {
@@ -115,7 +115,7 @@ foreach proc [nsv_array names api_proc_doc] {
     #################
     ## Source Search:
     #################
-    if {$source_weight} {
+    if {$source_weight != 0} {
         if {![catch {set source [info body $proc]}]} {
             incr score [expr {$source_weight * [::apidoc::ad_keywords_score $query_string $source]}] 
         }    
@@ -186,3 +186,9 @@ foreach output $private_matches {
 set show_private_url [export_vars -base [ad_conn url] -override { { show_private_p 1 } } { name_weight doc_weight param_weight source_weight search_type query_string show_deprecated_p }]
 
 set hide_private_url [export_vars -base [ad_conn url] -override { { show_private_p 0 } } { name_weight doc_weight param_weight source_weight search_type query_string show_deprecated_p }]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
