@@ -1,12 +1,12 @@
 ad_page_contract {
     Displays procs in a Tcl library file.
 
-    @cvs-id $Id: procs-file-view.tcl,v 1.3.10.8 2014/09/14 09:02:41 gustafn Exp $
+    @cvs-id $Id: procs-file-view.tcl,v 1.8.2.3 2015/10/06 06:28:55 gustafn Exp $
 } {
     version_id:naturalnum,optional
-    { public_p "" }
-    path:trim
-    source_p:integer,optional,trim
+    { public_p:boolean "" }
+    path:path,trim
+    source_p:boolean,optional,trim
 } -properties {
     title:onevalue
     context:onevalue
@@ -16,7 +16,7 @@ ad_page_contract {
     proc_doc_list:multirow
 }
 
-set url_vars [export_vars -url {path version_id}]
+set url_vars [export_vars {path version_id}]
 set return_url [ns_urlencode [ad_conn url]?][ns_urlencode $url_vars]
 set default_source_p [ad_get_client_property -default 0 acs-api-browser api_doc_source_p]
 if { ![info exists source_p] } {
@@ -35,10 +35,10 @@ set path [apidoc::sanitize_path $path]
 if {![file readable $::acs::rootdir/$path] || [file isdirectory $::acs::rootdir/$path]} {
     if {[info exists version_id]} {
 	set kind procs
-	set href [ad_conn package_url]/package-view?[export_vars {version_id {kind procs}}]
-	set link [subst {<p>Go back to <a href="$href">Package Documentation</a>.}]
+	set href [export_vars -base [ad_conn package_url]/package-view {version_id {kind procs}}]
+	set link [subst {<p>Go back to <a href="[ns_quotehtml $href]">Package Documentation</a>.}]
     } else {
-	set link [subst {<p>Go back to <a href="[ad_conn package_url]">API Browser</a>.}]
+	set link [subst {<p>Go back to <a href="[ns_quotehtml [ad_conn package_url]]">API Browser</a>.}]
     }
     ad_return_warning "No such library file" [subst {
 	The file '$path' was not found. Maybe the url contains a typo.
@@ -71,7 +71,7 @@ if { [info exists version_id] } {
          where version_id = :version_id
     }
     if {[info exists pretty_name]} {
-	lappend context [list "package-view?version_id=$version_id" "$pretty_name $version_name"]
+	lappend context [list [export_vars -base package-view {version_id}] "$pretty_name $version_name"]
     }
 
 }
@@ -111,3 +111,9 @@ if { $source_p } {
    set file_contents [template::util::read_file $::acs::rootdir/$path]
    set file_contents [apidoc::tclcode_to_html $file_contents]
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
