@@ -1,8 +1,8 @@
 ad_page_contract {
     Will redirect you to the server containing the documentation if it can be found
-    @cvs-id $Id: tcl-proc-view.tcl,v 1.6.8.5 2014/09/05 18:47:14 gustafn Exp $
+    @cvs-id $Id: tcl-proc-view.tcl,v 1.10.2.1 2015/09/10 08:21:12 gustafn Exp $
 } {
-    tcl_proc
+    tcl_proc:token,notnull
 } -properties {
     title:onevalue
     context:onevalue
@@ -34,3 +34,9 @@ if {$url ne ""} {
 
 set title "[ns_info name] Tcl API Search for: \"$tcl_proc\""
 set context [list "Tcl API Search: $tcl_proc"]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
