@@ -16,8 +16,8 @@ ad_page_contract {
 
 } {
     {search_text ""}
-    {authority_id ""}
-    orderby:optional
+    {authority_id:naturalnum,notnull ""}
+    orderby:token,optional
 }
 
 set authority_options [auth::authority::get_authority_options]
@@ -65,15 +65,18 @@ if {[info exists add_permission] && [llength $add_permission]} {
     lappend bulk_actions $add_user_label $add_user_url $add_user_label
 }
 if {![regexp {\?} $add_user_url]} {
-    set add_user_url "${add_user_url}?"
+    set add_user_url "$add_user_url?"
 }
 if {![info exists group_id] || $group_id eq ""} {
     set group_id [application_group::group_id_from_package_id -package_id $package_id]
 }
 # generate authority links
 
- template::multirow create users first last username email auth_status group_member_p create_account_url actions extra_attributes user_id authority_id
+template::multirow create users \
+    first last username email auth_status group_member_p create_account_url actions extra_attributes user_id authority_id
+
 ns_log debug "MEMBER SEARCH TCL level='[template::adp_level]' [uplevel \#[template::adp_level] "info vars"]"
+
  template::list::create \
     -no_data "Search returned no results" \
     -name users \
@@ -87,16 +90,25 @@ ns_log debug "MEMBER SEARCH TCL level='[template::adp_level]' [uplevel \#[templa
 	 display_template {<if @users.first@ not nil and @users.last@ not nil and @users.email@ not nil and @users.group_member_p@ false><input type="checkbox" name="userkey" value="@users.username@ @users.authority_id@" /></if>}} \
 		   first [list label "First Name" link_url_eval "\[export_vars -base \"$member_url\" {user_id} \]"] \
 		   last [list label "Last Name"  link_url_eval "\[export_vars -base \"$member_url\" {user_id} \]"] \
-    username [list label "Username" link_url_eval "\[export_vars -base \"$member_url\" {user_id} \]"] \
-     email {label "Email"} \
-     auth_status {
- 	label "Status"
-     } \
-		   actions [list label "Actions" display_template "<if @users.first@ not nil and @users.last@ not nil and @users.email@ not nil and @users.group_member_p@ false><a href=\"${add_user_url}&userkey=@users.username@+@users.authority_id@&authority_id=${authority_id}&return_url=[ad_urlencode ${return_url}]&group_id=$group_id\" class=button>$add_user_label</a></if>"] \
-     extra_attributes {label "Extra Attributes"} \
-		   user_id [list hide_p [expr {!$admin_p}] label "" display_template "<if @users.user_id@ not nil><a href=\"$member_admin_url?user_id=@users.user_id@\">User Admin Page</a></if>"] \
-	       ] -bulk_actions $bulk_actions \
- -orderby {first {orderby first_names} last {orderby last_name} username  {orderby username} email {orderby email} auth_status {orderby auth_status}}
+		   username [list label "Username" link_url_eval "\[export_vars -base \"$member_url\" {user_id} \]"] \
+		   email {label "Email"} \
+		   auth_status { label "Status" } \
+		   actions [list label "Actions" display_template [subst {
+		       <if @users.first@ not nil and @users.last@ not nil and @users.email@ not nil
+		       and @users.group_member_p@ false><a href="[ns_quotehtml ${add_user_url}&userkey=@users.username@+@users.authority_id@&authority_id=${authority_id}&return_url=[ad_urlencode ${return_url}]&group_id=$group_id]" class=button>$add_user_label</a></if>
+		   }]] \
+		   extra_attributes {label "Extra Attributes"} \
+		   user_id [list hide_p [expr {!$admin_p}] label "" display_template [subst {
+		       <if @users.user_id@ not nil><a href="[ns_quotehtml $member_admin_url?user_id=@users.user_id@]">User Admin Page</a></if>
+		   }]] \
+		  ] -bulk_actions $bulk_actions \
+    -orderby {
+	first {orderby first_names}
+	last {orderby last_name}
+	username {orderby username}
+	email {orderby email}
+	auth_status {orderby auth_status}
+    }
 
 template::multirow create authorities authority_id pretty_name local_authority_p search_url form_include
 
@@ -107,12 +119,19 @@ foreach option_list [auth::authority::get_authority_options] {
 	set local_authority_id $this_authority_id
 	set form_include /packages/acs-authentication/lib/local-search
     } else {
-	set form_include [acs_sc::invoke -impl_id [auth::authority::get_element -authority_id $this_authority_id -element search_impl_id] -operation FormInclude] 
+	set form_include [acs_sc::invoke \
+			      -impl_id [auth::authority::get_element -authority_id $this_authority_id -element search_impl_id] \
+			      -operation FormInclude]
     }
     if {$this_authority_id eq $selected_authority_id} {
 	set selected_form_include $form_include
     }
-    template::multirow append authorities $this_authority_id [lindex $option_list 0] $local_authority_p [export_vars -base [ad_conn url] -no_empty {{authority_id $this_authority_id} search_text object_id}] $form_include
+    template::multirow append authorities \
+	$this_authority_id \
+	[lindex $option_list 0] \
+	$local_authority_p \
+	[export_vars -base [ad_conn url] -no_empty {{authority_id $this_authority_id} search_text object_id}] \
+	$form_include
 }
 
 #template::multirow sort authorities -decreasing authority_id
@@ -127,4 +146,10 @@ set authority_id $selected_authority_id
 #<include src="@authorities.form_include@" authority_id="@authorities.authority_id@" search_text="@search_text@" return_url="@return_url@" orderby="@orderby@">
 if {![info exists orderby]} {
     set orderby ""
-}
\ No newline at end of file
+}
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
