@@ -3,7 +3,7 @@ ad_library {
 
     @author Lars Pind (lars@collaobraid.biz)
     @creation-date 2003-05-13
-    @cvs-id $Id: authentication-procs.tcl,v 1.87.4.7 2014/08/18 09:23:45 gustafn Exp $
+    @cvs-id $Id: authentication-procs.tcl,v 1.89.2.3 2015/10/20 08:19:13 gustafn Exp $
 }
 
 namespace eval auth {}
@@ -241,8 +241,7 @@ ad_proc -public auth::authenticate {
     } {
         set result(auth_status) failed_to_connect
         set result(auth_message) $errmsg
-        global errorInfo
-        ns_log Error "auth::authenticate: error invoking authentication driver for authority_id = $authority_id: $errorInfo"
+        ns_log Error "auth::authenticate: error invoking authentication driver for authority_id = $authority_id: $::errorInfo"
     }
 
     # Returns:
@@ -1061,8 +1060,7 @@ ad_proc -private auth::create_local_account_helper {
 
     } on_error {
         # we got an error.  log it and signal failure.
-        global errorInfo
-        ns_log Error "Problem creating a new user: $errorInfo"
+        ns_log Error "Problem creating a new user: $::errorInfo"
         set error_p 1
     }
     
@@ -1197,8 +1195,7 @@ ad_proc -public auth::update_local_account {
     if { $error_p } {
         set result(update_status) "failed_to_connect"
         set result(update_message) [_ acs-subsite.Error_update_account_info]
-        global errorInfo
-        ns_log Error "Error updating local account.\n$errorInfo"
+        ns_log Error "Error updating local account.\n$::errorInfo"
         return [array get result]
     }
 
@@ -1303,7 +1300,7 @@ ad_proc -private auth::get_local_account {
     if { $authority_id eq "" } {
         set authority_id [auth::authority::local]
     }
-    ns_log notice "auth::get_local_account authority_id = '${authority_id}' local = [auth::authority::local]"
+    #ns_log notice "auth::get_local_account authority_id = '${authority_id}' local = [auth::authority::local]"
     with_catch errmsg {
         acs_user::get -authority_id $authority_id -username $username -array user
         set account_found_p 1
@@ -1424,8 +1421,10 @@ ad_proc -private auth::check_local_account_status {
 
     switch $member_state {
         approved {
-            set PasswordExpirationDays [parameter::get -parameter PasswordExpirationDays -package_id [ad_acs_kernel_id] -default 0]
-            
+            set PasswordExpirationDays [parameter::get \
+                                            -parameter PasswordExpirationDays \
+                                            -package_id [ad_acs_kernel_id] \
+                                            -default 0]
 
             if { $email_verified_p == "f" } {
                 if { !$no_dialogue_p } {
@@ -1434,17 +1433,23 @@ ad_proc -private auth::check_local_account_status {
                     with_catch errmsg {
                         auth::send_email_verification_email -user_id $user_id
                     } {
-                        global errorInfo
-                        ns_log Error "auth::check_local_account_status: Error sending out email verification email to email $email:\n$errorInfo"
+                        ns_log Error "auth::check_local_account_status: Error sending out email verification email to email $email:\n$::errorInfo"
                         set result(account_message) [_ acs-subsite.Error_sending_verification_mail]
                     }
                 }
-            } elseif { [acs_user::ScreenName] eq "require" && $screen_name eq "" } {
-                set message "Please enter a screen name now."
-                set result(account_url) [export_vars -no_empty -base "[subsite::get_element -element url]user/basic-info-update" { message return_url {edit_p 1} }]
-            } elseif { $PasswordExpirationDays > 0 && \
-                           ($password_age_days eq "" || $password_age_days > $PasswordExpirationDays) } {
                 
+            } elseif { [acs_user::ScreenName] eq "require"
+                       && $screen_name eq ""
+                   } {
+                set message "Please enter a screen name now."
+                set result(account_url) [export_vars -no_empty \
+                                             -base "[subsite::get_element -element url]user/basic-info-update" {
+                                                 message return_url {edit_p 1}
+                                             }]
+                
+            } elseif { $PasswordExpirationDays > 0
+                       && ($password_age_days eq "" || $password_age_days > $PasswordExpirationDays)
+                   } {
                 set message [_ acs-subsite.Password_regular_change_now]
                 set result(account_url) [export_vars -base "[subsite::get_element -element url]user/password-update" { return_url message }]
             } else {
@@ -1571,12 +1576,14 @@ ad_proc -private auth::validate_account_info {
 
     # TODO: When doing RBM's parameter, make sure that we still require both first_names and last_names, or none of them
     if { ([info exists user(first_names)] && $user(first_names) ne "") 
-	 && [string first "<" $user(first_names)] != -1 } {
+	 && [string first "<" $user(first_names)] != -1
+     } {
         set element_messages(first_names) [_ acs-subsite.lt_You_cant_have_a_lt_in]
     }
 
     if { ([info exists user(last_name)] && $user(last_name) ne "") 
-	 && [string first "<" $user(last_name)] != -1 } {
+	 && [string first "<" $user(last_name)] != -1
+     } {
         set element_messages(last_name) [_ acs-subsite.lt_You_cant_have_a_lt_in_1]
     }
 
@@ -1855,3 +1862,9 @@ ad_proc -private auth::user_info::GetUserInfo {
                 -operation GetUserInfo \
                 -call_args [list $username $parameters]]
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
