@@ -3,7 +3,7 @@ ad_library {
 
     @author Lars Pind (lars@collaobraid.biz)
     @creation-date 2003-05-14
-    @cvs-id $Id: authority-procs.tcl,v 1.28.8.3 2013/10/17 08:51:56 gustafn Exp $
+    @cvs-id $Id: authority-procs.tcl,v 1.29.2.2 2015/09/10 08:21:12 gustafn Exp $
 }
 
 namespace eval auth {}
@@ -326,8 +326,7 @@ ad_proc -public auth::authority::batch_sync {
         with_catch errmsg {
             array set doc_result [auth::sync::GetDocument -authority_id $authority_id]
         } {
-            global errorInfo
-            ns_log Error "Error getting sync document:\n$errorInfo"
+            ns_log Error "Error getting sync document:\n$::errorInfo"
             set doc_result(doc_status) failed_to_connect
             set doc_result(doc_message) $errmsg
         }
@@ -373,8 +372,7 @@ ad_proc -public auth::authority::batch_sync {
                         $ack_doc
                 }
             } {
-                global errorInfo
-                ns_log Error "Error processing sync document:\n$errorInfo"
+                ns_log Error "Error processing sync document:\n$::errorInfo"
                 set message "Error processing sync document: $errmsg"
             }
         } else {
@@ -564,3 +562,9 @@ ad_proc -public auth::authority::local {} {
 } {
     return [auth::authority::get_id -short_name "local"]
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
