@@ -3,7 +3,7 @@ ad_library {
 
     @author Lars Pind (lars@collaobraid.biz)
     @creation-date 2003-05-13
-    @cvs-id $Id: local-procs.tcl,v 1.37.6.1 2013/09/30 18:26:48 gustafn Exp $
+    @cvs-id $Id: local-procs.tcl,v 1.39.2.3 2015/10/20 08:19:13 gustafn Exp $
 }
 
 namespace eval auth {}
@@ -278,8 +278,7 @@ ad_proc -private auth::local::password::ChangePassword {
 
     if { [catch { ad_change_password $user_id $new_password } errmsg] } {
         set result(password_status) "change_error"
-        global errorInfo
-        ns_log Error "Error changing local password for username $username, user_id $user_id: \n$errorInfo"
+        ns_log Error "Error changing local password for username $username, user_id $user_id: \n$::errorInfo"
         return [array get result]
     }
 
@@ -311,8 +310,7 @@ ad_proc -private auth::local::password::ChangePassword {
             -subject $subject \
             -body $body
 	} {
-            global errorInfo
-            ns_log Error "Error sending out password changed notification to account owner with user_id $user(user_id), email $user(email): $errmsg\n$errorInfo"
+            ns_log Error "Error sending out password changed notification to account owner with user_id $user(user_id), email $user(email): $errmsg\n$::errorInfo"
 	}
     }
     
@@ -501,23 +499,30 @@ ad_proc -private auth::local::registration::Register {
 
     # LARS TODO: Move this out of the local driver and into the auth framework
     # Send password confirmation email to user
-    if { [set email_reg_confirm_p [parameter::get -parameter EmailRegistrationConfirmationToUserP -package_id [ad_conn subsite_id] -default 0]] != -1 } {
-	if { $generated_pwd_p || \
-		 [parameter::get -parameter RegistrationProvidesRandomPasswordP -package_id [ad_conn subsite_id] -default 0] || \
-		 $email_reg_confirm_p } {
-
+    if { [set email_reg_confirm_p [parameter::get \
+                                       -parameter EmailRegistrationConfirmationToUserP \
+                                       -package_id [ad_conn subsite_id] -default 1]] != 0
+     } {
+	if { $generated_pwd_p
+             || [parameter::get \
+                     -parameter RegistrationProvidesRandomPasswordP \
+                     -package_id [ad_conn subsite_id] -default 0]
+             || $email_reg_confirm_p
+         } {
 	    with_catch errmsg {
 		auth::password::email_password \
 		    -username $username \
 		    -authority_id $authority_id \
 		    -password $password \
-		    -from [parameter::get -parameter NewRegistrationEmailAddress -package_id [ad_conn subsite_id] -default [ad_system_owner]] \
+		    -from [parameter::get \
+                               -parameter NewRegistrationEmailAddress \
+                               -package_id [ad_conn subsite_id] \
+                               -default [ad_system_owner]] \
 		    -subject_msg_key "acs-subsite.email_subject_Registration_password" \
 		    -body_msg_key "acs-subsite.email_body_Registration_password" 
 	    } {
 		# We don't fail hard here, just log an error
-		global errorInfo
-		ns_log Error "Error sending registration confirmation to $email.\n$errorInfo"
+		ns_log Error "Error sending registration confirmation to $email.\n$::errorInfo"
 	    }
 	}
     }
@@ -547,8 +552,7 @@ ad_proc -private auth::local::registration::Register {
                 -body [lang::message::lookup $admin_locale acs-subsite.lt_first_names_last_name]
         } {
             # We don't fail hard here, just log an error
-            global errorInfo
-            ns_log Error "Error sending admin notification to $admin_email.\n$errorInfo"
+            ns_log Error "Error sending admin notification to $admin_email.\n$::errorInfo"
         }
     }
 
@@ -640,3 +644,9 @@ ad_proc -private auth::local::search::GetParameters {} {
     # No parameters
     return [list]
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
