@@ -3,7 +3,7 @@ ad_library {
 
     @author Peter Marklund
     @creation-date 21 August 2003
-    @cvs-id $Id: acs-authentication-procs.tcl,v 1.42.8.4 2014/08/18 09:23:46 gustafn Exp $
+    @cvs-id $Id: acs-authentication-procs.tcl,v 1.44.2.2 2015/09/10 08:21:13 gustafn Exp $
 }
 
 aa_register_case \
@@ -221,13 +221,13 @@ aa_register_case \
                 array set elm_msgs $user_info(element_messages)
 
                 if { [aa_true "element_message(email) exists" \
-			  [expr {[info exists elm_msgs(email)] && $elm_msgs(email) ne ""}]
+			  [expr {[info exists elm_msgs(email)] && $elm_msgs(email) ne ""}] ]} {
                     aa_log "element_message(email) = $elm_msgs(email)"
                 }
-                if { [aa_true "element_message(first_names) exists" [info exists elm_msgs(first_names)]
+                if { [aa_true "element_message(first_names) exists" [info exists elm_msgs(first_names)] ]} {
                     aa_log "element_message(first_names) = $elm_msgs(first_names)"
                 }
-                if { [aa_true "element_message(last_name) exists" [info exists elm_msgs(last_name)]
+                if { [aa_true "element_message(last_name) exists" [info exists elm_msgs(last_name)] ]} {
                     aa_log "element_message(last_name) = $elm_msgs(last_name)"
                 }
             }
@@ -356,10 +356,7 @@ aa_register_case  \
     Test the auth::password::change proc.
 } {
     aa_stub acs_mail_lite::send {
-	acs_mail_lite::send__arg_parser
-
-        global ns_sendmail_to
-        set ns_sendmail_to $to_addr
+        set ::ns_sendmail_to $to_addr
     }
 
     aa_run_with_teardown \
@@ -376,8 +373,7 @@ aa_register_case  \
                     -secret_answer "no_answer"]
             set user_id $user_info(user_id)
 
-            global ns_sendmail_to
-            set ns_sendmail_to {ns_sendmail_UNCALLED}
+            set ::ns_sendmail_to {ns_sendmail_UNCALLED}
 
             parameter::set_value -parameter EmailAccountOwnerOnPasswordChangeP  -package_id [ad_acs_kernel_id] -value 1
             aa_true "Send email" [parameter::get -parameter EmailAccountOwnerOnPasswordChangeP -package_id [ad_acs_kernel_id] -default 1]
@@ -394,8 +390,8 @@ aa_register_case  \
                 "ok"
             
             # Check that user gets email about changed password
-            aa_equals "Email sent to user" $ns_sendmail_to $email
-            set ns_sendmail_to {}
+            aa_equals "Email sent to user" $::ns_sendmail_to $email
+            set ::ns_sendmail_to {}
 
             # check that the new password is actually set correctly
             set password_correct_p [ad_check_password $user_id $new_password]
@@ -731,10 +727,7 @@ aa_register_case  \
     Test acs-kernel.EmailAccountOwnerOnPasswordChangeP parameter
 } {
     aa_stub acs_mail_lite::send {
-	acs_mail_lite::send__arg_parser
-
-        global ns_sendmail_to
-        set ns_sendmail_to $to_addr
+        set ::ns_sendmail_to $to_addr
     }
 
     aa_run_with_teardown \
@@ -742,8 +735,7 @@ aa_register_case  \
         -test_code {
             parameter::set_value -parameter EmailAccountOwnerOnPasswordChangeP -package_id [ad_acs_kernel_id] -value 1
             
-            global ns_sendmail_to
-            set ns_sendmail_to {}
+            set ::ns_sendmail_to {}
            
             # Create a dummy local user
             set username [ad_generate_random_string]
@@ -779,8 +771,8 @@ aa_register_case  \
             }
             
             # Check that we get email
-            aa_equals "Email sent to user" $ns_sendmail_to $email
-            set ns_sendmail_to {ns_sendmail_UNCALLED}
+            aa_equals "Email sent to user" $::ns_sendmail_to $email
+            set ::ns_sendmail_to {ns_sendmail_UNCALLED}
 
             # Set parameter to false
             parameter::set_value -parameter EmailAccountOwnerOnPasswordChangeP -package_id [ad_acs_kernel_id] -value 0
@@ -795,7 +787,7 @@ aa_register_case  \
             aa_equals "Password change OK" $result(password_status) "ok"
             
             # Check that we do not get an email
-            aa_equals "Email NOT sent to user" $ns_sendmail_to {ns_sendmail_UNCALLED}
+            aa_equals "Email NOT sent to user" $::ns_sendmail_to {ns_sendmail_UNCALLED}
 
             ad_parameter_cache -delete [ad_acs_kernel_id] EmailAccountOwnerOnPasswordChangeP
         }
@@ -827,3 +819,9 @@ ad_proc -private auth::test::get_password_vars {
 
     db_1row select_vars {} -column_array test_vars
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
