@@ -3,7 +3,13 @@ ad_library {
 
   @author Peter Marklund
   @creation-date 4:th of April 2003
-  @cvs-id $Id: aa-test-init.tcl,v 1.2 2003/08/15 14:48:30 peterm Exp $
+  @cvs-id $Id: aa-test-init.tcl,v 1.2.26.1 2015/09/10 08:21:13 gustafn Exp $
 }
 
 # LARS: Moved to aa-test-procs.tcl file. See comment there.
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
