@@ -1,4 +1,3 @@
-
 ##############################################################################
 #
 #   Copyright 2001, OpenACS, Peter Harper.
@@ -7,7 +6,6 @@
 #
 ##############################################################################
 
-
 ad_library {
     Procs to support the acs-automated-testing package.
 
@@ -16,7 +14,7 @@ ad_library {
     
     @author Peter Harper (peter.harper@open-msg.com)
     @creation-date 21 June 2001
-    @cvs-id $Id: aa-test-procs.tcl,v 1.38.6.5 2014/09/09 08:31:53 gustafn Exp $
+    @cvs-id $Id: aa-test-procs.tcl,v 1.40.2.3 2015/09/05 14:52:37 gustafn Exp $
 }
 
 # LARS: We do this here, because if we do it in the -init file, then we cannot register 
@@ -34,6 +32,61 @@ if { ![nsv_exists aa_test cases] } {
     }    
 }
 
+proc aa_proc_copy {proc_name_old proc_name_new {new_body ""}} {
+    #
+    # This is a single proc handling all stub management requirements
+    # from aa-testing. Since the arglist nsf::procs is not simply "args"
+    # (like for proc based ad_procs), but the real argument/parameter
+    # list, we address these differences here for all needed cases.
+    #
+    if {[info proc $proc_name_old] ne ""} {
+        #
+        # We copy a regular Tcl proc
+        #
+        set args {}
+        foreach arg [info args $proc_name_old] {
+            if { [info default $proc_name_old $arg default_value] } {
+                lappend args [list $arg $default_value]
+            } else {
+                lappend args $arg
+            }
+        }
+        set old_body [info body $proc_name_old]
+        if {$new_body eq ""} {
+            set new_body $old_body
+        }
+        set arg_parser "[namespace tail $proc_name_old]__arg_parser"
+        #
+        # In case a arg-parser was used in the old body, but is
+        # missing in the new version, add it automatically to the new
+        # body.
+        #
+        if {[string match *$arg_parser* $old_body]} {
+            if {![string match *$arg_parser* $new_body]} {
+                set new_body $arg_parser\n$new_body
+                #ns_log notice "... auto added arg_parser for '$proc_name_new' ====> new_body $new_body"
+            }
+        }
+        ::proc $proc_name_new $args $new_body
+    } elseif {$::acs::useNsfProc && [info commands $proc_name_old] ne ""} {
+        #
+        # We copy a nsf::proc
+        #
+        # Use an absolute name to reference to a nsf::proc
+        # unambiguously
+        #
+        set proc_name [namespace which $proc_name_old]
+        if {$new_body eq ""} {
+            set new_body [::nsf::cmd::info body $proc_name]
+        }
+        nsf::proc -ad $proc_name_new \
+            [::nsf::cmd::info parameter $proc_name] \
+            $new_body
+    } else {
+        error "no such proc $proc_name_old"
+    }
+}
+
 ad_proc -public aa_stub {
     proc_name
     new_body
@@ -58,21 +111,11 @@ ad_proc -public aa_stub {
         #
         if {$proc_name ni $aa_stub_names} {
             lappend aa_stub_names $proc_name
-            proc ${proc_name}_unstubbed [info args $proc_name] [info body $proc_name]
+            aa_proc_copy $proc_name ${proc_name}_unstubbed
         }
         set aa_stub_sequence($proc_name) 1
         
-        set args [list]
-        set counter 0
-        foreach arg [info args $proc_name] {
-            if { [info default $proc_name $arg default_value] } {
-                lappend args [list $arg $default_value]
-            } else {
-                lappend args $arg
-            }
-        }
-
-        proc $proc_name $args "
+        aa_proc_copy $proc_name $proc_name "
       global aa_stub_sequence
       global aa_testcase_id
       set sequence_id \$aa_stub_sequence\($proc_name\)
@@ -85,9 +128,9 @@ ad_proc -public aa_stub {
         # File wide stub.
         #
         if {![nsv_exists aa_file_wide_stubs [info script]]} {
-            nsv_set aa_file_wide_stubs "[info script]" {}
+            nsv_set aa_file_wide_stubs [info script] {}
         }
-        nsv_lappend aa_file_wide_stubs "[info script]" [list $proc_name $new_body]
+        nsv_lappend aa_file_wide_stubs [info script] [list $proc_name $new_body]
     }
 }
 
@@ -97,17 +140,7 @@ ad_proc -public aa_unstub {
     @author Peter Harper
     @creation-date 24 July 2001
 } {
-    set args [list]
-    set counter 0
-    foreach arg [info args $proc_name] {
-        if { [info default $proc_name $arg default_value] } {
-            lappend args [list $arg $default_value]
-        } else {
-            lappend args $arg
-        }
-    }
-
-    proc $proc_name $args [info body ${proc_name}_unstubbed]
+    aa_proc_copy ${proc_name}_unstubbed $proc_name
     return
 }
 
@@ -302,7 +335,7 @@ ad_proc -public aa_register_case {
 } {
     Registers a testcase with the acs-automated-testing system.  Whenever possible, cases that fail to register are replaced with 'metatest' log cases, so that the register-time errors are visible at test time.
 
-    See <a href="/doc/tutorial-debug.html">the tutorial</a> for examples.
+    See <a href="/doc/tutorial-debug">the tutorial</a> for examples.
 
     @param libraries A list of keywords of additional code modules to load.  The entire test case will fail if any package is missing.  Currently includes <b>tclwebtest</b>.
 
@@ -316,14 +349,14 @@ ad_proc -public aa_register_case {
     <li><b>security_risk</b>: May introduce a security risk.
     <li><b>populator</b>: Creates sample data for future use.
     <li><b>production_safe</b>: Can be used on a live production site, ie for sanity checking or keepalive purposes.  Implies: no risk of adding or deleting data; no risk of crashing; minimal cpu/db/net load.
-</ul>
+    </ul>
     @param error_level Force all test failures to this error level.  One of 
-<ul>
-<li><b>notice</b>: Informative.  Does not indicate an error.
-<li><b>warning</b>: May indicate an problem.  Example: a non-critical bug repro case that hasn't been fixed.
-<li><b>error</b>: normal error
-<li><b>metatest</b>: Indicates a problem with the test framework, execution, or reporting.  Suggests that current test results may be invalid.  Use this for test cases that test the tests.  Also used, automatically, for errors sourcing test cases.  
-</ul>
+    <ul>
+    <li><b>notice</b>: Informative.  Does not indicate an error.
+    <li><b>warning</b>: May indicate an problem.  Example: a non-critical bug repro case that hasn't been fixed.
+    <li><b>error</b>: normal error
+    <li><b>metatest</b>: Indicates a problem with the test framework, execution, or reporting.  Suggests that current test results may be invalid.  Use this for test cases that test the tests.  Also used, automatically, for errors sourcing test cases.  
+    </ul>
     @param bugs A list of integers correspending to openacs.org bug numbers which relate to this test case.
     @param procs A list of OpenACS procs which are tested by this case.
 
@@ -480,8 +513,7 @@ ad_proc -public aa_register_case {
       aa_log \"Running testcase body \$body_count\"
       set catch_val \[catch \"eval \[list \$testcase_body\]\" msg\]
       if {\$catch_val != 0 && \$catch_val != 2} {
-        global errorInfo
-          aa_log_result \"fail\" \"$testcase_id (body \$body_count): Error during execution: \${msg}, stack trace: \n\$errorInfo\"
+          aa_log_result \"fail\" \"$testcase_id (body \$body_count): Error during execution: \${msg}, stack trace: \n\$::errorInfo\"
       }
       incr body_count
     }
@@ -943,23 +975,20 @@ ad_proc -public aa_run_with_teardown {
             aa_execute_rollback_tests
 
             if { \$errmsg ne {} && \$errmsg ne \"rollback tests\"\ } {
-                global errorInfo
-                error \"\$errmsg \n\n \$errorInfo\"
+                error \"\$errmsg \n\n \$::errorInfo\"
             }
         "
     }
 
     # Testing
     set setup_error_p [catch {uplevel $test_code} setup_error]
-    global errorInfo
-    set setup_error_stack $errorInfo
+    set setup_error_stack $::errorInfo
 
     # Teardown
     set teardown_error_p 0
     if { $teardown_code ne "" } {
         set teardown_error_p [catch {uplevel $teardown_code} teardown_error]
-        global errorInfo
-        set teardown_error_stack $errorInfo
+        set teardown_error_stack $::errorInfo
     }
 
     # Provide complete error message and stack trace
@@ -1103,10 +1132,11 @@ ad_proc -public aa_test::parse_install_file {
     }
 
     # TODO: Not working
-    set service(admin_login_url) "$service(url)register/?[export_vars { { email $service(adminemail) } { password $service(adminpassword) } }]"
-
+    set service(admin_login_url) [export_vars -base $service(url)register/ {
+        { email $service(adminemail) }
+        { password $service(adminpassword) }
+    }]
     set service(auto_test_url) "$service(url)test/admin"
-
     set service(rebuild_cmd) "sh [file join $service(script_path) recreate.sh]"
 }
 
@@ -1125,7 +1155,7 @@ ad_proc -private aa_test::get_test_doc {} {
 
     db_foreach result_counts {
         select result,
-               count(*) as result_count
+        count(*) as result_count
         from aa_test_results
         group by result
     } {
@@ -1138,7 +1168,7 @@ ad_proc -private aa_test::get_test_doc {} {
 
     db_foreach failure_counts {
         select testcase_id,
-               count(*) as failure_count
+        count(*) as failure_count
         from aa_test_results
         where result = 'fail'
         group by testcase_id
@@ -1173,7 +1203,7 @@ ad_proc -private aa_test::write_test_file {} {
         set file_path "$report_dir/${hostname}-${server}-testreport.xml"
 
         set xml_doc [get_test_doc]
-    
+        
         if { [catch {template::util::write_file $file_path $xml_doc} errmsg] } {
             ns_log Error "Failed to write xml test report to path $file_path - $errmsg"
         }
@@ -1218,15 +1248,15 @@ ad_proc -public aa_test::parse_test_file {
 ad_proc -public aa_get_first_url {
     {-package_key:required}
 } {
-  Procedure for geting the url of a mounted package with the package_key. It uses the first instance that it founds. This is usefull for tclwebtest tests.
+    Procedure for geting the url of a mounted package with the package_key. It uses the first instance that it founds. This is usefull for tclwebtest tests.
 } {
 
     if {![db_0or1row first_url { *SQL* }]} {
         site_node::instantiate_and_mount -package_key $package_key
-	db_1row first_url {*SQL*}
-}
+        db_1row first_url {*SQL*}
+    }
 
- return $url
+    return $url
 
 }
 
@@ -1242,9 +1272,9 @@ ad_proc -public aa_display_result {
     @param explanation An explanation accompanying the response.
 } {
     if {$response} {
-	aa_log_result "pass" $explanation
+        aa_log_result "pass" $explanation
     } else {
-	aa_log_result "fail" $explanation
+        aa_log_result "fail" $explanation
     }
 }
 
@@ -1264,7 +1294,7 @@ ad_proc -public aa_selenium_init {} {
         # request.
         return $_acs_automated_testing_selenium_init
     }
-            
+    
     set server_url [parameter::get_from_package_key \
                         -package_key acs-automated-testing \
                         -parameter "SeleniumRcServer" \
@@ -1294,3 +1324,10 @@ aa_register_init_class \
     "Init Class for Selenium Remote Control" \
     {aa_selenium_init} \
     {catch {Se stop} errmsg}
+
+#
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
