@@ -3,7 +3,7 @@ ad_library {
 
     @author Peter Marklund
     @creation-date 31 March 2004
-    @cvs-id $Id: tclwebtest-procs.tcl,v 1.7.10.2 2013/10/13 10:18:26 gustafn Exp $
+    @cvs-id $Id: tclwebtest-procs.tcl,v 1.8.2.2 2015/09/10 08:21:14 gustafn Exp $
 }
 
 namespace eval twt {}
@@ -57,8 +57,7 @@ ad_proc twt::do_request { page_url } {
         # $retry_max times. Propagate the error while retaining the stack trace
         aa_log "twt::do_request failed with error=\"$errmsg\" response_url=\"[tclwebtest::response url]\". See error log for the HTML response body"
         ns_log Error "twt::do_request failed with error=\"$errmsg\" response_url=\"[tclwebtest::response url]\" response_body=\"[tclwebtest::response body]\""
-        global errorInfo
-        error $errmsg $errorInfo
+        error $errmsg $::errorInfo
     }
 }
 
@@ -208,3 +207,9 @@ ad_proc twt::user::logout {} {
 } {
     twt::do_request "[twt::server_url]/register/logout"
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
