@@ -1,10 +1,10 @@
 ad_page_contract {
-  @cvs-id $Id: clear.tcl,v 1.2.26.2 2014/08/25 08:17:04 gustafn Exp $
+  @cvs-id $Id: clear.tcl,v 1.4.2.1 2015/09/10 08:21:14 gustafn Exp $
 } {
   {package_key ""}
   {category:aa_test_category ""}
   {view_by:aa_test_view_by "package"}
-  {testcase_id ""}
+  {testcase_id:naturalnum,notnull ""}
   {quiet:boolean "0"}
 } -properties {
 }
@@ -17,3 +17,9 @@ db_dml delete_testcase_tests_sql $sql
 ad_returnredirect "index"
 
 ad_returnredirect "index?by_package_key=$package_key&by_category=$category&view_by=$view_by&quiet=$quiet"
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
