@@ -1,7 +1,7 @@
 ad_page_contract {
-  @cvs-id $Id: component.tcl,v 1.3.22.2 2014/08/25 08:17:04 gustafn Exp $
+  @cvs-id $Id: component.tcl,v 1.5.2.1 2015/09/10 08:21:14 gustafn Exp $
 } {
-  component_id:notnull
+  component_id:naturalnum,notnull
   package_key:nohtml
 } -properties {
   title:onevalue
@@ -24,3 +24,9 @@ foreach component [nsv_get aa_test components] {
 }
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
