@@ -11,7 +11,7 @@ ad_page_contract {
     @author Bryan Quinn (bquinn@arsdigita.com)
     @author Richard Li (richardl@arsdigita.com)
     @creation-date Mon Oct  9 15:19:31 2000
-    @cvs-id $Id: index.tcl,v 1.28.2.2 2013/10/17 08:54:59 gustafn Exp $
+    @cvs-id $Id: index.tcl,v 1.30.2.3 2015/09/10 08:21:15 gustafn Exp $
 } {
 
 }
@@ -53,7 +53,7 @@ a suite of fully-integrated enterprise-class solutions
 for collaborative commerce.
 This is the OpenACS Installer which performs all the steps necessary
 to get the OpenACS Community System running on your server.<p>
-Please read the <a href=\"/doc/release-notes.html\">Release Notes</a> 
+Please read the <a href=\"/doc/release-notes\">Release Notes</a> 
 before proceeding to better understand what is contained in this release.
 
 "
@@ -77,10 +77,10 @@ application after the basic OpenACS tookit has been installed.
 "
 
     if { $acs_application(home) ne "" } {
-        append body "<p>
+        append body [subst {<p>
 For more information about the $acs_application(pretty_name) application visit the
-<a href=\"$acs_application(home)\">$acs_application(pretty_name) home page</a>
-"
+<a href="[ns_quotehtml $acs_application(home)]">$acs_application(pretty_name) home page</a>
+	}
     }
 } else {
     set acs_application(name) openacs
@@ -112,6 +112,11 @@ Once you're sure everything is installed and configured correctly, restart AOLse
     return
 } 
 
+#
+# Unset array errors, in case it exists
+#
+if {[array exists errors]} {array unset errors}
+
 # Perform database-specific checks
 db_installer_checks errors error_p
 
@@ -195,8 +200,8 @@ the user executing the web server, normally <code>nsadmin</code>, and the owner
 on this directory.  You can correct this by running the following script as root.
 To give another user access to the files, add them to <code>web</code> group.
 <blockquote><pre>
-groupadd web
-chown -R nsadmin:web $::acs::rootdir
+groupadd nsadmin
+chown -R nsadmin:nsadmin $::acs::rootdir
 chmod -R ug+rw $::acs::rootdir
 </pre></blockquote>
 </strong></p>"
@@ -211,8 +216,8 @@ if { ![file writable [file join $::acs::rootdir packages]] } {
     script as root.
     To give another user access to the files, add them to <code>web</code> group.
     <blockquote><pre>
-groupadd web
-chown -R nsadmin:web $::acs::rootdir/packages
+groupadd nsadmin
+chown -R nsadmin:nsadmin $::acs::rootdir/packages
 chmod -R ug+rw $::acs::rootdir/packages
     </pre></blockquote></strong></p>"
     set error_p 1
@@ -388,3 +393,9 @@ The email address to send New registration notifications.<br><br>
 }
 
 install_return 200 "Welcome" $body
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
