@@ -4,7 +4,7 @@ ad_library {
 
     @creation-date 4 Apr 2001
     @author Don Baccus (dhogaza@pacifier.com
-    @cvs-id $Id: 10-utilities-procs.tcl,v 1.9 2013/04/04 08:33:56 gustafn Exp $
+    @cvs-id $Id: 10-utilities-procs.tcl,v 1.9.4.1 2015/09/10 08:21:16 gustafn Exp $
 }
 
 ad_proc -public ad_find_all_files {
@@ -62,3 +62,9 @@ ad_proc -public ad_find_all_files {
     }
     return $files
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
