@@ -4,7 +4,7 @@ ad_library {
 
     @creation-date 26 May 2000
     @author Jon Salz [jsalz@arsdigita.com]
-    @cvs-id $Id: 30-apm-load-procs.tcl,v 1.41.2.12 2014/08/25 08:45:02 gustafn Exp $
+    @cvs-id $Id: 30-apm-load-procs.tcl,v 1.43.2.2 2015/11/30 12:57:42 gustafn Exp $
 }
 
 ad_proc apm_first_time_loading_p {} { 
@@ -322,7 +322,7 @@ ad_proc -private apm_guess_db_type { package_key path } {
             if {$db_dir eq "common"} {
                 return ""
             }
-            foreach known_database_type [db_known_database_types] {
+            foreach known_database_type $::acs::known_database_types {
                 if {[lindex $known_database_type 0] eq $db_dir} {
                     return $db_dir
                 }
@@ -332,7 +332,7 @@ ad_proc -private apm_guess_db_type { package_key path } {
     }
 
     set file_name [file tail $path]
-    foreach known_database_type [nsv_get ad_known_database_types .] {
+    foreach known_database_type $::acs::known_database_types {
         if { [regexp -- "\-[lindex $known_database_type 0]\.(xql|tcl|sqlj)\$" $file_name match] } {
             return [lindex $known_database_type 0]
         }
@@ -602,13 +602,17 @@ ad_proc apm_bootstrap_upgrade {
     acs-bootstrap-installer package (rather than a full tar file
     install as in eralier versions). 
 
-    Caveat: don't modify these files in your local installation, addin
+    Caveat: don't modify these files in your local installation, adding
     extra files to $::acs::rootdir/tcl is fine.
 } {
     set source $::acs::rootdir/packages/acs-bootstrap-installer/installer/tcl
     foreach file [glob -nocomplain $source/*tcl] {
         file copy -force $file $::acs::rootdir/tcl
     }
+    set source $::acs::rootdir/packages/acs-bootstrap-installer/installer/www
+    foreach file [glob -nocomplain $source/*tcl $source/*adp] {
+        file copy -force $file $::acs::rootdir/www
+    }
 }
 
 #
