@@ -4,7 +4,7 @@
 -- Copyright (C) 1999-2000 ArsDigita Corporation
 -- Author: Karl Goldstein (karlg@arsdigita.com)
 
--- $Id: content-create.sql,v 1.60.2.2 2013/12/25 16:10:31 gustafn Exp $
+-- $Id: content-create.sql,v 1.63.2.1 2015/08/16 22:47:36 gustafn Exp $
 
 -- This is free software distributed under the terms of the GNU Public
 -- License.  Full text of the license is available from the GNU Project:
@@ -400,7 +400,8 @@ create table cr_child_rels (
 
 create index cr_child_rels_by_parent on cr_child_rels(parent_id);
 create unique index cr_child_rels_unq_id on cr_child_rels(parent_id, child_id);
-CREATE UNIQUE INDEX CR_CHILD_RELS_kids_IDx ON CR_CHILD_RELS(CHILD_ID);
+create unique index cr_child_rels_child_id_idx on cr_child_rels(child_id);
+
 
 comment on table cr_child_rels is '
   Provides for richer parent-child relationships than the simple
@@ -506,14 +507,11 @@ comment on column cr_revisions.nls_language  is '
   for multi-lingual searching in Intermedia.
 ';
 
--- postgresql RI bug causes multiple failures with regards to deletion of
--- content_revisions (DanW dcwickstrom@earthlink.net)
+alter table cr_items add constraint cr_items_live_revision_fk 
+      foreign key (live_revision) references cr_revisions(revision_id) on delete set null;
 
--- alter table cr_items add constraint cr_items_live_fk 
---   foreign key (live_revision) references cr_revisions(revision_id);
-
--- alter table cr_items add constraint cr_items_latest_fk 
---   foreign key (latest_revision) references cr_revisions(revision_id);
+alter table cr_items add constraint cr_items_latest_revision_fk 
+     foreign key (latest_revision) references cr_revisions(revision_id) on delete set null;
 
 
 
@@ -521,180 +519,174 @@ comment on column cr_revisions.nls_language  is '
 --
 -- procedure cr_revision_del_ri_tr/0
 --
-CREATE OR REPLACE FUNCTION cr_revision_del_ri_tr(
-
-) RETURNS trigger AS $$
-DECLARE
-        dummy           integer;
-        v_latest        integer;
-        v_live          integer;
-BEGIN
-        select 1 into dummy
-        from 
-          cr_revisions           
-        where 
-          revision_id = old.live_revision;
-        
-        if FOUND then
-          raise EXCEPTION 'Referential Integrity: live_revision still exists: %', old.live_revision;
-        end if;
-        
-        select 1 into dummy
-        from 
-          cr_revisions 
-        where 
-          revision_id = old.latest_revision;
-        
-        if FOUND then
-          raise EXCEPTION 'Referential Integrity: latest_revision still exists: %', old.latest_revision;
-        end if;
-        
-        return old;
-END;
-$$ LANGUAGE plpgsql;
+-- CREATE OR REPLACE FUNCTION cr_revision_del_ri_tr(
+-- ) RETURNS trigger AS $$
+-- DECLARE
+--         dummy           integer;
+--         v_latest        integer;
+--         v_live          integer;
+-- BEGIN
+--         select 1 into dummy
+--         from 
+--           cr_revisions           
+--         where 
+--           revision_id = old.live_revision;
+--         
+--         if FOUND then
+--           raise EXCEPTION 'Referential Integrity: live_revision still exists: %', old.live_revision;
+--         end if;
+--         
+--         select 1 into dummy
+--         from 
+--           cr_revisions 
+--         where 
+--           revision_id = old.latest_revision;
+--         
+--         if FOUND then
+--           raise EXCEPTION 'Referential Integrity: latest_revision still exists: %', old.latest_revision;
+--         end if;
+--         
+--         return old;
+-- END;
+-- $$ LANGUAGE plpgsql;
 
 
 
 --
 -- procedure cr_revision_ins_ri_tr/0
 --
-CREATE OR REPLACE FUNCTION cr_revision_ins_ri_tr(
-
-) RETURNS trigger AS $$
-DECLARE
-        dummy           integer;
-        v_latest        integer;
-        v_live          integer;
-BEGIN
-        select 1 into dummy
-        from 
-          cr_revisions           
-        where 
-          revision_id = new.live_revision;
-        
-        if NOT FOUND and new.live_revision is NOT NULL then
-          raise EXCEPTION 'Referential Integrity: live_revision does not exist: %', new.live_revision;
-        end if;
-        
-        select 1 into dummy
-        from 
-          cr_revisions 
-        where 
-          revision_id = new.latest_revision;
-        
-        if NOT FOUND and new.latest_revision is NOT NULL then
-          raise EXCEPTION 'Referential Integrity: latest_revision does not exist: %', new.latest_revision;
-        end if;
-
-        return new;
-END;
-$$ LANGUAGE plpgsql;
+-- CREATE OR REPLACE FUNCTION cr_revision_ins_ri_tr(
+-- ) RETURNS trigger AS $$
+-- DECLARE
+--         dummy           integer;
+--         v_latest        integer;
+--         v_live          integer;
+-- BEGIN
+--         select 1 into dummy
+--         from 
+--           cr_revisions           
+--         where 
+--           revision_id = new.live_revision;
+--         
+--         if NOT FOUND and new.live_revision is NOT NULL then
+--           raise EXCEPTION 'Referential Integrity: live_revision does not exist: %', new.live_revision;
+--         end if;
+--         
+--         select 1 into dummy
+--         from 
+--           cr_revisions 
+--         where 
+--           revision_id = new.latest_revision;
+--         
+--         if NOT FOUND and new.latest_revision is NOT NULL then
+--           raise EXCEPTION 'Referential Integrity: latest_revision does not exist: %', new.latest_revision;
+--         end if;
+-- 
+--         return new;
+-- END;
+-- $$ LANGUAGE plpgsql;
 
 
 
 --
 -- procedure cr_revision_up_ri_tr/0
 --
-CREATE OR REPLACE FUNCTION cr_revision_up_ri_tr(
-
-) RETURNS trigger AS $$
-DECLARE
-        dummy           integer;
-        v_latest        integer;
-        v_live          integer;
-BEGIN
-        select 1 into dummy
-        from 
-          cr_revisions           
-        where 
-          revision_id = new.live_revision;
-        
-        if NOT FOUND and new.live_revision <> old.live_revision and new.live_revision is NOT NULL then
-          raise EXCEPTION 'Referential Integrity: live_revision does not exist: %', new.live_revision;
-        end if;
-        
-        select 1 into dummy
-        from 
-          cr_revisions 
-        where 
-          revision_id = new.latest_revision;
-        
-        if NOT FOUND and new.latest_revision <> old.latest_revision and new.latest_revision is NOT NULL then
-          raise EXCEPTION 'Referential Integrity: latest_revision does not exist: %', new.latest_revision;
-        end if;
-        
-        return new;
-END;
-$$ LANGUAGE plpgsql;
+-- CREATE OR REPLACE FUNCTION cr_revision_up_ri_tr(
+-- ) RETURNS trigger AS $$
+-- DECLARE
+--         dummy           integer;
+--         v_latest        integer;
+--         v_live          integer;
+-- BEGIN
+--         select 1 into dummy
+--         from 
+--           cr_revisions           
+--         where 
+--           revision_id = new.live_revision;
+--         
+--         if NOT FOUND and new.live_revision <> old.live_revision and new.live_revision is NOT NULL then
+--           raise EXCEPTION 'Referential Integrity: live_revision does not exist: %', new.live_revision;
+--         end if;
+--         
+--         select 1 into dummy
+--         from 
+--           cr_revisions 
+--         where 
+--           revision_id = new.latest_revision;
+--         
+--         if NOT FOUND and new.latest_revision <> old.latest_revision and new.latest_revision is NOT NULL then
+--           raise EXCEPTION 'Referential Integrity: latest_revision does not exist: %', new.latest_revision;
+--         end if;
+--         
+--         return new;
+-- END;
+-- $$ LANGUAGE plpgsql;
 
 
 
 --
 -- procedure cr_revision_del_rev_ri_tr/0
 --
-CREATE OR REPLACE FUNCTION cr_revision_del_rev_ri_tr(
-
-) RETURNS trigger AS $$
-DECLARE
-        dummy           integer;
-BEGIN
-        select 1 into dummy
-        from 
-          cr_items
-        where 
-          item_id = old.item_id
-        and
-          live_revision = old.revision_id;
-        
-        if FOUND then
-          raise EXCEPTION 'Referential Integrity: attempting to delete live_revision: %', old.revision_id;
-        end if;
-        
-        select 1 into dummy
-        from 
-          cr_items
-        where 
-          item_id = old.item_id
-        and
-          latest_revision = old.revision_id;
-        
-        if FOUND then
-          raise EXCEPTION 'Referential Integrity: attempting to delete latest_revision: %', old.revision_id;
-        end if;
-        
-        return old;
-END;
-$$ LANGUAGE plpgsql;
+-- CREATE OR REPLACE FUNCTION cr_revision_del_rev_ri_tr(
+-- ) RETURNS trigger AS $$
+-- DECLARE
+--         dummy           integer;
+-- BEGIN
+--         select 1 into dummy
+--         from 
+--           cr_items
+--         where 
+--           item_id = old.item_id
+--         and
+--           live_revision = old.revision_id;
+--         
+--         if FOUND then
+--           raise EXCEPTION 'Referential Integrity: attempting to delete live_revision: %', old.revision_id;
+--         end if;
+--         
+--         select 1 into dummy
+--         from 
+--           cr_items
+--         where 
+--           item_id = old.item_id
+--         and
+--           latest_revision = old.revision_id;
+--         
+--         if FOUND then
+--           raise EXCEPTION 'Referential Integrity: attempting to delete latest_revision: %', old.revision_id;
+--         end if;
+--         
+--         return old;
+-- END;
+-- $$ LANGUAGE plpgsql;
 
 
 -- reimplementation of RI triggers. (DanW dcwickstrom@earthlink.net)
 
-create trigger cr_revision_del_ri_tr 
-after delete on cr_items
-for each row execute procedure cr_revision_del_ri_tr();
+-- create trigger cr_revision_del_ri_tr 
+-- after delete on cr_items
+-- for each row execute procedure cr_revision_del_ri_tr();
 
-create trigger cr_revision_up_ri_tr 
-after update on cr_items
-for each row execute procedure cr_revision_up_ri_tr();
+-- create trigger cr_revision_up_ri_tr 
+-- after update on cr_items
+-- for each row execute procedure cr_revision_up_ri_tr();
+
+-- create trigger cr_revision_ins_ri_tr 
+-- after insert on cr_items
+-- for each row execute procedure cr_revision_ins_ri_tr();
+
+-- create trigger cr_revision_del_rev_ri_tr 
+-- after delete on cr_revisions
+-- for each row execute procedure cr_revision_del_rev_ri_tr();
 
-create trigger cr_revision_ins_ri_tr 
-after insert on cr_items
-for each row execute procedure cr_revision_ins_ri_tr();
 
-create trigger cr_revision_del_rev_ri_tr 
-after delete on cr_revisions
-for each row execute procedure cr_revision_del_rev_ri_tr();
 
 -- (DanW - OpenACS) Added cleanup trigger to log file items that need 
 -- to be cleaned up from the CR.
-
-
-
 --
 -- procedure cr_cleanup_cr_files_del_tr/0
 --
 CREATE OR REPLACE FUNCTION cr_cleanup_cr_files_del_tr(
-
 ) RETURNS trigger AS $$
 DECLARE
         
@@ -730,10 +722,6 @@ comment on column cr_revision_attributes.attributes is '
 ';
 
 
--- create global temporary table cr_content_text (
---     revision_id        integer primary key,
---     content            CLOB
--- ) on commit delete rows;
 
 create table cr_content_text (
     revision_id        integer 
@@ -753,11 +741,11 @@ comment on table cr_content_text is '
 
 create table cr_item_publish_audit (
   item_id            integer 
-                     constraint cr_item_publish_audit_item_fk references cr_items,
+                     constraint cr_item_publish_audit_item_fk references cr_items (item_id) on delete cascade,
   old_revision       integer
-                     constraint cr_item_publish_audit_orev_fk references cr_revisions (revision_id),
+                     constraint cr_item_publish_audit_orev_fk references cr_revisions (revision_id) on delete cascade,
   new_revision       integer
-                     constraint cr_item_publish_audit_nrev_fk references cr_revisions (revision_id),
+                     constraint cr_item_publish_audit_nrev_fk references cr_revisions (revision_id) on delete cascade,
   old_status         varchar(40),
   new_status         varchar(40),
   publish_date       timestamptz
@@ -777,7 +765,7 @@ comment on table cr_item_publish_audit is '
 create table cr_release_periods (
   item_id          integer
                    constraint cr_release_periods_item_id_fk
-		   references cr_items
+		   references cr_items on delete cascade
                    constraint cr_release_periods_item_id_pk
 		   primary key,
   start_when	   timestamptz default current_timestamp,
@@ -926,7 +914,7 @@ comment on column cr_type_template_map.use_context is '
 create table cr_item_template_map (
   item_id          integer
                    constraint cr_item_template_map_item_fk
-                   references cr_items
+                   references cr_items (item_id) on delete cascade
                    constraint cr_item_template_map_item_nn
                    not null,
   template_id      integer
@@ -1164,7 +1152,7 @@ comment on column cr_keywords.description is '
 create table cr_item_keyword_map (
   item_id          integer
                    constraint cr_item_keyword_map_item_id_fk
-                   references cr_items
+                   references cr_items (item_id) on delete cascade
                    constraint cr_item_keyword_map_item_id_nn
                    not null,
   keyword_id       integer
