@@ -4,7 +4,7 @@
 -- Copyright (C) 1999-2000 ArsDigita Corporation
 -- Author: Karl Goldstein (karlg@arsdigita.com)
 
--- $Id: content-item.sql,v 1.70.2.2 2014/09/13 11:09:29 gustafn Exp $
+-- $Id: content-item.sql,v 1.72.2.2 2015/09/25 10:45:05 gustafn Exp $
 
 -- This is free software distributed under the terms of the GNU Public
 -- License.  Full text of the license is available from the GNU Project:
@@ -52,13 +52,8 @@ $$ LANGUAGE plpgsql stable;
 -- new 19 param version of content_item__new (now its 20 with package_id)
 
 
--- old define_function_args('content_item__new','name,parent_id,item_id,locale,creation_date;now,creation_user,context_id,creation_ip,item_subtype;content_item,content_type;content_revision,title,description,mime_type;text/plain,nls_language,text,data,relation_tag,is_live;f,storage_type;null,package_id')
--- new
 select define_function_args('content_item__new','name,parent_id;null,item_id;null,locale;null,creation_date;now,creation_user;null,context_id;null,creation_ip;null,item_subtype;content_item,content_type;content_revision,title;null,description;null,mime_type;text/plain,nls_language;null,text;null,data;null,relation_tag;null,is_live;f,storage_type;null,package_id;null');
 
-
-
-
 --
 -- procedure content_item__new/20
 --
@@ -1057,9 +1052,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+
 select define_function_args('content_item__is_published','item_id');
-
-
 --
 -- procedure content_item__is_published/1
 --
@@ -1083,9 +1077,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable;
 
+
 select define_function_args('content_item__is_publishable','item_id');
-
-
 --
 -- procedure content_item__is_publishable/1
 --
@@ -1205,9 +1198,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable;
 
+
 select define_function_args('content_item__is_valid_child','item_id,content_type,relation_tag');
-
-
 --
 -- procedure content_item__is_valid_child/3
 --
@@ -1337,18 +1329,22 @@ END;
 $$ LANGUAGE plpgsql stable;
 
 
-/* delete a content item
- 1) delete all associated workflows
- 2) delete all symlinks associated with this object
- 3) delete any revisions for this item
- 4) unregister template relations
- 5) delete all permissions associated with this item
- 6) delete keyword associations
- 7) delete all associated comments */
+--
+-- Delete a content item
+--
+-- Technically, the following steps are necessary, some of these are
+-- achieved via cascading operations:
+--
+-- 1) delete all associated workflows
+-- 2) delete all symlinks associated with this object
+-- 3) delete any revisions for this item
+-- 4) unregister template relations
+-- 5) delete all permissions associated with this item
+-- 6) delete keyword associations
+-- 7) delete all associated comments
+
 
 select define_function_args('content_item__del','item_id');
-
-
 --
 -- procedure content_item__del/1
 --
@@ -1356,120 +1352,77 @@ CREATE OR REPLACE FUNCTION content_item__del(
    delete__item_id integer
 ) RETURNS integer AS $$
 DECLARE
-  -- v_wf_cases_val                 record;
   v_symlink_val                  record;
   v_revision_val                 record;
   v_rel_val                      record;
 BEGIN
-
-  -- Removed this as having workflow stuff in the CR is just plain wrong.
-  -- DanW, Aug 25th, 2001.
-
-  --   raise NOTICE 'Deleting associated workflows...';
-  -- 1) delete all workflow cases associated with this item
-  --   for v_wf_cases_val in select
-  --                           case_id
-  --                         from
-  --                           wf_cases
-  --                         where
-  --                           object_id = delete__item_id 
-  --   LOOP
-  --     PERFORM workflow_case__delete(v_wf_cases_val.case_id);
-  --   end loop;
-
-  -- 2) delete all symlinks to this item
-  for v_symlink_val in select 
-                         symlink_id
-                       from 
-                         cr_symlinks
-                       where 
-                         target_id = delete__item_id 
+  --
+  -- Delete all symlinks to this item
+  --
+  for v_symlink_val in select symlink_id
+                       from   cr_symlinks
+                       where  target_id = delete__item_id 
   LOOP
     PERFORM content_symlink__delete(v_symlink_val.symlink_id);
   end loop;
 
-  delete from cr_release_periods
-    where item_id = delete__item_id;
-
-  update cr_items set live_revision = null, latest_revision = null where item_id = delete__item_id;
-
-  -- 3) delete all revisions of this item
-  delete from cr_item_publish_audit
-    where item_id = delete__item_id;
-
-  for v_revision_val in select
-                          revision_id 
-                        from
-                          cr_revisions
-                        where
-                          item_id = delete__item_id 
+  --
+  -- Delete all revisions of this item
+  --
+  -- The following loop could be dropped / replaced by a cascade
+  -- operation, when proper foreign keys are used along the
+  -- inheritence path.
+  --
+  for v_revision_val in select revision_id 
+                        from   cr_revisions
+                        where  item_id = delete__item_id 
   LOOP
     PERFORM acs_object__delete(v_revision_val.revision_id);
   end loop;
-  
-  -- 4) unregister all templates to this item
-  delete from cr_item_template_map
-    where item_id = delete__item_id; 
 
+  --
   -- Delete all relations on this item
-  for v_rel_val in select
-                     rel_id
-                   from
-                     cr_item_rels
-                   where
-                     item_id = delete__item_id
-                   or
-                     related_object_id = delete__item_id 
+  --
+  for v_rel_val in select rel_id
+                   from   cr_item_rels
+                   where  item_id = delete__item_id
+                   or     related_object_id = delete__item_id 
   LOOP
     PERFORM acs_rel__delete(v_rel_val.rel_id);
   end loop;  
 
-  for v_rel_val in select
-                     rel_id
-                   from
-                     cr_child_rels
-                   where
-                     child_id = delete__item_id 
+  for v_rel_val in select rel_id
+                   from   cr_child_rels
+                   where  child_id = delete__item_id 
   LOOP
     PERFORM acs_rel__delete(v_rel_val.rel_id);
   end loop;  
 
-  for v_rel_val in select
-                     rel_id, child_id
-                   from
-                     cr_child_rels
-                   where
-                     parent_id = delete__item_id 
+  for v_rel_val in select rel_id, child_id
+                   from   cr_child_rels
+                   where  parent_id = delete__item_id 
   LOOP
     PERFORM acs_rel__delete(v_rel_val.rel_id);
     PERFORM content_item__delete(v_rel_val.child_id);
   end loop;  
 
-  -- 5) delete associated permissions
-  delete from acs_permissions
-    where object_id = delete__item_id;
-
-  -- 6) delete keyword associations
-  delete from cr_item_keyword_map
-    where item_id = delete__item_id;
-
-  -- 7) delete associated comments
+  --
+  -- Delete associated comments
+  --
   PERFORM journal_entry__delete_for_object(delete__item_id);
 
-  -- context_id debugging loop
-  --for v_error_val in c_error_cur loop
-  --    || v_error_val.object_type);
-  --end loop;
-
+  --
+  -- Finally, delete the acs_object of the item.
+  --
   PERFORM acs_object__delete(delete__item_id);
 
   return 0; 
 END;
 $$ LANGUAGE plpgsql;
 
+
+
 select define_function_args('content_item__delete','item_id');
-
-
 --
 -- procedure content_item__delete/1
 --
@@ -1478,14 +1431,14 @@ CREATE OR REPLACE FUNCTION content_item__delete(
 ) RETURNS integer AS $$
 DECLARE
 BEGIN
-        PERFORM content_item__del (delete__item_id);
-  return 0; 
+   PERFORM content_item__del (delete__item_id);
+   return 0; 
 END;
 $$ LANGUAGE plpgsql;
 
+
+
 select define_function_args('content_item__edit_name','item_id,name');
-
-
 --
 -- procedure content_item__edit_name/2
 --
@@ -1530,13 +1483,7 @@ END;
 $$ LANGUAGE plpgsql;
 
 
--- old define_function_args('content_item__get_id','item_path,root_folder_id,resolve_index;f')
--- new
 select define_function_args('content_item__get_id','item_path,root_folder_id;null,resolve_index;f');
-
-
-
-
 --
 -- procedure content_item__get_id/3
 --
@@ -1727,11 +1674,9 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+
 -- I hard code the content_item_globals.c_root_folder_id here
 select define_function_args('content_item__get_virtual_path','item_id,root_folder_id;-100');
-
-
-
 --
 -- procedure content_item__get_virtual_path/2
 --
@@ -1768,9 +1713,7 @@ $$ LANGUAGE plpgsql;
 
 
 
--- added
 select define_function_args('content_item__write_to_file','item_id,root_path');
-
 --
 -- procedure content_item__write_to_file/2
 --
@@ -1801,10 +1744,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+
 select define_function_args('content_item__register_template','item_id,template_id,use_context');
-
-
-
 --
 -- procedure content_item__register_template/3
 --
@@ -1842,12 +1783,7 @@ $$ LANGUAGE plpgsql;
 
 
 
--- old define_function_args('content_item__unregister_template','item_id,template_id,use_context')
--- new
 select define_function_args('content_item__unregister_template','item_id,template_id;null,use_context;null');
-
-
-
 --
 -- procedure content_item__unregister_template/3
 --
@@ -1892,10 +1828,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+
 select define_function_args('content_item__get_template','item_id,use_context');
-
-
-
 --
 -- procedure content_item__get_template/2
 --
@@ -1946,9 +1880,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable strict;
 
+
 select define_function_args('content_item__get_content_type','item_id');
-
-
 --
 -- procedure content_item__get_content_type/1
 --
@@ -1971,12 +1904,9 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable strict;
 
-select define_function_args('content_item__get_live_revision','item_id');
+
 
 select define_function_args('content_item__get_live_revision','item_id');
-
-
-
 --
 -- procedure content_item__get_live_revision/1
 --
@@ -1999,9 +1929,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable strict;
 
+
 select define_function_args('content_item__set_live_revision','revision_id,publish_status;ready');
-
-
 --
 -- procedure content_item__set_live_revision/1
 --
@@ -2039,9 +1968,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+
 select define_function_args('content_item__set_live_revision','revision_id,publish_status;ready');
-
-
 --
 -- procedure content_item__set_live_revision/2
 --
@@ -2077,9 +2005,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+
 select define_function_args('content_item__unset_live_revision','item_id');
-
-
 --
 -- procedure content_item__unset_live_revision/1
 --
@@ -2111,13 +2038,8 @@ END;
 $$ LANGUAGE plpgsql;
 
 
--- old define_function_args('content_item__set_release_period','item_id,start_when,end_when')
--- new
+
 select define_function_args('content_item__set_release_period','item_id,start_when;null,end_when;null');
-
-
-
-
 --
 -- procedure content_item__set_release_period/3
 --
@@ -2154,12 +2076,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
-select define_function_args('content_item__get_revision_count','item_id');
 
 select define_function_args('content_item__get_revision_count','item_id');
-
-
-
 --
 -- procedure content_item__get_revision_count/1
 --
@@ -2182,9 +2100,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable;
 
+
 select define_function_args('content_item__get_context','item_id');
-
-
 --
 -- procedure content_item__get_context/1
 --
@@ -2242,9 +2159,8 @@ return null;
 END;
 $$ LANGUAGE plpgsql;
 
+
 select define_function_args('content_item__move','item_id,target_folder_id,name');
-
-
 --
 -- procedure content_item__move/3
 --
@@ -2292,9 +2208,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
+
 select define_function_args('content_item__generic_move','item_id,target_item_id,name');
-
-
 --
 -- procedure content_item__generic_move/3
 --
@@ -2380,10 +2295,7 @@ $$ LANGUAGE plpgsql;
 -- 4) copy the latest revision from the original item to the new item (if any)
 
 
-
--- added
 select define_function_args('content_item__copy2','item_id,target_folder_id,creation_user,creation_ip;null');
-
 --
 -- procedure content_item__copy2/4
 --
@@ -2410,12 +2322,7 @@ END;
 $$ LANGUAGE plpgsql;
 
 
--- old define_function_args('content_item__copy','item_id,target_folder_id,creation_user,creation_ip,name')
--- new
 select define_function_args('content_item__copy','item_id,target_folder_id,creation_user,creation_ip;null,name;null');
-
-
-
 --
 -- procedure content_item__copy/5
 --
@@ -2573,10 +2480,7 @@ END;
 $$ LANGUAGE plpgsql;
 
 
-
 select define_function_args('content_item__get_latest_revision','item_id');
-
-
 --
 -- procedure content_item__get_latest_revision/1
 --
@@ -2608,9 +2512,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql strict stable;
 
+
 select define_function_args('content_item__get_best_revision','item_id');
-
-
 --
 -- procedure content_item__get_best_revision/1
 --
@@ -2635,9 +2538,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable strict;
 
+
 select define_function_args('content_item__get_title','item_id,is_live;f');
-
-
 --
 -- procedure content_item__get_title/2
 --
@@ -2710,9 +2612,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable strict;
 
+
 select define_function_args('content_item__get_publish_date','item_id,is_live;f');
-
-
 --
 -- procedure content_item__get_publish_date/2
 --
@@ -2751,9 +2652,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable;
 
+
 select define_function_args('content_item__is_subclass','object_type,supertype');
-
-
 --
 -- procedure content_item__is_subclass/2
 --
@@ -2778,12 +2678,8 @@ END;
 $$ LANGUAGE plpgsql stable;
 
 
--- old define_function_args('content_item__relate','item_id,object_id,relation_tag;generic,order_n,relation_type;cr_item_rel')
--- new
+
 select define_function_args('content_item__relate','item_id,object_id,relation_tag;generic,order_n;null,relation_type;cr_item_rel');
-
-
-
 --
 -- procedure content_item__relate/5
 --
@@ -2894,12 +2790,9 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
-select define_function_args('content_item__unrelate','rel_id');
+
 
 select define_function_args('content_item__unrelate','rel_id');
-
-
-
 --
 -- procedure content_item__unrelate/1
 --
@@ -2919,12 +2812,9 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql;
 
-select define_function_args('content_item__is_index_page','item_id,folder_id');
+
 
 select define_function_args('content_item__is_index_page','item_id,folder_id');
-
-
-
 --
 -- procedure content_item__is_index_page/2
 --
@@ -2943,10 +2833,8 @@ BEGIN
 END;
 $$ LANGUAGE plpgsql stable;
 
+
 select define_function_args('content_item__get_parent_folder','item_id');
-
-
-
 --
 -- procedure content_item__get_parent_folder/1
 --
