@@ -5,7 +5,7 @@
 -- Authors:      Michael Pih (pihman@arsdigita.com)
 --               Karl Goldstein (karlg@arsdigita.com)
 
--- $Id: content-type.sql,v 1.56 2011/07/07 10:46:02 gustafn Exp $
+-- $Id: content-type.sql,v 1.57 2015/07/27 12:29:28 gustafn Exp $
 
 -- This is free software distributed under the terms of the GNU Public
 -- License.  Full text of the license is available from the GNU Project:
@@ -875,8 +875,7 @@ BEGIN
  acs_objects.last_modified,
  acs_objects.modifying_user,
  acs_objects.modifying_ip,
- acs_objects.tree_sortkey,
- acs_objects.max_child_sortkey, cr.revision_id, cr.title, cr.item_id,
+ cr.revision_id, cr.title, cr.item_id,
     content_revision__get_content(cr.revision_id) as data, 
     cr_text.text_data as text,
     cr.description, cr.publish_date, cr.mime_type, cr.nls_language' || 
@@ -903,8 +902,7 @@ BEGIN
  acs_objects.last_modified,
  acs_objects.modifying_user,
  acs_objects.modifying_ip,
- acs_objects.tree_sortkey,
- acs_objects.max_child_sortkey, cr.revision_id, cr.title, cr.item_id,
+ cr.revision_id, cr.title, cr.item_id,
     cr.description, cr.publish_date, cr.mime_type, cr.nls_language,
     i.name, i.parent_id' || 
     cols || 
