@@ -6,7 +6,7 @@
 -- Copyright (C) 1999-2000 ArsDigita Corporation
 -- Authors:      Karl Goldstein (karlg@arsdigita.com)
 
--- $Id: content-update.sql,v 1.9 2011/07/07 10:46:02 gustafn Exp $
+-- $Id: content-update.sql,v 1.9.4.1 2015/08/16 22:47:37 gustafn Exp $
 
 -- This is free software distributed under the terms of the GNU Public
 -- License.  Full text of the license is available from the GNU Project:
@@ -147,7 +147,7 @@ BEGIN
 
     execute 'alter table cr_items add 
       latest_revision integer
-                      constraint cr_items_latest_fk
+                      constraint cr_items_latest_revision_fk
                       references cr_revisions';
 
     execute 'update cr_items 
