@@ -72,6 +72,9 @@ ad_proc -public cr_write_content {
 	    if {$filename eq ""} {
 		error "No content for the revision $revision_id.\
 		This seems to be an error which occured during the upload of the file"
+	    } elseif {![file readable $filename]} {
+	      ns_log Error "Could not read file $filename. Maybe the content repository is (partially) missing?"
+	      ns_return 404 text/plain {}
 	    } else {
 		if { $string_p } {
 		    set fd [open $filename "r"]
@@ -427,3 +430,9 @@ ad_proc -public cr_create_mime_type {
 }
 
                                
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
