@@ -2,7 +2,7 @@ ad_page_contract {
    
     @author Emmanuelle Raffenne (eraffenne@gmail.com)
     @creation-date 22-feb-2010
-    @cvs-id $Id: extensions.tcl,v 1.1 2010/03/09 11:49:46 emmar Exp $
+    @cvs-id $Id: extensions.tcl,v 1.1.6.1 2015/09/10 08:21:19 gustafn Exp $
 
 } {    
     mime_type:notnull
@@ -38,3 +38,9 @@ db_multirow -extend {action action_url} extensions get_extensions {} {
     set action_url [export_vars -base "unmap" {mime_type extension return_url}]
     set action "Unmap"
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
