@@ -2,7 +2,7 @@ ad_page_contract {
    
     @author Emmanuelle Raffenne (eraffenne@gmail.com)
     @creation-date 22-feb-2010
-    @cvs-id $Id: map.tcl,v 1.1 2010/03/09 11:49:46 emmar Exp $
+    @cvs-id $Id: map.tcl,v 1.1.6.1 2015/09/10 08:21:19 gustafn Exp $
 
 } {
     mime_type:notnull
@@ -45,3 +45,9 @@ ad_form -name extension_new -export {return_url} -cancel_url $return_url -form {
     ad_script_abort
 
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
