@@ -2,7 +2,7 @@ ad_page_contract {
    
     @author Emmanuelle Raffenne (eraffenne@gmail.com)
     @creation-date 22-feb-2010
-    @cvs-id $Id: unmap.tcl,v 1.1 2010/03/09 11:49:46 emmar Exp $
+    @cvs-id $Id: unmap.tcl,v 1.1.6.1 2015/09/10 08:21:20 gustafn Exp $
 
 } {
     extension:notnull
@@ -17,3 +17,9 @@ if { $return_url eq "" } {
 db_dml extension_unmap {}
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
