@@ -1,4 +1,4 @@
- # $Id: acs-developer-support-procs.tcl,v 1.52.2.14 2014/02/10 20:56:01 gustafn Exp $
+ # $Id: acs-developer-support-procs.tcl,v 1.55.2.5 2015/11/27 23:08:07 gustafn Exp $
  # File:        developer-support-procs.tcl
  # Author:      Jon Salz <jsalz@mit.edu>
  # Date:        22 Apr 2000
@@ -55,10 +55,20 @@
  ad_proc -public ds_enabled_p {} { 
      Returns true if developer-support facilities are enabled.
  } {
-     if { ![nsv_exists ds_properties enabled_p] || ![nsv_get ds_properties enabled_p] } {
-         return 0
+     #
+     # On busy sites, frequent calls to [ds_enabled_p] leads to huge
+     # number of mutex locks for the nsv ds_properties. Therefore,
+     # cache its results in a per-thead variable.
+     #
+     if {[info exists ::ds_enabled_p]} {
+         return $::ds_enabled_p
      }
-     return 1
+     if { ![nsv_exists ds_properties enabled_p] || ![nsv_get ds_properties enabled_p] } {
+         set ::ds_enabled_p 0
+     } else {
+         set ::ds_enabled_p 1
+     }
+     return $::ds_enabled_p
  }
 
  ad_proc -public ds_collection_enabled_p {} {
@@ -149,7 +159,7 @@
      template::adp_append_code "if { \[info exists ::ds_show_p\] } {"
      template::adp_append_code "    set __apidoc_path \[string range $stub \[string length \$::acs::rootdir\] end\].adp"
      template::adp_append_code "    set __stub_path \[join \[split $stub /\] \" / \"\]"
-     template::adp_append_code "    append __adp_output \"<div class=\\\"\[::ds_adp_box_class\]\\\"><span class=\\\"\[::ds_adp_file_class\]\\\"><a href=\\\"/api-doc/content-page-view?source_p=1&path=\$__apidoc_path\\\" style=\\\"text-decoration: none;\\\">\$__stub_path</a></span><div class=\\\"\[::ds_adp_output_class\]\\\">\""
+     template::adp_append_code "    append __adp_output \"<div class=\\\"\[::ds_adp_box_class\]\\\"><span class=\\\"\[::ds_adp_file_class\]\\\"><a href=\\\"/api-doc/content-page-view?source_p=1&amp;path=\$__apidoc_path\\\" style=\\\"text-decoration: None;\\\">\$__stub_path</a></span><div class=\\\"\[::ds_adp_output_class\]\\\">\""
      template::adp_append_code "}"
  }
 
@@ -173,7 +183,7 @@
      @return A link to the first instance of the developer-support information available in the site node, \
              the empty_string if none are available.
  } {
-     return "[ad_url][apm_package_url_from_key "acs-developer-support"]"
+     return [apm_package_url_from_key acs-developer-support]
  }
 
  ad_proc ds_link {} { 
@@ -188,12 +198,15 @@
          return ""
      }
 
-     set out "<div class=\"developer-support\">"
+     set out "<div class='developer-support'>"
      if { [ds_enabled_p] && [ds_collection_enabled_p] } {
 
          set ds_url [ds_support_url]
          if {$ds_url ne ""} {
-             append out "<a href=\"${ds_url}\">Developer Support Home</a> - <a href=\"${ds_url}request-info?request=$::ad_conn(request)\">Request Information</a><br>"
+             append out [subst {
+		 <a href="$ds_url">Developer Support Home</a> -
+		 <a href="$ds_urlrequest-info?request=$::ad_conn(request)">Request Information</a><br>
+	     }]
          } else {
              ns_log Error "ACS-Developer-Support: Unable to offer link to Developer Support \
                      because it is not mounted anywhere."
@@ -221,19 +234,25 @@
          }
 
          if { [parameter::get -package_id [ds_instance_id] -parameter ShowCommentsInlineP -default 0] } {
-             append out "Comments: <b>On</b> | <a href=\"[export_vars -base ${ds_url}comments-toggle { { return_url [ad_return_url] } }]\">Off</a><br>"
+	     set href [export_vars -base ${ds_url}comments-toggle { { return_url [ad_return_url] } }]
+             append out [subst {
+		 Comments: <b>On</b> | <a href="[ns_quotehtml $href]">Off</a><br>
+	     }]
              if { [nsv_exists ds_request $::ad_conn(request).comment] } {
                  foreach comment [nsv_get ds_request $::ad_conn(request).comment] {
                      append out "<b>Comment:</b> $comment<br>\n"
                  }
              }
          } else {
-             append out "Comments: <a href=\"[export_vars -base ${ds_url}comments-toggle { { return_url [ad_return_url] } }]\">On</a> | <b>Off</b><br>"
+	     set href [export_vars -base ${ds_url}comments-toggle { { return_url [ad_return_url] } }]
+             append out [subst {
+		 Comments: <a href="[ns_quotehtml $href]">On</a> | <b>Off</b><br>
+	     }]
          }
      }
 
      if { [ds_user_switching_enabled_p] } {
-         append out "[ds_user_select_widget]<br>"
+         append out [ds_user_select_widget] "<br>"
      }
 
      return $out
@@ -269,7 +288,7 @@
  ad_proc -public ds_get_db_command_info {} {
      Get a Tcl list with { num_commands total_ms } for the database commands for the request.
 
-     Returns the empty string if the information is not available.
+     @return list containing num_commands and total_ms, or empty string if the information is not available.
  } { 
      set result {}
      if { [ds_enabled_p] && [ds_collection_enabled_p] } {
@@ -350,8 +369,7 @@
  ad_proc -private ds_add { name args } { 
      Sets a developer-support property for the current request. 
  } {
-
-     if { [ds_enabled_p] && [ds_collection_enabled_p] } { 
+     if { [ds_enabled_p] && [ds_collection_enabled_p] } {
          if { [catch { nsv_exists ds_request . }] } {
              ns_log "Warning" "ds_request NSVs not initialized"
              return
@@ -469,12 +487,15 @@
 
      set ds_url [ds_support_url]
      if {$ds_url ne ""} {
-         return "<form action=\"${ds_url}/set-user\" method=\"get\">
-         $you_are
-         $you_are_really
-         Change user: <select name=\"user_id\">
-         $options
-         </select>[export_vars -form {return_url}]<input type=submit value=\"Go\"></form>"
+         return [subst {
+	     <form action="$ds_url/set-user" method="get">
+	     $you_are
+	     $you_are_really
+	     Change user: <select name="user_id">
+	     $options
+	     </select>[export_vars -form {return_url}]
+	     <input type="submit" value="Go"></form>
+	 }]
      } else {
          ns_log Error "ACS-Developer-Support: Unable to offer link to Developer Support \
                  because it is not mounted anywhere."
@@ -574,30 +595,15 @@ ad_proc -private ds_replace_get_user_procs { enabled_p } {
 		ad_set_client_property developer-support user_id [ad_conn user_id]
 	    }
             rename ad_conn orig_ad_conn
-	    #rename ad_get_user_id orig_ad_get_user_id
-	    #rename ad_verify_and_get_user_id orig_ad_verify_and_get_user_id
-	    
             proc ad_conn { args } {
 	        ds_conn {*}$args
             }
-	    #proc ad_get_user_id {} {
-            #    ds_get_user_id
-	    #}
-	    #proc ad_verify_and_get_user_id {} {
-            #    ds_get_user_id
-	    #}
 	}
     } else {
         #ds_comment "Disabling user-switching"
 	if { [info commands orig_ad_conn] ne ""} {
             rename ad_conn {}
             rename orig_ad_conn ad_conn
-
-	    #rename ad_get_user_id {}
-	    #rename orig_ad_get_user_id ad_get_user_id
-
-	    #rename ad_verify_and_get_user_id {}
-	    #rename orig_ad_verify_and_get_user_id ad_verify_and_get_user_id
 	}
     }
 }
@@ -695,9 +701,14 @@ ad_proc -public ds_init { } {
 	# variables, which are deleted automatically after every
 	# request.
 	#
-	set ::ds_enabled_p 1
 	if {[::ds_collection_enabled_p] } {set ::ds_collection_enabled_p 1}
 	if {[::ds_profiling_enabled_p] } {set ::ds_profiling_enabled_p 1}
 	if {[::ds_show_p]} {set ::ds_show_p 1}
     }
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
