@@ -6,7 +6,7 @@ ad_page_contract {
     
     @author Malte Sussdorff (malte.sussdorff@cognovis.de)
     @creation-date 2007-09-29
-    @cvs-id $Id: css-list.tcl,v 1.2 2010/12/05 13:45:21 jeffd Exp $
+    @cvs-id $Id: css-list.tcl,v 1.2.4.1 2015/09/10 08:21:23 gustafn Exp $
 } {
     {return_url ""}
     {css_list}
@@ -35,3 +35,9 @@ foreach css $css_list {
     }
     template::multirow append css_multirow $css $file_location $edit_location
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
