@@ -4,7 +4,7 @@ ad_page_contract {
     @author Lars Pind (lars@pinds.com)
     @author Jeff Davis <davis@xarg.net>
     @creation-date 2003-10-28
-    @cvs-id $Id: set.tcl,v 1.2.4.1 2014/08/05 12:46:53 gustafn Exp $
+    @cvs-id $Id: set.tcl,v 1.3.2.2 2015/11/27 10:26:59 gustafn Exp $
 } {
     field 
     enabled_p:boolean
@@ -28,6 +28,7 @@ switch -- $field {
     }
     ds {
         nsv_set ds_properties enabled_p $enabled_p
+        set ::ds_enabled_p $enabled_p
     }
     frag {
         nsv_set ds_properties page_fragment_cache_p $enabled_p
@@ -40,3 +41,9 @@ switch -- $field {
     }
 }
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
