@@ -29,8 +29,13 @@ ad_form -name shell -form {
         set out "You cannot use GET to invoke a script on this page.\nClick OK to resubmit the form as a POST."
     } else {
         if {[catch {set out [uplevel 1 [string map {"\\\r\n" " "} $script]]}]} {
-            global errorInfo
-            set out "ERROR:\n$errorInfo"
+            set out "ERROR:\n$::errorInfo"
         }
     }
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
