@@ -7,7 +7,7 @@
 --
 -- @author rhs@mit.edu
 --
--- @cvs-id $Id: acs-relationships-create.sql,v 1.6 2004/03/04 14:52:40 jeffd Exp $
+-- @cvs-id $Id: acs-relationships-create.sql,v 1.14 2010/01/06 20:07:24 ryang Exp $
 --
 
 ----------------------------------------------------------------
@@ -15,21 +15,25 @@
 ----------------------------------------------------------------
 
 create table acs_rel_roles (
-	role		varchar2(100) not null
-			constraint acs_rel_roles_pk primary key,
-        pretty_name	varchar2(100) not null,
-        pretty_plural	varchar2(100) not null
+	role		varchar2(100) 
+			constraint acs_rel_roles_role_nn not null
+			constraint acs_rel_roles_role_pk primary key,
+        pretty_name	varchar2(100) 
+			constraint acs_rel_roles_pretty_name_nn not null,
+        pretty_plural	varchar2(100) 
+			constraint acs_rel_roles_pretty_plural_nn not null
 );
 
 create table acs_rel_types (
-	rel_type	varchar2(100) not null
-			constraint acs_rel_types_pk primary key
+	rel_type	varchar2(100) 
+			constraint acs_rel_types_rel_type_nn not null
+			constraint acs_rel_types_rel_type_pk primary key
 			constraint acs_rel_types_rel_type_fk
 			references acs_object_types(object_type),
 	object_type_one	not null
 			constraint acs_rel_types_obj_type_1_fk
 			references acs_object_types (object_type),
-	role_one	constraint acs_rel_types_role_1_fk
+	role_one	constraint acs_rel_types_role_one_fk
 			references acs_rel_roles (role),
 	min_n_rels_one	integer default 0 not null
 			constraint acs_rel_types_min_n_1_ck
@@ -40,7 +44,7 @@ create table acs_rel_types (
 	object_type_two	not null
 			constraint acs_rel_types_obj_type_2_fk
 			references acs_object_types (object_type),
-	role_two	constraint acs_rel_types_role_2_fk
+	role_two	constraint acs_rel_types_role_two_fk
 			references acs_rel_roles (role),
 	min_n_rels_two	integer default 0 not null
 			constraint acs_rel_types_min_n_2_ck
@@ -288,19 +292,26 @@ show errors
 create sequence acs_rel_id_seq;
 
 create table acs_rels (
-	rel_id		not null
+	rel_id		integer 
+			constraint acs_rels_rel_id_nn not null
 			constraint acs_rels_rel_id_fk
 			references acs_objects (object_id)
-			constraint acs_rels_pk primary key,
-	rel_type	not null
+                        on delete cascade
+			constraint acs_rels_rel_id_pk primary key,
+	rel_type	varchar(100) 
+			constraint acs_rels_rel_type_nn not null
 			constraint acs_rels_rel_type_fk
 			references acs_rel_types (rel_type),
-	object_id_one	not null
-			constraint acs_object_rels_one_fk
-			references acs_objects (object_id),
-	object_id_two	not null
-			constraint acs_object_rels_two_fk
-			references acs_objects (object_id),
+	object_id_one	integer 
+			constraint acs_rels_object_id_one_nn not null
+			constraint acs_rels_object_id_one_fk
+			references acs_objects (object_id)
+                        on delete cascade,
+	object_id_two	integer 
+			constraint acs_rels_object_id_two_nn not null
+			constraint acs_rels_object_id_two_fk
+			references acs_objects (object_id)
+                        on delete cascade,
 	constraint acs_object_rels_un unique
 	(rel_type, object_id_one, object_id_two)
 );
@@ -326,6 +337,33 @@ comment on table acs_rels is '
  acs_attributes.
 ';
 
+----------------------------
+-- Application Data Links --
+----------------------------
+
+create sequence acs_data_links_seq start with 1;
+
+create table acs_data_links (
+	rel_id		integer 
+			constraint acs_data_links_rel_id_nn not null
+			constraint acs_data_links_rel_id_pk primary key,
+	object_id_one	integer not null
+			constraint acs_data_links_obj_one_fk
+			references acs_objects (object_id)
+                        on delete cascade,
+	object_id_two	integer not null
+			constraint acs_data_links_obj_two_fk
+			references acs_objects (object_id)
+                        on delete cascade,
+    relation_tag    varchar2(100),
+    constraint acs_data_links_un unique
+    (object_id_one, object_id_two, relation_tag)    
+);
+
+create index acs_data_links_id_one_idx on acs_data_links (object_id_one);
+create index acs_data_links_id_two_idx on acs_data_links (object_id_two);
+create index acs_data_links_rel_tag_idx on acs_data_links (relation_tag);
+
 --------------
 -- TRIGGERS --
 --------------
@@ -434,6 +472,7 @@ as
     v_rel_id := acs_object.new (
       object_id => rel_id,
       object_type => rel_type,
+      title => rel_type || ': ' || object_id_one || ' - ' || object_id_two,
       context_id => context_id,
       creation_user => creation_user,
       creation_ip => creation_ip
