@@ -3,7 +3,7 @@
 --
 -- @author rhs@mit.edu
 -- @creation-date 2000-09-05
--- @cvs-id $Id: site-nodes-create.sql,v 1.8 2010/11/24 18:58:45 victorg Exp $
+-- @cvs-id $Id: site-nodes-create.sql,v 1.9 2015/04/27 15:28:17 victorg Exp $
 --
 
 begin
@@ -47,7 +47,9 @@ create table site_nodes (
 );
 
 create index site_nodes_object_id_idx on site_nodes (object_id);
-create index site_nodes_parent_id_idx on site_nodes(parent_id,object_id,node_id);
+create index site_nodes_parent_object_node_id_idx on site_nodes(parent_id, object_id, node_id);
+create index site_nodes_parent_id_idx on site_nodes(parent_id);
+
 
 create or replace package site_node
 as
