@@ -5,25 +5,31 @@
 --
 -- @author Peter Marklund
 -- @creation-date 2000/10/01
--- @cvs-id $Id: acs-install.sql,v 1.27 2006/06/04 00:45:38 donb Exp $
+-- @cvs-id $Id: acs-install.sql,v 1.28 2011/07/07 10:46:01 gustafn Exp $
 --
 
-create function inline_0 ()
-returns integer as '
-declare
+
+
+--
+-- procedure inline_0/0
+--
+CREATE OR REPLACE FUNCTION inline_0(
+
+) RETURNS integer AS $$
+DECLARE
     node_id             site_nodes.node_id%TYPE;
     main_site_id        site_nodes.node_id%TYPE;
-begin   
+BEGIN   
 
   main_site_id := apm_service__new(
                     null,
-		    ''#acs-kernel.Main_Site#'',
-		    ''acs-subsite'',
-                    ''apm_service'',
+		    '#acs-kernel.Main_Site#',
+		    'acs-subsite',
+                    'apm_service',
                     now(),
                     null,
                     null,
-                    acs__magic_object_id(''default_context'')
+                    acs__magic_object_id('default_context')
 	       );
 
 
@@ -35,65 +41,66 @@ begin
     (-2, main_site_id);
 
   update acs_objects
-  set object_type = ''application_group'',
+  set object_type = 'application_group',
       context_id = main_site_id
   where object_id = -2;
 
   insert into group_rels
     (group_rel_id, group_id, rel_type)
-  select nextval(''t_acs_object_id_seq''), -2, ''admin_rel'';
+  select nextval('t_acs_object_id_seq'), -2, 'admin_rel';
 
 
   -- Create the members and admins rel segments
 
   perform rel_segment__new(
                    null,
-                   ''rel_segment'',
+                   'rel_segment',
                    now(),
                    null,
                    null,
                    null,
                    null,
-                   ''#acs-kernel.Main_Site_Members#'',
+                   '#acs-kernel.Main_Site_Members#',
                    -2,
-                   ''membership_rel'',
+                   'membership_rel',
                    null
                  );
 
   perform rel_segment__new(
                    null,
-                   ''rel_segment'',
+                   'rel_segment',
                    now(),
                    null,
                    null,
                    null,
                    null,
-                   ''#acs-kernel.lt_Main_Site_Administrat#'',
+                   '#acs-kernel.lt_Main_Site_Administrat#',
                    -2,
-                   ''admin_rel'',
+                   'admin_rel',
                    null
                  );
 
   node_id := site_node__new (
           null,
           null,          
-          '''',
+          '',
           main_site_id,          
-          ''t'',
-          ''t'',
+          't',
+          't',
           null,
           null
   );
 
   perform acs_permission__grant_permission (
         main_site_id,
-        acs__magic_object_id(''the_public''),
-        ''read''
+        acs__magic_object_id('the_public'),
+        'read'
         );
 
   return null;
 
-end;' language 'plpgsql';
+END;
+$$ LANGUAGE plpgsql;
 
 select inline_0 ();
 
