@@ -5,17 +5,18 @@
 --
 -- @author Lars Pind (lars@pinds.com)
 -- @creation-date 2000-22-18
--- @cvs-id $Id: journal-drop.sql,v 1.2 2004/06/18 18:21:57 jeffd Exp $
+-- @cvs-id $Id: journal-drop.sql,v 1.3 2011/07/07 10:46:02 gustafn Exp $
 --
 
 \t
-create function inline_0 () returns integer as '
-begin
+CREATE OR REPLACE FUNCTION inline_0 () RETURNS integer AS $$
+BEGIN
   PERFORM acs_object_type__drop_type(
-    ''journal_entry'', ''f''
+    'journal_entry', 'f'
   );
   return null;
-end;' language 'plpgsql';
+END;
+$$ LANGUAGE plpgsql;
 
 select inline_0 ();
 drop function inline_0 ();
