@@ -3,13 +3,14 @@
 -- 
 -- @author Oumi Mehrotra
 -- @creation-date 2000-11-22
--- @cvs-id rel-constraints-drop.sql,v 1.1.4.1 2001/01/12 22:58:51 mbryzek Exp
+-- @cvs-id $Id: rel-constraints-drop.sql,v 1.3 2011/07/07 10:46:02 gustafn Exp $
 \t
-create function  inline_0 () returns integer as '
-begin
-        PERFORM acs_rel_type__drop_type(''rel_constraint'');
+CREATE OR REPLACE FUNCTION  inline_0 () RETURNS integer AS $$
+BEGIN
+        PERFORM acs_rel_type__drop_type('rel_constraint');
         return null;
-end;' language 'plpgsql';
+END;
+$$ LANGUAGE plpgsql;
 select inline_0 ();
 drop function inline_0 ();
 
