@@ -24,7 +24,7 @@ ad_library {
     @author Jeff Davis
     @author Peter Marklund (peter@collaboraid.biz)
     @author Lars Pind (lars@collaboraid.biz)
-    @cvs-id $Id: lang-catalog-procs.tcl,v 1.49.8.6 2013/10/13 10:37:10 gustafn Exp $
+    @cvs-id $Id: lang-catalog-procs.tcl,v 1.50.2.3 2015/09/18 07:41:03 gustafn Exp $
 }
 
 namespace eval lang::catalog {}
@@ -356,9 +356,9 @@ ad_proc -private lang::catalog::export_to_file {
    # Loop over and write the messages to the file
    set message_count "0"
    foreach message_key $message_key_list {
-       puts $catalog_file_id "  <msg key=\"[ad_quotehtml $message_key]\">[ad_quotehtml $messages_array($message_key)]</msg>"
+       puts $catalog_file_id "  <msg key=\"[ns_quotehtml $message_key]\">[ns_quotehtml $messages_array($message_key)]</msg>"
        if { ([info exists descriptions_array($message_key)] && $descriptions_array($message_key) ne "") && $filename_info(locale) eq "en_US" } {
-           puts $catalog_file_id "  <description key=\"[ad_quotehtml $message_key]\">[ad_quotehtml $descriptions_array($message_key)]</description>\n"
+           puts $catalog_file_id "  <description key=\"[ns_quotehtml $message_key]\">[ns_quotehtml $descriptions_array($message_key)]</description>\n"
        }
        incr message_count
    }
@@ -606,8 +606,7 @@ ad_proc -private lang::catalog::import_from_file {
                     -message_key $message_key \
                     -description $descriptions_array($message_key)
             } {
-                global errorInfo
-                ns_log Error "Registering description for key ${package_key}.${message_key} in locale $locale failed with error message \"$errmsg\"\n\n$errorInfo"
+                ns_log Error "Registering description for key ${package_key}.${message_key} in locale $locale failed with error message \"$errmsg\"\n\n$::errorInfo"
             }
         }    
     }
@@ -1023,9 +1022,8 @@ ad_proc -public lang::catalog::import {
             # Use a catch so that parse failure of one file doesn't cause the import of all files to fail
             array unset loop_message_count
             if { [catch { array set loop_message_count [lang::catalog::import_from_file $file_path] } errMsg] } {
-                global errorInfo
                 
-                ns_log Error "The import of file $file_path failed, error message is:\n\n${errMsg}\n\nstack trace:\n\n$errorInfo\n\n"
+                ns_log Error "The import of file $file_path failed, error message is:\n\n${errMsg}\n\nstack trace:\n\n$::errorInfo\n\n"
             } else {
                 foreach action [array names loop_message_count] {
                     if { $action ne "errors" } {
@@ -1156,3 +1154,9 @@ ad_proc -private lang::catalog::translate {} {
         }
     }                 
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
