@@ -12,7 +12,7 @@ ad_library {
     @author Bruno Mattarollo (bruno.mattarollo@ams.greenpeace.org)
     @author Peter Marklund (peter@collaboraid.biz)
     @author Lars Pind (lars@collaboraid.biz)
-    @cvs-id $Id: lang-message-procs.tcl,v 1.51.8.7 2014/09/08 07:58:50 gustafn Exp $
+    @cvs-id $Id: lang-message-procs.tcl,v 1.54.2.3 2015/10/19 17:33:01 gustafn Exp $
 }
 
 namespace eval lang::message {}
@@ -627,7 +627,7 @@ ad_proc -private lang::message::format {
     set localized_message "The %animal% jumped across the %barrier%. About 50% of the time, he stumbled, or maybe it was %%20 %times%."
     set value_list { animal "frog" barrier "fence" }
 
-    puts "[format $localized_message $value_list]"
+    ns_log notice formatted=[format $localized_message $value_list]
     
     The output from the example is:
 
@@ -677,7 +677,8 @@ ad_proc -private lang::message::format {
                         append formated_message $local_variable($array_key)
                     }
                 } else {
-                    error "Message contains a variable named '$variable_name' which doesn't exist in the caller's environment: message $localized_message"
+                    ns_log warning "Message contains a variable named '$variable_name' which doesn't exist in the caller's environment: message $localized_message"
+		    append formated_message "MISSING: variable '$variable_name' is not available"
                 }
             }
         }
@@ -705,7 +706,7 @@ ad_proc -public lang::message::message_exists_p { locale key } {
     @author Peter Marklund
 } {
     # Make sure messages are in the cache
-    cache
+    lang::message::cache
 
     return [nsv_exists lang_message_$locale $key]        
 }
@@ -775,7 +776,7 @@ ad_proc -public lang::message::lookup {
     @return A localized piece of text.
 } { 
     # Make sure messages are in the cache
-    cache
+    lang::message::cache
 
     # Make sure that a default of "" is transformed into Translation Missing
     # As per discussion on IRC on 2008-03-06
@@ -832,16 +833,11 @@ ad_proc -public lang::message::lookup {
                     if { [message_exists_p $locale $key] } {
                         set message [nsv_get lang_message_$locale $key]
                     } else {
-			if {"TRANSLATION MISSING" != $default} {
+			if {"TRANSLATION MISSING" ne $default} {
 			    set message $default
 			} else {
-			    if {[string match "acs-translations.*" $key]} {
-				ns_log Debug "lang::message::lookup: Key '$key' does not exist in en_US"
-				set message "MESSAGE KEY MISSING: '$key'"
-			    } else {
-				ns_log Error "lang::message::lookup: Key '$key' does not exist in en_US"
-				set message "MESSAGE KEY MISSING: '$key'"
-			    }
+                            ad_log Error "lang::message::lookup: Key '$key' does not exist in en_US"
+                            set message "MESSAGE KEY MISSING: '$key'"
 			}
 		    }
                 }
@@ -1030,3 +1026,9 @@ ad_proc -public lang::message::update_description {
         db_dml update_description {} -clobs [list $description]
     }
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
