@@ -10,7 +10,7 @@ ad_library {
     @creation-date 30 September 2000
     @author Jeff Davis (davis@xarg.net) 
     @author Ashok Argent-Katwala (akatwala@arsdigita.com)
-    @cvs-id $Id: localization-procs.tcl,v 1.23.8.6 2014/07/15 10:14:52 michaela Exp $
+    @cvs-id $Id: localization-procs.tcl,v 1.24.2.1 2015/09/10 08:21:26 gustafn Exp $
 }
 
 
@@ -582,3 +582,9 @@ ad_proc -private lc_leading_zeros {
 } {
     return [format "%0${n_desired_digits}d" $the_integer]
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
