@@ -6,14 +6,14 @@ ad_page_contract {
     @author Bruno Mattarollo <bruno.mattarollo@ams.greenpeace.org>
     @author Christian Hvid
     @creation-date 30 October 2001
-    @cvs-id $Id: edit-localized-message.tcl,v 1.17.8.2 2013/09/12 16:25:48 antoniop Exp $
+    @cvs-id $Id: edit-localized-message.tcl,v 1.20.2.1 2015/09/10 08:21:27 gustafn Exp $
 
 } {
     locale
     package_key
     message_key
     show:optional
-    {usage_p "f"}
+    {usage_p:boolean "f"}
     {return_url {}}
 }
 
@@ -51,7 +51,7 @@ set usage_show_url [export_vars -base [ad_conn url] { locale package_key message
 set delete_url [export_vars -base message-delete { locale package_key message_key show {return_url {[ad_return_url]}} }]
 
 
-ad_form -name message -form {
+ad_form -name message_form -form {
     {locale:text(hidden),optional {value $current_locale}}
     {package_key:text(hidden),optional {value $package_key}}
     {message_key:text(hidden),optional {value $message_key}}
@@ -69,17 +69,17 @@ ad_form -name message -form {
 } 
 
 if { $default_locale ne $current_locale } {
-    ad_form -extend -name message -form {
+    ad_form -extend -name message_form -form {
         {original_message:text(inform)
             {label "$default_locale_label Message"}
         }
     }
 }
     
-ad_form -extend -name message -form {
+ad_form -extend -name message_form -form {
     {message:text(textarea)
         {label "$locale_label Message"} 
-        {html { rows 6 cols 40 }}
+        {html { rows 6 cols 40 } }
     }
     {comment:text(textarea),optional
         {label "Comment"}
@@ -122,12 +122,12 @@ ad_form -extend -name message -form {
     } else {
         set message $original_message
     }
-    set original_message [ad_quotehtml $original_message]
+    set original_message [ns_quotehtml $original_message]
 
     if { $description eq "" } {
-        set description [subst {(<a href="$description_edit_url">add description</a>)}]
+        set description [subst {(<a href="[ns_quotehtml $description_edit_url]">add description</a>)}]
     } else {
-        set description "[ad_text_to_html -- $description] [subst { (<a href="$description_edit_url">edit</a>)}]"
+        set description "[ad_text_to_html -- $description] [subst { (<a href="[ns_quotehtml $description_edit_url]">edit</a>)}]"
     }
 
     # Augment the audit trail with info on who created the first message
@@ -162,7 +162,11 @@ ad_form -extend -name message -form {
             }
         } 
 
-        set first_translated_message "<ul> <li>First translated by [acs_community_member_link -user_id $creation_user_id -label $creation_user_name] on $creation_date</li></ul>"
+        set first_translated_message [subst {
+	    <ul> <li>First translated by
+	    [acs_community_member_link -user_id $creation_user_id -label $creation_user_name] on $creation_date
+	    </li></ul>
+	}]
     } else {
         set first_translated_message ""
     }
@@ -182,8 +186,14 @@ ad_form -extend -name message -form {
     lang::message::register -comment $comment $locale $package_key $message_key $message
 
     if { $return_url eq "" } {
-        set return_url "[ad_conn url]?[export_vars { locale package_key message_key show }]"
+        set return_url [export_vars -base [ad_conn url] { locale package_key message_key show }]
     }
     ad_returnredirect $return_url
     ad_script_abort
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
