@@ -9,7 +9,7 @@ ad_page_contract {
     locale
 }
 
-set locale_label [ad_locale_get_label $locale]
+set locale_label [lang::util::get_label $locale]
 set page_title "Import all messages for locale $locale"
 set return_url [export_vars -base package-list { locale }]
 set context [list [list $return_url $locale_label] $page_title]
@@ -17,3 +17,9 @@ set context [list [list $return_url $locale_label] $page_title]
 lang::catalog::import -locales [list $locale]
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
