@@ -3,9 +3,15 @@ ad_page_contract {
 
     @author Peter Marklund (peter@collaboraid.biz)
     @creation-date 2002-10-07
-    @cvs-id $Id: load-catalog-files.tcl,v 1.5 2003/10/16 10:50:12 peterm Exp $
+    @cvs-id $Id: load-catalog-files.tcl,v 1.5.24.1 2015/09/10 08:21:28 gustafn Exp $
 }
 
 lang::catalog::import
 
 ad_returnredirect "index"
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
