@@ -6,10 +6,10 @@ ad_page_contract {
 
     @author Bruno Mattarollo <bruno.mattarollo@ams.greenpeace.org>
     @creation-date 19 march 2002
-    @cvs-id $Id: locale-delete.tcl,v 1.5.16.1 2013/08/27 12:20:36 gustafn Exp $
+    @cvs-id $Id: locale-delete.tcl,v 1.7.2.1 2015/09/10 08:21:28 gustafn Exp $
 } {
     locale
-    confirm_p:optional
+    confirm_p:boolean,optional
 }
 
 
@@ -42,3 +42,9 @@ if { ([info exists confirm_p] && $confirm_p ne "") && [template::util::is_true $
     ad_returnredirect "."
     ad_script_abort
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
