@@ -7,7 +7,7 @@ ad_page_contract {
     Modified by Christian Hvid
 
     @creation-date 19 march 2002
-    @cvs-id $Id: locale-edit.tcl,v 1.10 2010/10/17 21:06:08 donb Exp $
+    @cvs-id $Id: locale-edit.tcl,v 1.10.6.1 2015/09/10 08:21:28 gustafn Exp $
 } {
     locale
 }
@@ -174,3 +174,9 @@ if { [form is_valid locale_editing] } {
     forward "index?tab=locales"
 
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
