@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author Bruno Mattarollo <bruno.mattarollo@ams.greenpeace.org>
     @creation-date 15 march 2002
-    @cvs-id $Id: locale-new.tcl,v 1.5.6.1 2013/10/26 09:35:44 gustafn Exp $
+    @cvs-id $Id: locale-new.tcl,v 1.7.2.1 2015/09/10 08:21:28 gustafn Exp $
 }
 
 
@@ -23,8 +23,11 @@ form create locale_creation
 # information on this view can be found in the docs at http://tahiti.oracle.com/
 # look for the PDF file of Oracle 8i "national language support guide"
 
+### GN: this is apparently Oracle-only
 catch {
-    set nls_values_list [db_list_of_lists select_nls_values {select parameter, value from v$nls_valid_values order by parameter, value}]
+    set nls_values_list [db_list_of_lists select_nls_values {
+	select parameter, value from v$nls_valid_values order by parameter, value
+    }]
 
     foreach nls_value $nls_values_list {
         set value [lindex $nls_value 1]
@@ -124,3 +127,9 @@ if { [form is_valid locale_creation] } {
     forward "index?tab=locales"
 
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
