@@ -6,7 +6,7 @@ ad_page_contract {
     @author Bruno Mattarollo <bruno.mattarollo@ams.greenpeace.org>
     @author Christian Hvid
     @creation-date 15 April 2002
-    @cvs-id $Id: localized-message-new.tcl,v 1.11 2008/04/18 06:48:43 victorg Exp $
+    @cvs-id $Id: localized-message-new.tcl,v 1.12.2.1 2015/09/10 08:21:28 gustafn Exp $
 
 } {
     locale
@@ -24,8 +24,8 @@ set locale_label [lang::util::get_label $current_locale]
 set default_locale_label [lang::util::get_label $default_locale]
 
 set page_title "Create New Message"
-set context [list [list "package-list?[export_vars { locale }]" $locale_label] \
-                 [list "message-list?[export_vars { locale package_key show }]" $package_key] \
+set context [list [list [export_vars -base package-list { locale }] $locale_label] \
+                 [list [export_vars -base message-list { locale package_key show }] $package_key] \
                  $page_title]
 
 
@@ -113,4 +113,9 @@ if { [form is_valid message_new] } {
 
 set focus ""
 
-ad_return_template
\ No newline at end of file
+ad_return_template
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
