@@ -3,7 +3,7 @@
 #
 # @author Peter Marklund (peter@collaboraid.biz)
 # @author Lars Pind (lars@collaboraid.biz)
-# @cvs-id $Id: message-usage-include.tcl,v 1.5.10.2 2013/10/17 08:37:12 gustafn Exp $
+# @cvs-id $Id: message-usage-include.tcl,v 1.6.2.2 2015/09/10 08:21:29 gustafn Exp $
 
 set full_key "$package_key.$message_key"
 
@@ -21,7 +21,6 @@ with_catch errmsg {
     exec find $::acs::rootdir -type f -regex ".*\\.\\(info\\|adp\\|sql\\|tcl\\)" -follow | xargs egrep "$grepfor" 2>/dev/null
 } {
     #error "find $::acs::rootdir -type f -regex \".*\\.\\(info\\|adp\\|sql\\|tcl\\)\" -follow | xargs egrep \"${full_key_pattern}\""
-    global errorInfo
 
     foreach line [split $errmsg "\n"] {
         if { [string first "child process exited abnormally" $line] == -1 } {
@@ -33,3 +32,9 @@ with_catch errmsg {
         }
     }
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
