@@ -2,7 +2,7 @@ ad_page_contract {
     Localization home
 } {
     {return_url ""}
-    {return_p "f"}
+    {return_p:boolean "f"}
 }
 
 set instance_name [ad_conn instance_name]
@@ -15,3 +15,9 @@ set context_bar [ad_context_bar]
 set locale [lang::user::locale]
 set language [lang::user::language]
 set admin_p [permission::permission_p -object_id [ad_conn package_id] -privilege admin]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
