@@ -4,7 +4,7 @@ ad_library {
     
     @author Eric Lorenzo (eric@openforce.net)
     @creation-date 22 March 2002
-    @cvs-id $Id: acs-mail-lite-procs.tcl,v 1.90.2.7 2014/07/25 16:49:35 antoniop Exp $
+    @cvs-id $Id: acs-mail-lite-procs.tcl,v 1.92.2.3 2015/09/18 07:44:29 gustafn Exp $
 
 }
 
@@ -156,9 +156,9 @@ namespace eval acs_mail_lite {
 	}
 
         ns_log Debug "send cmd: $cmd"
-        if {[catch $cmd errorInfo]} {
-	    ns_log Error "acs-mail-lite::smtp: error $errorInfo while executing\n$cmd"
-	    error $errorInfo
+        if {[catch $cmd errorMsg]} {
+	    ns_log Error "acs-mail-lite::smtp: error $errorMsg while executing\n$cmd"
+	    error $errorMsg
 	}
     }
 
@@ -460,7 +460,7 @@ namespace eval acs_mail_lite {
 
             db_foreach get_file_info {} {
                 lappend tokens [mime::initialize \
-                                    -param [list name [ad_quotehtml $title]] \
+                                    -param [list name [ns_quotehtml $title]] \
                                     -header [list "Content-Disposition" "attachment; filename=\"$name\""] \
                                     -header [list Content-Description $title] \
                                     -canonical $mime_type \
@@ -474,8 +474,8 @@ namespace eval acs_mail_lite {
 	    set filesystem_attachments_root [parameter::get -parameter "FilesystemAttachmentsRoot" \
                               -package_id $mail_package_id -default ""]
 	    if {$filesystem_attachments_root eq ""} {
-		# on a unix system this should be '/tmp'
-		set filesystem_attachments_root [file dirname [ns_tmpnam]]
+		# on a unix system this could be '/tmp'
+		set filesystem_attachments_root [ad_tmpdir]
 	    }
             foreach f $filesystem_files {
 		# make the file name absolute
@@ -702,3 +702,9 @@ namespace eval acs_mail_lite {
     }
 
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
