@@ -4,7 +4,7 @@ ad_library {
     
     @author Eric Lorenzo (eric@openforce.net)
     @creation-date 22 March 2002
-    @cvs-id $Id: bounce-procs.tcl,v 1.9.4.1 2013/09/09 16:44:18 gustafn Exp $
+    @cvs-id $Id: bounce-procs.tcl,v 1.11.2.1 2015/09/10 08:21:31 gustafn Exp $
 
 }
 
@@ -129,8 +129,8 @@ namespace eval acs_mail_lite {
             set notification_list [util_ns_set_to_list -set $notification]
             array set user $notification_list
             set user_id $user(user_id)
-
-            set body "Dear $user(name),\n\nDue to returning mails from your email account, we currently do not send you any email from our system. To reenable your email account, please visit\n[ad_url]/register/restore-bounce?[export_vars -url {user_id}]"
+	    set href [export_vars -base [ad_url]/register/restore-bounce {user_id}]
+            set body "Dear $user(name),\n\nDue to returning mails from your email account, we currently do not send you any email from our system. To reenable your email account, please visit\n$href"
 
             send -to_addr $notification_list -from_addr $notification_sender -subject $subject -body $body -valid_email
             ns_log Notice "Bounce notification send to user $user_id"
@@ -161,3 +161,9 @@ namespace eval acs_mail_lite {
     }
 
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
