@@ -2,7 +2,7 @@ ad_library {
 
     Set up a scheduled process to send out email messages.
 
-    @cvs-id $Id: acs-messaging-init.tcl,v 1.3.6.1 2013/10/04 13:35:46 victorg Exp $
+    @cvs-id $Id: acs-messaging-init.tcl,v 1.4.2.1 2015/09/10 08:21:32 gustafn Exp $
     @author John Prevost <jmp@arsdigita.com>
     @creation-date 2000-10-28
 
@@ -11,3 +11,9 @@ ad_library {
 # Schedule every 15 minutes
 ad_schedule_proc -thread t 907 acs_messaging_process_queue
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
