@@ -3,7 +3,7 @@ ad_page_contract {
     
     @author Jon Griffin (jon@jongriffin.com)
     @creation-date 2000-10-04
-    @cvs-id $Id: reference-data-list.tcl,v 1.2 2005/03/01 00:01:22 jeffd Exp $
+    @cvs-id $Id: reference-data-list.tcl,v 1.2.18.1 2015/09/10 08:21:32 gustafn Exp $
 } {
 } -properties {
     context_bar:onevalue
@@ -22,4 +22,9 @@ set user_id [ad_conn user_id]
 db_multirow data data_select { 
 }
 
-ad_return_template
\ No newline at end of file
+ad_return_template
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
