@@ -4,7 +4,7 @@ ad_page_contract {
     @param table_name 
     @author Jon Griffin (jon@jongriffin.com)
     @creation-date 17 Sept 2001
-    @cvs-id $Id: table-detail.tcl,v 1.2 2004/02/05 23:37:08 jong Exp $
+    @cvs-id $Id: table-detail.tcl,v 1.3.18.1 2015/09/10 08:21:32 gustafn Exp $
 } {
     table_name:notnull
 } -properties {
@@ -17,7 +17,12 @@ ad_page_contract {
 set package_id [ad_conn package_id]
 set title "View one Table Structure"
 set context_bar [list "$title"]
-set user_id [ad_verify_and_get_user_id]
+set user_id [ad_conn user_id]
 
 
-ad_return_template
\ No newline at end of file
+ad_return_template
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
