@@ -1,4 +1,4 @@
--- $Id: acs-sc-packages-create.sql,v 1.14 2004/03/04 14:52:46 jeffd Exp $
+-- $Id: acs-sc-packages-create.sql,v 1.15 2004/03/12 18:48:53 jeffd Exp $
 
 create or replace package acs_sc_contract
 as
@@ -152,7 +152,10 @@ as
    is
        v_contract_id	acs_sc_contracts.contract_id%TYPE;
    begin
-       v_contract_id := acs_object.new( object_type=>'acs_sc_contract');
+       v_contract_id := acs_object.new(
+		object_type => 'acs_sc_contract',
+		title => contract_name
+	);
 
        insert into acs_sc_contracts (
 	      contract_id,
@@ -250,7 +253,10 @@ as
    begin
 
        v_contract_id := acs_sc_contract.get_id(contract_name);
-       v_operation_id := acs_object.new (object_type=>'acs_sc_operation');
+       v_operation_id := acs_object.new (
+		object_type => 'acs_sc_operation',
+		title => operation_name
+	);
        v_operation_inputtype_id := acs_sc_msg_type.get_id(operation_inputtype);
        v_operation_outputtype_id := acs_sc_msg_type.get_id(operation_outputtype);
 
@@ -341,7 +347,10 @@ as
    is
        v_impl_id		acs_sc_impls.impl_id%TYPE;
    begin
-       v_impl_id := acs_object.new (object_type => 'acs_sc_implementation');
+       v_impl_id := acs_object.new (
+		object_type => 'acs_sc_implementation',
+		title => impl_pretty_name
+	);
 
        insert into acs_sc_impls (
 	      impl_id,
