@@ -6,7 +6,7 @@ ad_library {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Nov  7 22:52:39 2000
-    @cvs-id $Id: group-type-procs.tcl,v 1.5.10.2 2013/10/11 11:11:17 gustafn Exp $
+    @cvs-id $Id: group-type-procs.tcl,v 1.6.2.2 2015/10/28 09:38:34 gustafn Exp $
 
 }
 
@@ -31,14 +31,7 @@ namespace eval group_type {
 	    } 
 	    set user_id [ad_conn user_id]	
 	}
-	return [db_string group_exists_p {
-	    select case when exists (select 1 
-                                       from acs_objects o
-                                      where acs_permission.permission_p(o.object_id, :user_id, 'delete') = 'f'
-                                        and o.object_type = :group_type)
-                        then 0 else 1 end
-              from dual
-	}]
+	return [db_string group_exists_p {}]
     }
 
     
@@ -186,3 +179,9 @@ create table $table_name (
     }
 	
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
