@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Sun Nov 12 18:03:50 2000
-    @cvs-id $Id: delete-2.tcl,v 1.2.10.4 2013/09/09 16:44:19 gustafn Exp $
+    @cvs-id $Id: delete-2.tcl,v 1.4.2.1 2015/09/10 08:21:39 gustafn Exp $
 
 } {
     attribute_id:notnull,naturalnum,attribute_dynamic_p
@@ -29,7 +29,13 @@ if {$operation eq "Yes, I really want to delete this attribute"} {
 	}
     }
 } elseif { $return_url eq "" } {
-    set return_url one?[export_vars attribute_id]
+    set return_url [export_vars -base one attribute_id]
 }
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
