@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Nov  7 12:14:42 2000
-    @cvs-id $Id: enum-add.tcl,v 1.3.10.5 2014/07/29 11:23:56 gustafn Exp $
+    @cvs-id $Id: enum-add.tcl,v 1.5.2.1 2015/09/10 08:21:39 gustafn Exp $
 
 } {
     attribute_id:naturalnum,notnull
@@ -49,8 +49,14 @@ db_1row select_attr_name {
      where a.attribute_id = :attribute_id
 }
 
-set context [list [list one?[export_vars -url {attribute_id}] "One attribute"] "Add values"]
+set context [list [list [export_vars -base one {attribute_id}] "One attribute"] "Add values"]
 
 set export_vars [export_vars -form {attribute_id return_url}]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
