@@ -6,13 +6,13 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Sun Dec 10 14:48:44 2000
-    @cvs-id $Id: value-delete-2.tcl,v 1.2.10.4 2013/09/09 16:44:19 gustafn Exp $
+    @cvs-id $Id: value-delete-2.tcl,v 1.4.2.1 2015/09/10 08:21:40 gustafn Exp $
 
 } {
     attribute_id:naturalnum,notnull
     enum_value:trim,notnull
     { operation:trim "No, I want to cancel my request" } 
-    { return_url "one?[export_vars attribute_id]" }    
+    { return_url [export_vars -base one attribute_id] }    
 }
 
 if {$operation eq "Yes, I really want to delete this attribute value"} {
@@ -22,3 +22,9 @@ if {$operation eq "Yes, I really want to delete this attribute value"} {
 }
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
