@@ -6,12 +6,12 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Sun Dec 10 14:45:29 2000
-    @cvs-id $Id: value-delete.tcl,v 1.3.26.4 2013/09/09 16:44:19 gustafn Exp $
+    @cvs-id $Id: value-delete.tcl,v 1.5.2.1 2015/09/10 08:21:40 gustafn Exp $
 
 } {
     attribute_id:naturalnum,notnull
     enum_value:trim,notnull
-    { return_url "one?[export_vars attribute_id]" }    
+    { return_url [export_vars -base one attribute_id] }    
 } -properties {
     context:onevalue
     export_vars:onevalue
@@ -29,7 +29,13 @@ if { ![db_0or1row select_pretty_name {
     ad_script_abort
 }
 
-set context [list [list one?[export_vars attribute_id] "One attribute"] "Delete value"]
+set context [list [list [export_vars -base one attribute_id] "One attribute"] "Delete value"]
 set export_vars [export_vars -form {attribute_id enum_value return_url}]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
