@@ -6,7 +6,7 @@ ad_page_contract {
     @author Oumi Mehrotra (oumi@arsdigita.com)
 
     @creation-date 2001-02-23
-    @cvs-id $Id: change-join-policy-2.tcl,v 1.2.10.5 2013/10/10 21:00:46 gustafn Exp $
+    @cvs-id $Id: change-join-policy-2.tcl,v 1.4.2.1 2015/09/10 08:21:40 gustafn Exp $
 } {
     group_type:notnull
     default_join_policy:notnull
@@ -45,7 +45,13 @@ if {!$group_type_exists_p} {
 }
 
 if {$return_url eq ""} {
-    set return_url one?[export_vars group_type]
+    set return_url [export_vars -base one group_type]
 }
 
-ad_returnredirect $return_url
\ No newline at end of file
+ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
