@@ -6,7 +6,7 @@ ad_page_contract {
     @author Oumi Mehrotra (oumi@arsdigita.com)
 
     @creation-date 2001-02-23
-    @cvs-id $Id: change-join-policy.tcl,v 1.4.10.5 2013/10/10 21:00:46 gustafn Exp $
+    @cvs-id $Id: change-join-policy.tcl,v 1.6.2.2 2015/09/18 07:27:47 gustafn Exp $
 } {
     group_type:notnull
     {return_url ""}
@@ -23,7 +23,7 @@ ad_page_contract {
 
 set context [list \
         [list "[ad_conn package_url]admin/group-types/" "Group types"] \
-	[list "one?[export_vars group_type]" "One type"] \
+	[list [export_vars -base one group_type] "One type"] \
 	"Edit default join policy"]
 
 if { ![db_0or1row select_pretty_name {
@@ -42,6 +42,11 @@ if {$dynamic_p != "t" } {
 }
 
 set possible_join_policies [list open "needs approval" closed]
-set QQreturn_url [ad_quotehtml $return_url]
-set QQgroup_type [ad_quotehtml $group_type]
-ad_return_template
\ No newline at end of file
+set QQreturn_url [ns_quotehtml $return_url]
+set QQgroup_type [ns_quotehtml $group_type]
+ad_return_template
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
