@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Wed Nov  8 18:29:11 2000
-    @cvs-id $Id: delete-2.tcl,v 1.5.10.4 2013/09/09 16:44:19 gustafn Exp $
+    @cvs-id $Id: delete-2.tcl,v 1.7.2.2 2015/10/27 23:01:34 gustafn Exp $
 
 } {
     group_type
@@ -24,7 +24,7 @@ ad_page_contract {
 
 if { $operation ne "Yes, I really want to delete this group type" } {
     if { $return_url eq "" } {
-	ad_returnredirect "one?[export_vars {group_type}]"
+	ad_returnredirect [export_vars -base one {group_type}]
     } else {
 	ad_returnredirect $return_url
     }
@@ -42,14 +42,7 @@ if { ![db_0or1row select_type_info {
     set package_name $group_type
 }
     
-if { [db_string package_exists {
-    select case when exists (select 1 
-                               from user_objects o
-                              where o.object_type='PACKAGE' 
-                                and o.object_name = upper(:package_name))
-           then 1 else 0 end
-      from dual
-}] } {
+if { [db_string package_exists {}] } {
     lappend plsql [list "package_drop" [db_map package_drop]]
 } else {
     set package_name ""
@@ -61,13 +54,7 @@ lappend plsql [list "delete_rel_types" [db_map delete_rel_types]]
 # Remove the group_type
 lappend plsql [list "delete_group_type" [db_map delete_group_type]]
 
-if { [db_string type_exists {
-    select case when exists (select 1 from acs_object_types t where t.object_type = :group_type)
-                then 1
-                else 0
-           end
-      from dual
-}] } {
+if { [db_string type_exists {}] } {
     lappend plsql [list "drop_type" [db_map drop_type]]
 }
 
@@ -115,3 +102,9 @@ db_transaction {
 package_object_view_reset $group_type
 
 ad_returnredirect $return_url 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
