@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Wed Nov  8 18:22:04 2000
-    @cvs-id $Id: delete.tcl,v 1.3.26.4 2013/09/09 16:44:20 gustafn Exp $
+    @cvs-id $Id: delete.tcl,v 1.5.2.2 2015/10/27 23:01:34 gustafn Exp $
 
 } {
     group_type:notnull
@@ -30,7 +30,7 @@ ad_page_contract {
 
 set context [list \
          [list "[ad_conn package_url]admin/group-types/" "Group types"] \
-         [list one?[export_vars -url {group_type}] "One group type"] \
+         [list [export_vars -base one {group_type}] "One group type"] \
          "Delete group type"]
 
 if { ![db_0or1row select_pretty_name {
@@ -42,13 +42,7 @@ if { ![db_0or1row select_pretty_name {
     return
 }
 
-set subtypes_exist_p [db_string number_subtypes {
-    select case when exists (select 1 
-                               from acs_object_types t
-                              where t.supertype = :group_type) 
-                then 1 else 0 end
-      from dual
-}]
+set subtypes_exist_p [db_string number_subtypes {}]
 
 if { $subtypes_exist_p } {
     set return_url "[ad_conn url]?[ad_conn query]"
@@ -68,14 +62,7 @@ if { $subtypes_exist_p } {
 }
 
 # Now let's check if any relationship types depend on this group type
-set rel_types_depend_p [db_string rel_type_exists_p {
-    select case when exists (select 1 
-                               from acs_rel_types t
-                              where t.object_type_one = :group_type
-                                 or t.object_type_two = :group_type)
-                then 1 else 0 end
-      from dual
-}]
+set rel_types_depend_p [db_string rel_type_exists_p {}]
 
 if { $rel_types_depend_p } {
     set return_url "[ad_conn url]?[ad_conn query]"
@@ -114,3 +101,9 @@ set relations_to_this_type [util_commify_number [db_string relations_to_this_typ
 }]]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
