@@ -5,7 +5,7 @@ ad_page_contract {
 
     @author rhs@mit.edu
     @creation-date 2000-12-04
-    @cvs-id $Id: new.tcl,v 1.5 2011/04/15 11:43:48 emmar Exp $
+    @cvs-id $Id: new.tcl,v 1.5.6.2 2015/10/27 23:01:35 gustafn Exp $
 } {
     { object_type:trim "" }
     { pretty_name:trim "" }
@@ -71,20 +71,12 @@ if { [template::form is_valid group_type] } {
 Please back up and choose another.</li>"
     } else {
 	# let's make sure the names are unique
-	if { [db_string pretty_name_unique {
-	    select case when exists (select 1 from acs_object_types t where t.pretty_name = :pretty_name)
-                    then 1 else 0 end
-	  from dual
-	}] } {
+	if { [db_string pretty_name_unique {}] } {
 	    incr exception_count
 	    append exception_text "<li> The specified pretty name, $pretty_name, already exists. Please enter another </li>"
 	}
 
-	if { [db_string pretty_name_unique {
-	    select case when exists (select 1 from acs_object_types t where t.pretty_plural = :pretty_plural)
-                    then 1 else 0 end
-	  from dual
-	}] } {
+	if { [db_string pretty_name_unique {}] } {
 	    incr exception_count
 	    append exception_text "<li> The specified pretty plural, $pretty_plural, already exists. Please enter another </li>"
 	}
@@ -103,3 +95,9 @@ Please back up and choose another.</li>"
 }
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
