@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Wed Nov  8 18:02:15 2000
-    @cvs-id $Id: one.tcl,v 1.5.4.1 2014/10/03 16:33:48 antoniop Exp $
+    @cvs-id $Id: one.tcl,v 1.7.2.2 2015/10/27 23:01:35 gustafn Exp $
 
 } {
     group_type:notnull
@@ -47,22 +47,7 @@ set context [list [list "[ad_conn package_url]admin/group-types/" [_ acs-subsite
 # Pull out the first 25 groups of this type. If there are more, we'll
 # offer a link to display them all. Alphabetize the first 25 groups
 
-db_multirow groups groups_select {
-    select my_view.group_name, my_view.group_id, rownum as num 
-    from (select /*+ ORDERED */ DISTINCT  g.group_name, g.group_id
-           from acs_objects o, groups g,
-                application_group_element_map app_group, 
-                all_object_party_privilege_map perm
-          where perm.object_id = g.group_id
-            and perm.party_id = :user_id
-            and perm.privilege = 'read'
-            and g.group_id = o.object_id
-            and o.object_type = :group_type
-            and app_group.package_id = :package_id
-            and app_group.element_id = g.group_id
-          order by lower(g.group_name)) my_view 
-    where rownum <= 26
-}
+db_multirow groups groups_select {}
 
 # Select out all the attributes for groups of this type
 db_multirow -extend {one_attribute_url} attributes attributes_select {
@@ -77,7 +62,7 @@ db_multirow -extend {one_attribute_url} attributes attributes_select {
        and t.object_type = a.ancestor_type
     order by type_level 
 } {
-    set one_attribute_url [export_vars -url -base "../attributes/one" {attribute_id return_url}]
+    set one_attribute_url [export_vars -base "../attributes/one" {attribute_id return_url}]
 }
 
 
@@ -94,8 +79,14 @@ db_multirow allowed_relations relations_select {
 # See if we need to offer a link to add a rel type
 set more_relation_types_p [rel_types::additional_rel_types_p -group_type $group_type]
 
-set add_group_url [export_vars -url -base "../parties/new" {{party_type $group_type} {add_with_rel_type composition_rel} return_url}]
+set add_group_url [export_vars -base "../parties/new" {{party_type $group_type} {add_with_rel_type composition_rel} return_url}]
 
-set add_attribute_url [export_vars -url -base "../attributes/add" {{object_type $group_type} return_url}]
+set add_attribute_url [export_vars -base "../attributes/add" {{object_type $group_type} return_url}]
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
