@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Sun Dec 10 16:40:11 2000
-    @cvs-id $Id: rel-type-remove.tcl,v 1.3.26.4 2013/09/09 16:44:20 gustafn Exp $
+    @cvs-id $Id: rel-type-remove.tcl,v 1.5.2.1 2015/09/10 08:21:41 gustafn Exp $
 
 } {
     group_rel_type_id:naturalnum,notnull
@@ -31,6 +31,12 @@ if { ![db_0or1row select_info {
 }
 
 set export_vars [export_vars -form {group_rel_type_id return_url}]
-set context [list [list "[ad_conn package_url]admin/group-types/" "Group types"] [list one?[export_vars {group_type}] "One type"] "Remove relation type"]
+set context [list [list "[ad_conn package_url]admin/group-types/" "Group types"] [list [export_vars -base one {group_type}] "One type"] "Remove relation type"]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
