@@ -6,9 +6,9 @@ ad_page_contract {
     @author Oumi Mehrotra (oumi@arsdigita.com)
 
     @creation-date 2001-02-23
-    @cvs-id $Id: change-join-policy.tcl,v 1.3 2002/09/06 21:49:59 jeffd Exp $
+    @cvs-id $Id: change-join-policy.tcl,v 1.4.2.2 2015/09/18 07:27:48 gustafn Exp $
 } {
-    group_id:integer,notnull
+    group_id:naturalnum,notnull
     {return_url ""}
 } -properties {
     context:onevalue
@@ -44,5 +44,10 @@ db_1row group_info {
 }
 
 set possible_join_policies [list open "needs approval" closed]
-set QQreturn_url [ad_quotehtml $return_url]
-ad_return_template
\ No newline at end of file
+set QQreturn_url [ns_quotehtml $return_url]
+ad_return_template
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
