@@ -7,7 +7,7 @@ ad_page_contract {
     
     @author mbryzek@arsdigita.com
     @creation-date Thu Jan  4 11:02:15 2001
-    @cvs-id $Id: constraints-create-2.tcl,v 1.2.10.5 2014/08/05 09:49:23 gustafn Exp $
+    @cvs-id $Id: constraints-create-2.tcl,v 1.4.2.1 2015/09/10 08:21:41 gustafn Exp $
 
 } {
     group_id:notnull,naturalnum
@@ -22,13 +22,19 @@ if {$operation eq "yes"} {
     if { $return_url eq "" } {
 	# Setup return_url to send up back to the group admin page
 	# when we're all done
-	set return_url "[ad_conn package_url]/admin/groups/one?[export_vars group_id]"
+	set return_url [export_vars -base [ad_conn package_url]/admin/groups/one group_id]
     }
-    ad_returnredirect "../rel-segments/new?[export_vars {group_id rel_type return_url}]"
+    ad_returnredirect [export_vars -base ../rel-segments/new {group_id rel_type return_url}]
 } else {
     if { $return_url eq "" } {
-	set return_url "one?[export_vars group_id]"
+	set return_url [export_vars -base one group_id]
     }
     ad_returnredirect $return_url
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
