@@ -7,7 +7,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Thu Jan  4 10:54:36 2001
-    @cvs-id $Id: constraints-create.tcl,v 1.3.26.5 2014/08/05 09:49:23 gustafn Exp $
+    @cvs-id $Id: constraints-create.tcl,v 1.5.2.2 2015/10/28 09:38:35 gustafn Exp $
 
 } {
     group_id:notnull,naturalnum
@@ -20,16 +20,17 @@ ad_page_contract {
     group_name:onevalue
 }
 
-set context [list [list "[ad_conn package_url]admin/groups/" "Groups"] [list one?[export_vars group_id] "One Group"] "Add constraint"]
+set context [list [list "[ad_conn package_url]admin/groups/" "Groups"] [list [export_vars -base one group_id] "One Group"] "Add constraint"]
 set export_vars [export_vars -form {group_id rel_type return_url}]
 
-db_1row select_props {
-    select acs_group.name(:group_id) as group_name,
-           t.pretty_name as rel_type_pretty_name
-      from acs_object_types t
-     where t.object_type = :rel_type
-}
+db_1row select_props {}
 
 ad_return_template
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
