@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Fri Dec  8 14:41:36 2000
-    @cvs-id $Id: delete-2.tcl,v 1.2.10.5 2014/07/29 11:23:56 gustafn Exp $
+    @cvs-id $Id: delete-2.tcl,v 1.4.2.1 2015/09/10 08:21:42 gustafn Exp $
 
 } {
     group_id:naturalnum,notnull
@@ -25,13 +25,19 @@ if {$operation eq "Yes, I really want to delete this group"} {
 	set group_type [group::delete $group_id]
     }
     if { $return_url eq "" && $group_type ne "" } {
-	set return_url "../group-types/one?[export_vars group_type]"
+	set return_url [export_vars -base ../group-types/one group_type]
     }
 } else {
     if { $return_url eq "" } {
-	set return_url "one?[export_vars group_id]"
+	set return_url [export_vars -base one group_id]
     }
 }
 
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
