@@ -21,7 +21,7 @@
 #
 # @author oumi@arsdigita.com
 # @creation-date 2001-2-6
-# @cvs-id $Id: elements-by-rel-type.tcl,v 1.3.4.1 2013/09/06 12:06:49 gustafn Exp $
+# @cvs-id $Id: elements-by-rel-type.tcl,v 1.6.2.1 2015/09/10 08:21:42 gustafn Exp $
 
 set user_id [ad_conn user_id]
 set admin_p [permission::permission_p -object_id $group_id -privilege "admin"]
@@ -67,7 +67,13 @@ db_multirow -extend {elements_display_url relations_add_url} rels relations_quer
     set role_pretty_name [lang::util::localize $role_pretty_name]
     set role_pretty_plural [lang::util::localize $role_pretty_plural]    
 
-    set elements_display_url [export_vars -url -base "elements-display" {group_id rel_type}]
-    set relations_add_url [export_vars -url -base "../relations/add" {group_id rel_type {return_url $return_url_enc}}]
+    set elements_display_url [export_vars -base "elements-display" {group_id rel_type}]
+    set relations_add_url [export_vars -base "../relations/add" {group_id rel_type {return_url $return_url}}]
 
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
