@@ -1,14 +1,14 @@
 # /packages/acs-subsite/www/admin/groups/elements-display.tcl
 
-if { (![info exists group_id] || $group_id eq "") } {
+if { ![info exists group_id] || $group_id eq "" } {
     error "Group must be specified"
 }
 
-if { (![info exists rel_type] || $rel_type eq "") } {
+if { ![info exists rel_type] || $rel_type eq "" } {
     error "Rel type must be specified"
 }
 
-if { (![info exists return_url_enc] || $return_url_enc eq "") } {
+if { ![info exists return_url_enc] || $return_url_enc eq "" } {
     # Default return url to the current page
     set return_url_enc [ad_urlencode "[ad_conn url]?[ad_conn query]"]
 }
@@ -33,16 +33,7 @@ if {$admin_p} {
 
 # Pull out all the relations of the specified type
 
-db_1row rel_type_info {
-    select object_type as ancestor_rel_type
-      from acs_object_types
-     where supertype = 'relationship'
-       and object_type in (
-               select object_type from acs_object_types
-               start with object_type = :rel_type
-               connect by object_type = prior supertype
-           )
-}
+db_1row rel_type_info {}
 
 set extra_tables ""
 set extra_where_clauses ""
@@ -72,7 +63,7 @@ order by lower(element_name)
 
 # Build the member state dimensional slider
 
-set base_url [ad_conn package_url]admin/groups/elements-display?[export_vars {group_id rel_type}]
+set base_url [export_vars -base [ad_conn package_url]admin/groups/elements-display {group_id rel_type}]
 
 template::multirow create possible_member_states \
 	val label url
@@ -84,3 +75,9 @@ foreach state [group::possible_member_states] {
 	    $state $state $base_url&member_state=[ad_urlencode $state]
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
