@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Thu Dec  7 18:09:49 2000
-    @cvs-id $Id: index.tcl,v 1.4 2011/04/18 17:24:30 emmar Exp $
+    @cvs-id $Id: index.tcl,v 1.4.6.1 2015/09/10 08:21:42 gustafn Exp $
 
 } {
     {view_by "group_type"}
@@ -41,3 +41,9 @@ db_1row subsite_info {
 set intro_text [lang::util::localize [_ acs-subsite.Currently_the_instance_name_has_the_following_groups]]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
