@@ -6,9 +6,9 @@ ad_page_contract {
     @author Michael Bryzek (mbryzek@arsdigita.com)
 
     @creation-date 2000-12-05
-    @cvs-id $Id: one.tcl,v 1.6.10.3 2014/07/29 11:23:56 gustafn Exp $
+    @cvs-id $Id: one.tcl,v 1.8.2.1 2015/09/10 08:21:42 gustafn Exp $
 } {
-    group_id:naturalnum,notnull
+    group_id:integer,notnull
 } -properties {
     context:onevalue
     group_id:onevalue
@@ -77,3 +77,9 @@ if {[apm_package_installed_p categories]} {
 }
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
