@@ -7,7 +7,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Jan  2 12:23:02 2001
-    @cvs-id $Id: rel-type-remove.tcl,v 1.3.26.6 2014/07/29 11:23:56 gustafn Exp $
+    @cvs-id $Id: rel-type-remove.tcl,v 1.5.2.2 2015/10/28 09:38:36 gustafn Exp $
 
 } {
     group_rel_id:naturalnum,notnull
@@ -19,13 +19,7 @@ ad_page_contract {
     export_vars:onevalue
 }
 
-if { ![db_0or1row select_info {
-    select g.rel_type, g.group_id, acs_object.name(g.group_id) as group_name,
-           t.pretty_name as rel_pretty_name
-      from acs_object_types t, group_rels g
-     where g.group_rel_id = :group_rel_id
-       and t.object_type = g.rel_type
-}] } {
+if { ![db_0or1row select_info {}] } {
     ad_return_error "Relation already removed." "Please back up and reload"
     return
 }
@@ -33,6 +27,12 @@ if { ![db_0or1row select_info {
 permission::require_permission -object_id $group_id -privilege admin
 
 set export_vars [export_vars -form {group_rel_id return_url}]
-set context [list [list "[ad_conn package_url]admin/groups/" "Groups"] [list one?[export_vars {group_id}] "One group"] "Remove relation type"]
+set context [list [list "[ad_conn package_url]admin/groups/" "Groups"] [list [export_vars -base one {group_id}] "One group"] "Remove relation type"]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
