@@ -2,7 +2,7 @@ ad_page_contract {
     @author Mark Dettinger (mdettinger@arsdigita.com)
     @author Michael Steigman (michael@steigman.net)
     @creation-date 2000-10-24
-    @cvs-id $Id: index.tcl,v 1.9 2011/04/19 21:22:47 emmar Exp $
+    @cvs-id $Id: index.tcl,v 1.9.6.1 2015/09/10 08:21:43 gustafn Exp $
 } {
 }
 
@@ -71,3 +71,9 @@ ad_form -name add_host_node_mapping -form {
 } -after_submit {
     ad_returnredirect index
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
