@@ -5,7 +5,7 @@ ad_page_contract {
     @author Michael Bryzek (mbryzek@arsdigita.com)
 
     @creation-date August 15, 2000
-    @cvs-id $Id: index.tcl,v 1.19 2011/04/15 09:50:52 emmar Exp $
+    @cvs-id $Id: index.tcl,v 1.19.6.2 2015/09/10 08:21:37 gustafn Exp $
 } {
 } -properties {
     context:onevalue
@@ -17,7 +17,7 @@ ad_page_contract {
 }
 
 array set this_node [site_node::get -url [ad_conn url]]
-set title "$this_node(instance_name) [_ acs-subsite.Administration]"
+set title "Subsite [_ acs-subsite.Administration]: $this_node(instance_name)"
 
 set acs_admin_url [apm_package_url_from_key "acs-admin"]
 array set acs_admin_node [site_node::get -url $acs_admin_url]
@@ -25,3 +25,9 @@ set acs_admin_name $acs_admin_node(instance_name)
 set sw_admin_p [permission::permission_p -party_id [ad_conn user_id] -object_id $acs_admin_node(object_id) -privilege admin]
 
 set convert_subsite_p [expr { [llength [apm::get_package_descendent_options [ad_conn package_key]]] > 0 }]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
