@@ -4,10 +4,16 @@ ad_page_contract {
 
     @author Yonatan Feldman (yon@arsdigita.com)
     @creation-date August 15, 2000
-    @cvs-id $Id: alphabetical-index.tcl,v 1.6 2011/04/18 17:24:30 emmar Exp $
+    @cvs-id $Id: alphabetical-index.tcl,v 1.6.6.1 2015/09/10 08:21:43 gustafn Exp $
 
 } {}
 
 set doc(title) "Object Type Alphabetical Index"
 set context [list "Object Type Alphabetical Index"]
 db_multirow alpha_object_types object_type_in_alphabetical_order {}
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
