@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author Yonatan Feldman (yon@arsdigita.com)
     @creation-date August 13, 2000
-    @cvs-id $Id: index.tcl,v 1.6 2011/04/18 17:24:30 emmar Exp $
+    @cvs-id $Id: index.tcl,v 1.6.6.1 2015/09/10 08:21:43 gustafn Exp $
 
 } {}
 
@@ -12,3 +12,9 @@ set doc(title) "Object Type Hierarchical Index"
 set context [list "Object Type Hierarchical Index"]
 
 set object_type_hierarchy [acs_object_type_hierarchy]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
