@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author Yonantan Feldman (yon@arsdigita.com)
     @creation-date August 13, 2000
-    @cvs-id $Id: one.tcl,v 1.7.12.1 2013/08/27 12:20:37 gustafn Exp $
+    @cvs-id $Id: one.tcl,v 1.11.2.1 2015/09/10 08:21:43 gustafn Exp $
 
 } {
     object_type:notnull
@@ -22,12 +22,12 @@ set context [list [list index "Object Type Index"] "Details for type $pretty_nam
 
 set page "[acs_object_type_hierarchy -object_type $object_type]"
 
-append page "
+append page [subst {
 <p>
 <b>Information</b>:
- <ul>
-<li>Pretty Name: [lang::util::localize $pretty_name]</li>
-<li>Pretty Plural: [lang::util::localize $pretty_plural]</li>
+<ul>
+  <li>Pretty Name: [lang::util::localize $pretty_name]</li>
+  <li>Pretty Plural: [lang::util::localize $pretty_plural]</li>
   <li>Abstract: [ad_decode $abstract_p "f" "False" "True"]</li>
   <li>Dynamic: [ad_decode $dynamic_p "f" "False" "True"]</li>
   [ad_decode $table_name "" "" "<li>Table Name: $table_name</li>"]
@@ -35,23 +35,25 @@ append page "
   [ad_decode $name_method "" "" "<li>Name Method: $name_method</li>"]
   [ad_decode $type_extension_table "" "" "<li>Helper Table: $type_extension_table</li>"]
   [ad_decode $package_name "" "" "<li>Package Name: $package_name</li>"]
- </ul>"
+</ul>
+}]
 
 set i 0
-set body "
-    <table border=0 cellpadding=5 cellspacing=5>
+set body [subst {
+    <table cellpadding="5" cellspacing="5">
      <tr>
-      <th align=left>Attribute Name</th>
-      <th align=left>Pretty Name</th>
-      <th align=left>Pretty Plural</th>
-      <th align=left>Datatype</th>
-      <th align=left>Default Value</th>
-      <th align=left>Minimum Number of Values</th>
-      <th align=left>Maximum Number of Values</th>
-      <th align=left>Storage</th>
-      <th align=left>Table Name</th>
-      <th align=left>Column Name</th>
-     </tr>"
+      <th>Attribute Name</th>
+      <th>Pretty Name</th>
+      <th>Pretty Plural</th>
+      <th>Datatype</th>
+      <th>Default Value</th>
+      <th>Minimum Number of Values</th>
+      <th>Maximum Number of Values</th>
+      <th>Storage</th>
+      <th>Table Name</th>
+      <th>Column Name</th>
+    </tr>
+}]    
 
 db_foreach attribute {
     select attribute_name,
@@ -90,34 +92,25 @@ append body "
 	append page "
 <p>
 <b>Attributes</b>:
- <ul>
 $body
- </ul>"
+"
     }
 
 if { ([info exists table_name] && $table_name ne "") } {
 
-    set body [db_string table_comment "select comments from user_tab_comments where table_name = '[string toupper $table_name]'" -default ""]
+    set body [db_string table_comment {} -default ""]
 
-    append body "
-    <table border=0 cellpadding=5 cellspacing=5>
+    append body [subst {
+    <table border="0" cellpadding="5" cellspacing="5">
      <tr>
-      <th align=left>Type</th>
-      <th align=left>Name</th>
-      <th align=left>Comment</th>
-     </tr>"
+      <th>Type</th>
+      <th>Name</th>
+      <th>Comment</th>
+     </tr>
+    }]
 
     set i 0
-    db_foreach attribute_comment "
-	select utc.column_name,
-	       utc.data_type,
-               ucc.comments
-	  from user_tab_columns utc,
-               user_col_comments ucc
-	 where utc.table_name = '[string toupper $table_name]'
-           and utc.table_name = ucc.table_name(+)
-           and utc.column_name = ucc.column_name(+)
-    " {
+    db_foreach attribute_comment {} {
 	incr i
 	append body "
      <tr>
@@ -131,41 +124,27 @@ if { ([info exists table_name] && $table_name ne "") } {
     </table>"
 
     if { $i > 0 } {
-	append page "
-<p>
-<b>Table Attributes</b>:
- <ul>
-$body
- </ul>"
+	append page [subst {<p><b>Table Attributes</b>:<p>$body\n}]
     }
 }
 
 set i 0
 set body ""
-db_foreach package_index {
-    select replace (replace (text, ' ', '&nbsp;'), chr(9), '&nbsp;&nbsp;&nbsp;&nbsp;') as text
-      from user_source
-     where lower(name) = :package_name
-       and type = 'PACKAGE BODY'
-     order by line
-} {
+db_foreach package_index {} {
     incr i
-    append body "$text"
+    append body [subst {
+	<pre class="code">[ns_quotehtml $text]</pre>
+	<p>
+    }]
 }
 
 if { $i > 0 } {
-    append page "
-<p>
-<b>Methods</b>:
- <ul>
-  <pre>
-   <code>
-$body
-   </code>
-  </pre>
- </ul>"
+    append page [subst {<p><b>SQL Functions</b>:<p>$body}]
 }
 
-append page "
-</ul>
-"
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
