@@ -6,11 +6,11 @@ ad_page_contract {
 
     @author oumi@arsdigita.com
     @creation-date 2000-02-07
-    @cvs-id $Id: new.tcl,v 1.6.10.7 2014/08/05 09:49:24 gustafn Exp $
+    @cvs-id $Id: new.tcl,v 1.9.2.2 2015/10/28 09:38:36 gustafn Exp $
 
 } {
     party_type:notnull
-    { party_type_exact_p t }
+    { party_type_exact_p:boolean t }
     { party_id:naturalnum "" }
     { party.email ""}
     { return_url "" }
@@ -41,16 +41,7 @@ db_1row group_info {
 }
 
 # We assume the group is on side 1... 
-db_1row rel_type_info {
-    select object_type as ancestor_rel_type
-      from acs_object_types
-     where supertype = 'relationship'
-       and object_type in (
-               select object_type from acs_object_types
-               start with object_type = :add_with_rel_type
-               connect by object_type = prior supertype
-           )
-}
+db_1row rel_type_info {}
 
 set create_p [group::permission_p -privilege create $add_to_group_id]
 
@@ -196,7 +187,12 @@ if { [template::form is_valid add_party] } {
     foreach group_rel_type $group_rel_type_list {
 	lassign $group_rel_type next_group_id next_rel_type
 	lappend return_url_list \
-		"../relations/add?group_id=$next_group_id&rel_type=[ad_urlencode $next_rel_type]&party_id=$party_id&allow_out_of_scope_p=t"
+	    [export_vars -base "../relations/add" {
+		{group_id $next_group_id}
+		{rel_type $next_rel_type}
+		party_id
+		{allow_out_of_scope_p t}
+	    }]
     }
 
     # Add the original return_url as the last one in the list
@@ -210,3 +206,9 @@ if { [template::form is_valid add_party] } {
 
 ad_return_template
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
