@@ -7,7 +7,7 @@ ad_page_contract {
     @author Oumi Mehrotra (oumi@arsdigita.com)
 
     @creation-date 2001-02-06
-    @cvs-id $Id: one.tcl,v 1.4.26.2 2014/07/29 11:23:57 gustafn Exp $
+    @cvs-id $Id: one.tcl,v 1.5.2.2 2015/10/28 09:38:36 gustafn Exp $
 } {
     party_id:naturalnum,notnull
 } -properties {
@@ -34,12 +34,7 @@ ad_page_contract {
 # Select out the party name and the party's object type. Note we can
 # use 1row because the validate filter above will catch missing parties
 
-db_1row party_info {
-    select acs_object.name(:party_id) as party_name,
-           object_type as party_type
-      from acs_objects
-     where object_id = :party_id
-}
+db_1row party_info {}
 
 ### This page redirects to different pages for groups or rel_segments.
 ### We have to check whether the party_type is a type of group or rel_segment.
@@ -71,3 +66,9 @@ attribute::multirow \
 	-object_type $party_type \
 	$party_id
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
