@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Thu Jan  4 11:20:37 2001
-    @cvs-id $Id: constraints-redirect.tcl,v 1.2.10.4 2013/09/09 16:44:22 gustafn Exp $
+    @cvs-id $Id: constraints-redirect.tcl,v 1.4.2.1 2015/09/10 08:21:44 gustafn Exp $
 
 } {
     segment_id:naturalnum,notnull
@@ -20,8 +20,14 @@ if {$operation eq "yes"} {
     ad_returnredirect "constraints/new?rel_segment=$segment_id&[export_vars return_url]"
 } else {
     if { $return_url eq "" } {
-	set return_url "one?[export_vars segment_id]"
+	set return_url [export_vars -base one segment_id]
     }
     ad_returnredirect $return_url
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
