@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Fri Dec 15 11:27:27 2000
-    @cvs-id $Id: delete-2.tcl,v 1.4.10.5 2013/09/09 16:44:22 gustafn Exp $
+    @cvs-id $Id: delete-2.tcl,v 1.6.2.2 2015/10/28 09:38:36 gustafn Exp $
 
 } {
     constraint_id:naturalnum,notnull
@@ -25,7 +25,7 @@ if {$operation eq "Yes, I really want to delete this constraint"} {
 	if { [db_0or1row select_segment_id {
 	    select c.rel_segment as segment_id from rel_constraints c where c.constraint_id = :constraint_id
 	}] } {
-	    set return_url "../one?[export_vars {segment_id}]"
+	    set return_url [export_vars -base ../one {segment_id}]
 	}
     }
 
@@ -44,15 +44,19 @@ if {$operation eq "Yes, I really want to delete this constraint"} {
         ad_script_abort
     }
     
-    db_exec_plsql delete_constraint {
-	begin rel_constraint.del(constraint_id => :constraint_id); end;
-    }
+    db_exec_plsql delete_constraint {}
     db_release_unused_handles
 
 } elseif { $return_url eq "" } {
     # if we're not deleting, redirect to the constraint page
-    set return_url one?[export_vars constraint_id]
+    set return_url [export_vars -base one constraint_id]
 }
 
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
