@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Dec 12 11:23:12 2000
-    @cvs-id $Id: delete-2.tcl,v 1.2.10.5 2014/07/29 11:23:57 gustafn Exp $
+    @cvs-id $Id: delete-2.tcl,v 1.4.2.1 2015/09/10 08:21:44 gustafn Exp $
 
 } {
     segment_id:naturalnum,notnull
@@ -27,7 +27,7 @@ if {$operation eq "Yes, I really want to delete this segment"} {
 	    select s.group_id from rel_segments s where s.segment_id = :segment_id
 	} -default ""]
 	if { $group_id ne "" } {
-	    set return_url "../groups/one?[export_vars group_id]"
+	    set return_url [export_vars -base ../groups/one group_id]
 	}
     }
 
@@ -38,8 +38,14 @@ if {$operation eq "Yes, I really want to delete this segment"} {
 } 
 
 if { $return_url eq "" } {
-    set return_url "one?[export_vars {segment_id}]"
+    set return_url [export_vars -base one {segment_id}]
 }
 
 ad_returnredirect $return_url
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
