@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Dec 12 11:23:12 2000
-    @cvs-id $Id: delete.tcl,v 1.3.26.6 2014/07/29 11:23:57 gustafn Exp $
+    @cvs-id $Id: delete.tcl,v 1.5.2.1 2015/09/10 08:21:44 gustafn Exp $
 
 } {
     segment_id:naturalnum,notnull
@@ -31,7 +31,13 @@ db_1row select_segment_info {
 set export_vars [export_vars -form {segment_id}]
 set context [list \
      [list "[ad_conn package_url]admin/rel-segments/" "Relational segments"] \
-     [list one?[export_vars segment_id] "One segment"] \
+     [list [export_vars -base one segment_id] "One segment"] \
      "Remove segment"]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
