@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Tue Dec 12 17:52:03 2000
-    @cvs-id $Id: elements.tcl,v 1.5.22.5 2014/07/29 11:23:57 gustafn Exp $
+    @cvs-id $Id: elements.tcl,v 1.7.2.2 2015/10/28 09:38:36 gustafn Exp $
 
 } {
     segment_id:naturalnum,notnull
@@ -24,20 +24,20 @@ ad_page_contract {
     }
 }
 
-db_1row select_segment_info {
-    select s.segment_name, s.group_id,
-           acs_rel_type.role_pretty_plural(r.role_two) as role_pretty_plural
-      from rel_segments s, acs_rel_types r
-     where s.segment_id = :segment_id
-       and s.rel_type = r.rel_type
-}
+db_1row select_segment_info {}
 
 # The role pretty names can be message catalog keys that need
 # to be localized before they are displayed
 set role_pretty_plural [lang::util::localize $role_pretty_plural]    
 
-set context [list [list "[ad_conn package_url]admin/rel-segments/" "Relational segments"] [list one?[export_vars {segment_id}] "One segment"] "Elements"]
+set context [list [list "[ad_conn package_url]admin/rel-segments/" "Relational segments"] [list [export_vars -base one {segment_id}] "One segment"] "Elements"]
 
 # Expects segment_id, segment_name, group_id, role to be passed in 
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
