@@ -7,10 +7,10 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Wed Dec 13 20:00:25 2000
-    @cvs-id $Id: new-3.tcl,v 1.4.10.6 2014/07/29 11:23:57 gustafn Exp $
+    @cvs-id $Id: new-3.tcl,v 1.7.2.2 2015/10/28 09:38:36 gustafn Exp $
 
 } {
-    group_id:naturalnum,notnull
+    group_id:integer,notnull
     segment_name:notnull
     rel_type:notnull
     { return_url "" }
@@ -54,19 +54,20 @@ db_transaction {
 # Now let's offer to walk the user through the process of creating
 # constraints it there are any other segments
 
-if { ![db_string segments_exists_p {
-    select case when exists 
-                   (select 1 from rel_segments s where s.segment_id <> :segment_id)
-           then 1 else 0 end
-      from dual
-}] } {
+if { ![db_string segments_exists_p {}] } {
     # No more segments... can't create constraints
     ad_returnredirect $return_url
     return
 }
 
 
-set context [list [list "[ad_conn package_url]admin/rel-segments/" "Relational segments"] [list one?[export_vars segment_id] "One segment"] "Create constraints"]
+set context [list [list "[ad_conn package_url]admin/rel-segments/" "Relational segments"] [list [export_vars -base one segment_id] "One segment"] "Create constraints"]
 set export_vars [export_vars -form {segment_id return_url}]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
