@@ -6,10 +6,10 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Mon Dec 11 13:51:21 2000
-    @cvs-id $Id: new.tcl,v 1.3.10.6 2014/07/29 11:23:57 gustafn Exp $
+    @cvs-id $Id: new.tcl,v 1.6.2.2 2015/10/28 09:38:36 gustafn Exp $
 
 } {
-    group_id:naturalnum,notnull
+    group_id:integer,notnull
     { rel_type:trim "" }
     { return_url "" }
 } -properties {
@@ -31,7 +31,7 @@ set subsite_group_id [application_group::group_id_from_package_id]
 
 # If the user has specified a rel_type, redirect to new-2
 if { $rel_type ne "" } {
-    ad_returnredirect new-2?[export_vars {group_id rel_type return_url}]
+    ad_returnredirect [export_vars -base new-2 {group_id rel_type return_url}]
     ad_script_abort
 } 
 
@@ -41,19 +41,14 @@ set context [list [list "" "Relational segments"] "Add segment"]
 
 set export_vars [export_vars -form {group_id return_url}]
 # Select out all relationship types
-db_multirow rel_types select_relation_types {
-    select t.pretty_name, t.object_type as rel_type,
-    replace(lpad(' ', (level - 1) * 4), ' ', '&nbsp;') as indent
-    from acs_object_types t
-    where t.object_type not in (select s.rel_type from rel_segments s where s.group_id = :group_id)
-    connect by prior t.object_type = t.supertype
-    start with t.object_type in ('membership_rel', 'composition_rel')
-    order by lower(t.pretty_name) desc
-}
+db_multirow rel_types select_relation_types {}
 
-db_1row select_basic_info {
-    select acs_group.name(:group_id) as group_name
-      from dual
-}
+db_1row select_basic_info {}
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
