@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Sun Nov 12 18:05:09 2000
-    @cvs-id $Id: add-2.tcl,v 1.1.1.1.28.1 2014/07/29 11:23:57 gustafn Exp $
+    @cvs-id $Id: add-2.tcl,v 1.2.2.1 2015/09/10 08:21:45 gustafn Exp $
 
 } {
     constraint_id:naturalnum,notnull
@@ -23,3 +23,9 @@ db_dml update_rel_type_mapping {
 }
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
