@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Sun Nov 12 18:27:08 2000
-    @cvs-id $Id: new.tcl,v 1.4.4.4 2013/09/09 16:44:23 gustafn Exp $
+    @cvs-id $Id: new.tcl,v 1.5.2.2 2015/10/28 09:38:37 gustafn Exp $
 
 } {
     { return_url "" }
@@ -15,16 +15,16 @@ ad_page_contract {
 }
 
 
-db_multirow supertypes select_supertypes {
-    select replace(lpad(' ', (level - 1) * 4), ' ', '&nbsp;') || t.pretty_name as name,
-           t.object_type
-      from acs_object_types t
-   connect by prior t.object_type = t.supertype
-     start with t.object_type in ('membership_rel','composition_rel')
-}
+db_multirow supertypes select_supertypes {}
 
 set context [list [list "[ad_conn package_url]admin/rel-types/" [_ acs-subsite.Relationship_Types]] [_ acs-subsite.Create_relation_type]]
 
 set export_vars [export_vars -form {return_url}]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
