@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Fri Jan 12 20:52:33 2001
-    @cvs-id $Id: rels-list.tcl,v 1.2.26.4 2013/09/09 16:44:23 gustafn Exp $
+    @cvs-id $Id: rels-list.tcl,v 1.4.2.2 2015/10/28 09:38:37 gustafn Exp $
 
 } {
     rel_type:notnull
@@ -19,7 +19,7 @@ ad_page_contract {
 set user_id [ad_conn user_id]
 set package_id [ad_conn package_id]
 
-set context [list [list "" "Relationship types"] [list one?[export_vars rel_type] "One type"] "Relations"]
+set context [list [list "" "Relationship types"] [[export_vars -base one rel_type] "One type"] "Relations"]
 
 if { ![db_0or1row select_pretty_name {
     select t.pretty_name as rel_type_pretty_name
@@ -30,17 +30,12 @@ if { ![db_0or1row select_pretty_name {
     return
 }
 
-db_multirow rels rels_select {
-    select r.rel_id, acs_object.name(r.object_id_one) || ' and ' || acs_object.name(r.object_id_two) as name
-      from acs_rels r, acs_object_party_privilege_map perm,
-           app_group_distinct_rel_map m
-     where perm.object_id = r.rel_id
-       and perm.party_id = :user_id
-       and perm.privilege = 'read'
-       and r.rel_type = :rel_type
-       and m.rel_id = r.rel_id
-       and m.package_id = :package_id
-     order by lower(name)
-}
+db_multirow rels rels_select {}
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
