@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Mon Dec 11 11:30:53 2000
-    @cvs-id $Id: delete-2.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: delete-2.tcl,v 1.2.12.2 2015/10/28 09:38:38 gustafn Exp $
 
 } {
     role:notnull
@@ -15,13 +15,10 @@ ad_page_contract {
 }
 
 
-if { [string eq $operation "Yes, I really want to delete this role"] } {
+if {$operation eq "Yes, I really want to delete this role"} {
     db_transaction {
-	if { [catch {db_exec_plsql drop_role {begin acs_rel_type.drop_role(:role);end;}} errmsg] } {
-	    if { [db_string role_used_p {
-		select case when exists (select 1 from acs_rel_types where role_one = :role or role_two = :role) then 1 else 0 end
-		from dual
-	    }] } {
+	if { [catch {db_exec_plsql drop_role {}} errmsg] } {
+	    if { [db_string role_used_p {}] } {
 		ad_return_complaint 1 "<li> The role \"$role\" is still in use. You must remove all relationship types that use this role before you can remove this role."
 		return
 	    } else {
@@ -33,3 +30,9 @@ if { [string eq $operation "Yes, I really want to delete this role"] } {
 }
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
