@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Mon Dec 11 11:30:53 2000
-    @cvs-id $Id: delete.tcl,v 1.2.26.4 2013/09/09 16:44:23 gustafn Exp $
+    @cvs-id $Id: delete.tcl,v 1.4.2.1 2015/09/10 08:21:46 gustafn Exp $
 
 } {
     role:notnull
@@ -17,7 +17,7 @@ ad_page_contract {
     export_vars:onevalue
 }
 
-set context [list [list "../" "Relationship types"] [list "" "Roles"] [list one?[export_vars role] "One role"] "Delete role"]
+set context [list [list "../" "Relationship types"] [list "" "Roles"] [[export_vars -base one role] "One role"] "Delete role"]
 
 set export_vars [export_vars -form {role return_url}]
 
@@ -26,3 +26,9 @@ set pretty_name [db_string select_role_pretty_name {
 }]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
