@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author mbryzek@arsdigita.com
     @creation-date Mon Dec 11 10:52:35 2000
-    @cvs-id $Id: new.tcl,v 1.4 2002/09/18 12:16:43 jeffd Exp $
+    @cvs-id $Id: new.tcl,v 1.5.14.1 2015/09/10 08:21:46 gustafn Exp $
 
 } {
     { role:trim "" }
@@ -52,10 +52,14 @@ if { [template::form is_valid role_form] } {
     }
 
     db_transaction {
-	db_exec_plsql create_role {
-	    begin acs_rel_type.create_role(role => :role, pretty_name => :pretty_name, pretty_plural => :pretty_plural); end;
-	}
+        rel_types::create_role -pretty_name $pretty_name -pretty_plural $pretty_plural -role $role
     }
     ad_returnredirect $return_url
     ad_script_abort
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
