@@ -7,14 +7,14 @@ ad_page_contract {
 
     @author mbryzek@mit.edu
     @creation-date 2000-12-11
-    @cvs-id $Id: add.tcl,v 1.10.10.8 2014/09/10 08:19:36 gustafn Exp $
+    @cvs-id $Id: add.tcl,v 1.15.2.2 2015/10/28 09:38:38 gustafn Exp $
 } {
-    group_id:naturalnum,notnull
+    group_id:integer,notnull
     rel_type:notnull
-    {party_id:naturalnum ""}
-    { exact_p "f" }
+    { party_id:naturalnum "" }
+    { exact_p:boolean "f" }
     { return_url "" }
-    { allow_out_of_scope_p "f" }
+    { allow_out_of_scope_p:boolean "f" }
 } -properties {
     context:onevalue
     role_pretty_name:onevalue
@@ -60,22 +60,7 @@ db_1row group_info {
 }
 
 # We assume the group is on side 1... 
-db_1row rel_type_info {
-    select t.object_type_two, t.role_two as role, 
-           acs_rel_type.role_pretty_name(t.role_two) as role_pretty_name,
-           acs_object_type.pretty_name(t.object_type_two) as object_type_two_name,
-           ancestor_rel_types.object_type as ancestor_rel_type
-      from acs_rel_types t, acs_object_types obj_types, 
-           acs_object_types ancestor_rel_types
-     where t.rel_type = :rel_type
-       and t.rel_type = obj_types.object_type
-       and ancestor_rel_types.supertype = 'relationship'
-       and ancestor_rel_types.object_type in (
-               select object_type from acs_object_types
-               start with object_type = :rel_type
-               connect by object_type = prior supertype
-           )
-}
+db_1row rel_type_info {}
 
 # The role pretty names can be message catalog keys that need
 # to be localized before they are displayed
@@ -126,15 +111,19 @@ set party_type $object_type_two
 set party_type_exact_p f
 set add_to_group_id $group_id
 set add_with_rel_type $rel_type
-set add_party_url "[ad_conn package_url]admin/parties/new?[export_vars {add_to_group_id add_with_rel_type party_type party_type_exact_p return_url}]"
+set add_party_url [export_vars -base [ad_conn package_url]admin/parties/new {add_to_group_id add_with_rel_type party_type party_type_exact_p return_url}]
 
 # Build a url used to select an existing party from the system (as opposed
 # to limiting the selection to parties on the current subsite).
-set add_out_of_scope_url "[ad_conn url]?[export_vars -exclude allow_out_of_scope_p $export_var_list]&allow_out_of_scope_p=t"
+set saved_allow_out_of_scope_p $allow_out_of_scope_p
+set allow_out_of_scope_p t
+set add_out_of_scope_url [export_vars -base [ad_conn url] $export_var_list]
 
 # Build a url used to select an existing party from the current subsite
-set add_in_scope_url "[ad_conn url]?[export_vars -exclude allow_out_of_scope_p $export_var_list]&allow_out_of_scope_p=f"
+set allow_out_of_scope_p f
+set add_in_scope_url [export_vars -base [ad_conn url] $export_var_list]
 
+set allow_out_of_scope_p $saved_allow_out_of_scope_p
 
 # We select out all parties that are to not already belong to the
 # specified group with the specified rel_type. Note that we take
@@ -159,7 +148,7 @@ if { [template::form is_valid add_relation] } {
 	ad_script_abort
     }
     if { $return_url eq "" } { 
-	set return_url one?[export_vars rel_id]
+	set return_url [export_vars -base one rel_id]
     }
     ad_returnredirect $return_url
     ad_script_abort
@@ -232,3 +221,9 @@ if {$party_id ne ""} {
 }
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
