@@ -5,9 +5,9 @@ ad_page_contract {
     
     @author Michael Bryzek (mbryzek@arsdigita.com)
     @creation-date 2000-12-16
-    @cvs-id $Id: remove-2.tcl,v 1.1.1.1 2001/03/13 22:59:26 ben Exp $
+    @cvs-id $Id: remove-2.tcl,v 1.4.2.1 2015/09/10 08:21:47 gustafn Exp $
 } {
-    rel_id:integer,notnull
+    rel_id:naturalnum,notnull
     { operation "" }
     { return_url "" }
 } -validate {
@@ -18,7 +18,7 @@ ad_page_contract {
     }
 }
 
-if { [string eq $operation "Yes, I really want to remove this relation"] } {
+if {$operation eq "Yes, I really want to remove this relation"} {
     db_transaction {
 	relation_remove $rel_id
     } on_error {
@@ -26,12 +26,18 @@ if { [string eq $operation "Yes, I really want to remove this relation"] } {
 	ad_script_abort
     }
 } else {
-    if { [empty_string_p $return_url] } {
+    if { $return_url eq "" } {
 	# redirect to the relation by default, if we haven't deleted it
-	set return_url "one?[ad_export_vars rel_id]"
+	set return_url [export_vars -base one rel_id]
     }
 }
 
 db_release_unused_handles
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
