@@ -3,7 +3,7 @@ ad_page_contract {
 
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-05-28
-    @cvs-id $Id: application-new.tcl,v 1.5.10.2 2014/07/30 15:33:22 michaela Exp $
+    @cvs-id $Id: application-new.tcl,v 1.6.2.1 2015/09/10 08:21:47 gustafn Exp $
 }
 
 set page_title "New Application"
@@ -73,3 +73,9 @@ ad_form -name application -cancel_url . -form {
     ad_returnredirect .
     ad_script_abort
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
