@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author rhs@mit.edu
     @creation-date 2000-09-09
-    @cvs-id $Id: delete.tcl,v 1.4.26.3 2014/08/05 09:49:24 gustafn Exp $
+    @cvs-id $Id: delete.tcl,v 1.6.2.1 2015/09/10 08:21:47 gustafn Exp $
 
 } {
     expand:integer,multiple
@@ -18,4 +18,10 @@ if {$root_id == $node_id} {
 
 site_node::delete -node_id $node_id
 
-ad_returnredirect ".?[export_vars -url {expand:multiple root_id}]"
+ad_returnredirect [export_vars -base . {expand:multiple root_id}]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
