@@ -6,7 +6,7 @@ ad_page_contract {
 
     @author Bryan Quinn (bquinn@arsdigita.com)
     @creation-date Mon Oct 23 14:58:57 2000
-    @cvs-id $Id: instance-delete.tcl,v 1.9.10.2 2014/09/03 19:06:23 gustafn Exp $
+    @cvs-id $Id: instance-delete.tcl,v 1.10.2.2 2015/09/18 07:27:48 gustafn Exp $
 
 } {
     package_id:naturalnum
@@ -49,8 +49,14 @@ db_transaction {
 	where package_id = :package_id
     } -default 0]} {
 	ad_return_error "Error Deleting Instance" "The following error was returned:
-	<blockquote><pre>[ad_quotehtml $errmsg]</pre></blockquote>"
+	<blockquote><pre>[ns_quotehtml $errmsg]</pre></blockquote>"
     }
 }
 	
 ad_returnredirect ${parent}admin/site-map
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
