@@ -4,7 +4,7 @@ ad_page_contract {
 
   @author rhs@mit.edu
   @creation-date 2000-09-12
-  @cvs-id $Id: mount.tcl,v 1.3.22.2 2014/07/29 11:23:58 gustafn Exp $
+  @cvs-id $Id: mount.tcl,v 1.5.2.1 2015/09/10 08:21:47 gustafn Exp $
 } {
   node_id:naturalnum,notnull
   {expand:integer,multiple {}}
@@ -20,15 +20,21 @@ set context [list [list . "Site Map"] $page_title]
 set site_node_url [site_node::get_url -node_id $node_id]
 
 db_multirow -extend { url } unmounted packages_unmounted_select {} {
-    set url "mount-2?[export_vars { expand:multiple root_id node_id package_id }]"
+    set url [export_vars -base mount-2 { expand:multiple root_id node_id package_id }]
 }
 
 db_multirow -extend { url } mounted packages_mounted_select {} {
-    set url "mount-2?[export_vars { expand:multiple root_id node_id package_id}]"
+    set url [export_vars -base mount-2 { expand:multiple root_id node_id package_id}]
 }
 
 db_multirow -extend { url } singleton packages_singleton_select {} {
-    set url "mount-2?[export_vars { expand:multiple root_id node_id package_id}]"
+    set url [export_vars -base mount-2 { expand:multiple root_id node_id package_id}]
 }
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
