@@ -4,7 +4,7 @@ ad_page_contract {
 
     @author rhs@mit.edu
     @creation-date 2000-09-12
-    @cvs-id $Id: unmount.tcl,v 1.3.26.3 2014/07/29 11:23:58 gustafn Exp $
+    @cvs-id $Id: unmount.tcl,v 1.5.2.1 2015/09/10 08:21:48 gustafn Exp $
 
 } {
     node_id:naturalnum,notnull
@@ -14,4 +14,10 @@ ad_page_contract {
 
 site_node::unmount -node_id $node_id
 
-ad_returnredirect ".?[export_vars -url {expand:multiple root_id}]"
+ad_returnredirect [export_vars -base . {expand:multiple root_id}]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
