@@ -3,12 +3,12 @@ ad_page_contract {
 
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-08-07
-    @cvs-id $Id: group-join.tcl,v 1.1 2003/09/21 19:20:30 lars Exp $
+    @cvs-id $Id: group-join.tcl,v 1.2.18.1 2015/09/10 08:21:37 gustafn Exp $
 } {
     {return_url "."}
 }
 
-ad_maybe_redirect_for_registration
+auth::require_login
 
 set user_id [ad_conn user_id]
 set group_id [application_group::group_id_from_package_id]
@@ -35,3 +35,9 @@ if { !$member_p } {
 }
 
 ad_returnredirect $return_url
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
