@@ -3,14 +3,14 @@ ad_page_contract {
     
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-06-02
-    @cvs-id $Id: index.tcl,v 1.18.10.3 2014/07/29 10:56:35 gustafn Exp $
+    @cvs-id $Id: index.tcl,v 1.20.2.2 2015/09/10 08:21:48 gustafn Exp $
 } {
     {member_state "approved"}
-    {orderby "name,asc"}
+    {orderby:token "name,asc"}
     page:naturalnum,optional
 } -validate {
     member_state_valid -requires { member_state } {
-        if { [lsearch [group::possible_member_states] $member_state] == -1 } {
+        if { $member_state ni [group::possible_member_states] } {
             ad_complain "Invalid member_state"
         }
     }
@@ -223,3 +223,9 @@ db_multirow -extend {
     }
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
