@@ -3,7 +3,7 @@ ad_page_contract {
 
     @author Lars Pind (lars@collaboraid.biz)
     @creation-date 2003-06-02
-    @cvs-id $Id: user-new.tcl,v 1.10 2011/04/07 11:39:12 emmar Exp $
+    @cvs-id $Id: user-new.tcl,v 1.10.6.1 2015/09/10 08:21:49 gustafn Exp $
 } {
     email:trim
 }
@@ -81,3 +81,9 @@ set user_new_template [parameter::get -parameter "UserNewTemplate" -package_id $
 if {$user_new_template eq ""} {
     set user_new_template "/packages/acs-subsite/lib/user-new"
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
