@@ -4,7 +4,7 @@ ad_page_contract {
 
   @author rhs@mit.edu
   @creation-date 2000-08-20
-  @cvs-id $Id: revoke.tcl,v 1.4.22.4 2014/07/29 11:23:59 gustafn Exp $
+  @cvs-id $Id: revoke.tcl,v 1.6.2.2 2015/10/28 09:38:39 gustafn Exp $
 } {
   object_id:naturalnum,notnull
   {revoke_list:multiple,optional {}}
@@ -14,7 +14,7 @@ ad_page_contract {
 permission::require_permission -object_id $object_id -privilege admin
 
 if {[llength $revoke_list] == 0} {
-  ad_returnredirect "./?[export_vars -url {object_id}]"
+  ad_returnredirect [export_vars -base ./ {object_id}]
   ad_script_abort
 }
 
@@ -26,7 +26,7 @@ set body [subst {
 
     <hr>
     Are you sure you want to remove the following entries from the access
-    control list of [db_string name {select acs_object.name(:object_id) from dual}]?
+    control list of [db_string name {}]?
     <ul>
 }]
 
@@ -34,7 +34,7 @@ foreach item $revoke_list {
     set party_id [lindex $item 0]
     set privilege [lindex $item 1]
     append body [subst {
-	<li>[db_string party_name {select acs_object.name(:party_id) from dual}]</li>
+	<li>[db_string party_name {}]</li>
     }]
 }
 
@@ -55,3 +55,9 @@ append body {
     </form>
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
