@@ -1,7 +1,7 @@
 ad_page_contract {
     Inform the user that his/her account is closed
 
-    @cvs-id $Id: account-closed.tcl,v 1.9 2011/02/10 15:17:01 daveb Exp $
+    @cvs-id $Id: account-closed.tcl,v 1.9.6.1 2015/09/10 08:21:51 gustafn Exp $
 } {
 
 }
@@ -10,3 +10,9 @@ set page_title [_ acs-subsite.Account_closed_title]
 
 set context [list [_ "acs-kernel.common_Register"]]
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
