@@ -14,10 +14,16 @@ array set auth_info [auth::authenticate \
                          -email [string trim $email] \
                          -password $password]
 
-if { [string equal $auth_info(auth_status) "ok"] } {
+if {$auth_info(auth_status) eq "ok"} {
     ad_returnredirect $return_url
     ad_script_abort
 } else {
     # Login problem - redirect to login form
     ad_returnredirect [export_vars -base /register { email return_url }]    
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
