@@ -3,13 +3,13 @@
 ad_page_contract {
     Logs a user out
 
-    @cvs-id $Id: logout.tcl,v 1.3 2003/10/16 20:44:58 lars Exp $
+    @cvs-id $Id: logout.tcl,v 1.4.12.1 2015/09/10 08:21:52 gustafn Exp $
 
 } {
     {return_url ""}
 }
 
-if { [empty_string_p $return_url] } {
+if { $return_url eq "" } {
     if { [permission::permission_p -object_id [subsite::get_element -element package_id] -party_id 0 -privilege read] } {
         set return_url [subsite::get_element -element url]
     } else {
@@ -22,3 +22,9 @@ db_release_unused_handles
 
 ad_returnredirect $return_url
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
