@@ -2,7 +2,7 @@ ad_page_contract {
     shows User A what User B has contributed to the community
     
     @param user_id defaults to currently logged in user if there is one
-    @cvs-id $Id: community-member.tcl,v 1.19.2.4 2014/08/05 09:49:26 gustafn Exp $
+    @cvs-id $Id: community-member.tcl,v 1.21.2.1 2015/09/10 08:21:52 gustafn Exp $
 } {
     {user_id:naturalnum ""}
 } -properties {
@@ -73,7 +73,7 @@ set bio [ad_text_to_html -- [person::get_bio -person_id $user_id]]
 
 # Do we show the portrait?
 set inline_portrait_state "none"
-set portrait_export_vars [export_vars -url {user_id}]
+set portrait_export_vars [export_vars {user_id}]
 
 if {[db_0or1row portrait_info "
 select i.width, i.height, cr.title, cr.description, cr.publish_date
@@ -112,3 +112,9 @@ set login_export_vars "return_url=[ns_urlencode [acs_community_member_url -user_
 set login_url [export_vars -base "/register/." { { return_url [ad_return_url]} }]
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
