@@ -3,7 +3,7 @@ ad_page_contract {
     @author rhs@mit.edu
     @author bquinn@arsidigta.com
     @creation-date 2000-09-09
-    @cvs-id $Id: index.tcl,v 1.7.8.7 2014/08/05 09:49:27 gustafn Exp $
+    @cvs-id $Id: index.tcl,v 1.9.2.1 2015/09/10 08:21:53 gustafn Exp $
     
 } {
     {expand:integer,multiple ""}
@@ -38,7 +38,7 @@ if {$new_parent ne ""} {
 set javascript "onload=\"javascript:document.check_checkbox()\""
 
 
-set parent_link ".?[export_vars -url {expand:multiple {root_id $parent_id}}]"
+set parent_link [export_vars -base . {expand:multiple {root_id $parent_id}}]
 
 set page_title "[ad_system_name] Site Map"
 set context [list $page_title]
@@ -47,7 +47,7 @@ set user_id [ad_conn user_id]
 
 db_foreach path_select {} {
     if {$node_id != $root_id && $admin_p == "t"} {
-        append head "<a href=\".?[export_vars -url {expand:multiple {root_id $node_id}}]\">"
+        append head "<a href=\"[export_vars -base . {expand:multiple {root_id $node_id}}]\">"
     }
     if {$name eq ""} {
 	append head "$obj_name:"
@@ -98,12 +98,11 @@ template::list::create \
                 </if>
 
 		<if @nodes.action_type@ eq "new_folder">
-		<a name="add" />
-		<form name=new_parent action=new>
-		@nodes.tree_indent;noquote@
+		<form name="new_parent" action="new">
+		<div>@nodes.tree_indent;noquote@
 		@nodes.action_form_part;noquote@
-		<input name=name type=text size=8 value=Untitled>
-		<input type=submit value=New>
+		<input name="name" type="text" size="8" value="Untitled">
+		<input type="submit" value="New"></div>
 		</form>
 		</if>
 	    }
@@ -112,19 +111,17 @@ template::list::create \
             html "align left"
 	    display_template {
 		<if @nodes.action_type@ eq "new_app">
-		<a name="new" />
-		<form name=new_application action=package-new>
-		<input name=instance_name type=text size=8 value="">
+		<form name="new_application" action="package-new">
+		<div><input name="instance_name" type="text" size="8" value="">
 		(@nodes.action_form_part;noquote@)
-		<input type=submit value=New>
+		<input type="submit" value="New"></div>
 		</form>
 		</if>
 		<if @nodes.action_type@ eq "rename_app">
-		<a name="rename" />
-		<form name=rename_application action=rename>
-		<input name=instance_name type=text value="@nodes.instance@">
+		<form name="rename_application" action="rename">
+		<div><input name="instance_name" type="text" value="@nodes.instance@">
 		(@nodes.action_form_part;noquote@)
-		<input type=submit value=Rename>
+		<input type="submit" value="Rename"></div>
 		</form>
 		</if>
 		<else>
@@ -150,33 +147,33 @@ db_foreach nodes_select {} {
     if { [lsearch -exact $open_nodes $parent_id] == -1 && $parent_id ne "" && $mylevel > 2 } { continue } 
         
     if {$directory_p == "t"} {
-	set add_folder_url "?[export_vars -url {expand:multiple root_id node_id {new_parent $node_id} {new_type folder}}]"
+	set add_folder_url [export_vars -base . {expand:multiple root_id node_id {new_parent $node_id} {new_type folder}}]
 	if {$object_id eq ""} {
-	    set mount_url "mount?[export_vars -url {expand:multiple root_id node_id}]"
-	    set new_app_url "?[export_vars -url {expand:multiple root_id {new_application $node_id}}]"
+	    set mount_url [export_vars -base mount {expand:multiple root_id node_id}]
+	    set new_app_url [export_vars -base . {expand:multiple root_id {new_application $node_id}}]
 	} else {
 	    # This makes sure you can't unmount the thing that is serving the page you're looking at.
 	    if {[ad_conn node_id] != $node_id} {
-		set unmount_url "unmount?[export_vars -url {expand:multiple root_id node_id}]"
+		set unmount_url [export_vars -base unmount {expand:multiple root_id node_id}]
 	    }
 	    
 	    # Add a link to control permissioning
 	    if {$object_admin_p} {
-		set permissions_url "../../permissions/one?[export_vars -url {object_id}]"
-		set rename_url "?[export_vars -url {expand:multiple root_id {rename_application $node_id}}]"
-		set delete_url "instance-delete?package_id=$object_id&root_id=$root_id"
+		set permissions_url [export_vars -base ../../permissions/one {object_id}]
+		set rename_url [export_vars -base . {expand:multiple root_id {rename_application $node_id}}]
+		set delete_url [export_vars -base instance-delete {{package_id $object_id} root_id}]
 	    }
 	    # Is the object a package?
 	    if {$package_id ne ""} {
 		if {$object_admin_p && ($parameter_count > 0)} {
-		    set parameters_url "[export_vars -base "/shared/parameters" { package_id {return_url {[ad_return_url]} } }]"
+		    set parameters_url [export_vars -base "/shared/parameters" { package_id {return_url {[ad_return_url]} } }]
 		}
 	    }
 	}
     }
     
     if {[ad_conn node_id] != $node_id && $n_children == 0 && $object_id eq ""} {
-	set delete_url "delete?[export_vars -url {expand:multiple root_id node_id}]"
+	set delete_url [export_vars -base delete {expand:multiple root_id node_id}]
     }
     
     # use the indent variable to hold current indent level we'll use it later to indent stuff at the end by the amount of the last node
@@ -219,7 +216,7 @@ db_foreach nodes_select {} {
 	set expand_url ""
     }
     
-    set name_url [export_vars -url {expand:multiple {root_id $node_id}}]
+    set name_url [export_vars {expand:multiple {root_id $node_id}}]
         
     set action_type 0
     set action_form_part ""
@@ -237,7 +234,7 @@ db_foreach nodes_select {} {
 	}
     } elseif {$rename_application == $node_id} {
 	set action_type "rename_app"
-	set action_form_part "[export_vars -form {expand:multiple root_id node_id rename_package_id}]"
+	set action_form_part [export_vars -form {expand:multiple root_id node_id rename_package_id}]
 	
     } else {}
     
@@ -245,25 +242,31 @@ db_foreach nodes_select {} {
 	set parent_id $new_parent
 	set node_type $new_type	
 	set action_type "new_folder"
-	set action_form_part "[export_vars -form {expand:multiple parent_id node_type root_id}]"
+	set action_form_part [export_vars -form {expand:multiple parent_id node_type root_id}]
     }
 
     multirow append nodes $node_id $expand_mode $expand_url $indent $name $name_url $object_name $url $package_pretty_name $action_type $action_form_part $add_folder_url $new_app_url $unmount_url $mount_url $rename_url $delete_url $parameters_url $permissions_url "" $view_p
 
 }
 
-#set new_app_form_part_1 "<p align=\"top\"><form name=new_application action=package-new><input type=hidden name=node_id value=$node(node_id)><input type=hidden name=root_id value=$node(node_id)><input type=hidden name=new_node_p value=t>[export_vars -form {expand:multiple}]<input name=node_name type=text size=8></p>"
+#set new_app_form_part_1 "<p align=\"top\"><form name="new_application" action="package-new"><input type="hidden" name="node_id" value="$node(node_id)>"<input type="hidden" name="root_id" value="$node(node_id)"><input type="hidden" name="new_node_p" value="t">[export_vars -form {expand:multiple}]<input name="node_name" type="text" size="8"></p>"
 
 #set new_app_form_part_2 "<p align=\"top\">[apm_application_new_checkbox]</p>"
-#set new_app_form_part_3 "<p align=\"top\"><input type=submit value=\"Mount Package\"></form></p>"
+#set new_app_form_part_3 "<p align=\"top\"><input type="submit" value=\"Mount Package\"></form></p>"
 #    multirow append nodes "" "" "" "" $new_app_form_part_1 "" "" "" $new_app_form_part_2 "" "" "" "" "" "" "" "" "" "" $new_app_form_part_3
 
 set services ""
 
 db_foreach services_select {} {
     if {$parameter_count > 0} {
-        append services "<li><a href=\"[export_vars -base "/shared/parameters" { package_id { return_url {[ad_return_url]} } }]\">$instance_name</a>"
+        append services "<li><a href=\"[export_vars -base /shared/parameters { package_id { return_url {[ad_return_url]} } }]\">$instance_name</a>"
     }
 } if_no_rows {
     append services "  <li>(none)\n"
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
