@@ -1,14 +1,13 @@
 ad_page_contract {
-    Displays form for currently logged in user to update his/her
- personal information
+    Displays form for currently logged in user to update his/her personal information
 
     @author Unknown
     @creation-date Unknown
-    @cvs-id $Id: basic-info-update.tcl,v 1.14.8.1 2014/08/05 09:49:27 gustafn Exp $
+    @cvs-id $Id: basic-info-update.tcl,v 1.16.2.2 2015/09/22 12:36:39 gustafn Exp $
 } {
     {return_url ""}
     {user_id:naturalnum ""}
-    {edit_p 0}
+    {edit_p:boolean 0}
     {message ""}
 }
 
@@ -29,3 +28,9 @@ if {$user_info_template eq ""} {
     set user_info_template "/packages/acs-subsite/lib/user-info"
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
