@@ -1,7 +1,7 @@
 ad_page_contract {
     Erases a portrait
 
-    @cvs-id $Id: erase.tcl,v 1.7.8.2 2014/08/05 09:49:27 gustafn Exp $
+    @cvs-id $Id: erase.tcl,v 1.9.2.1 2015/09/10 08:21:54 gustafn Exp $
 } {
     {return_url "" }
     {user_id:naturalnum ""}
@@ -26,7 +26,7 @@ set doc(title) [_ acs-subsite.Erase]
 if {$admin_p} {
     set context [list \
                      [list [ad_pvt_home] [ad_pvt_home_name]] \
-                     [list "./?[export_vars user_id]" [_ acs-subsite.User_Portrait]] \
+                     [list [export_vars -base ./ user_id] [_ acs-subsite.User_Portrait]] \
                      $doc(title)]
 } else {
     set context [list \
@@ -77,3 +77,9 @@ ad_form -name "portrait_erase" -export {user_id return_url} -form {} -on_submit
 }
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
