@@ -5,7 +5,7 @@ ad_library {
 
     @author Many others at ArsDigita and in the OpenACS community.
     @creation-date 2 April 1998
-    @cvs-id $Id: defs-procs.tcl,v 1.62.2.9 2014/09/10 18:17:20 gustafn Exp $
+    @cvs-id $Id: defs-procs.tcl,v 1.66.2.1 2015/09/10 08:21:56 gustafn Exp $
 }
 
 ad_proc -public ad_acs_version_no_cache {} {
@@ -139,7 +139,7 @@ ad_proc -public acs_community_member_url {
 } {
     @return the url for the community member page of a particular user
 } {
-    return "[acs_community_member_page]?[export_vars user_id]"
+    return [export_vars -base [acs_community_member_page] user_id]
 }
 
 ad_proc -public acs_community_member_link {
@@ -153,8 +153,8 @@ ad_proc -public acs_community_member_link {
         acs_user::get -user_id $user_id -array user
         set label "$user(first_names) $user(last_name)"
     }
-
-    return "<a href=\"[acs_community_member_url -user_id $user_id]\">$label</a>"
+    set href [acs_community_member_url -user_id $user_id]
+    return [subst {<a href="[ns_quotehtml $href]">$label</a>}]
 }
 
 ad_proc -deprecated ad_present_user {
@@ -196,8 +196,8 @@ ad_proc -public acs_community_member_admin_link {
             where person_id = :user_id
         } -default $user_id]
     }
-
-    return "<a href=\"[acs_community_member_admin_url -user_id $user_id]\">$label</a>"
+    set href [acs_community_member_admin_url -user_id $user_id]
+    return [subst {<a href="[ns_quotehtml $href]">$label</a>}]
 }
 
 ad_proc -deprecated ad_admin_present_user {
@@ -381,13 +381,13 @@ ad_proc -public ad_return_complaint {
 				-package_key "acs-tcl" \
 				-parameter "ReturnComplaint" \
 				-default "/packages/acs-tcl/lib/ad-return-complaint"]
-    ns_return 200 text/html [ad_parse_template \
+    ns_return 422 text/html [ad_parse_template \
                                  -params [list [list exception_count $exception_count] \
                                               [list exception_text $exception_text]] \
 				 $complaint_template]
 				 
     # raise abortion flag, e.g., for templating
-    set ::request_aborted [list 200 "Problem with Your Input"]
+    set ::request_aborted [list 422 "Problem with Your Input"]
 }
 
 
@@ -766,7 +766,7 @@ ad_proc -public ad_return_url {
 
     <pre>
     set return_url [ad_return_url]
-    set edit_link "edit?[export_vars item_id return_url]"
+    set edit_link [export_vars -base edit item_id return_url]
     </pre>
 
     Example setting a variable with extra_vars:
@@ -853,3 +853,9 @@ ad_proc -public ad_progress_bar_end {
     ns_write "<script type=\"text/javascript\">window.location='$url';</script>"
     ns_conn close
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
