@@ -3,7 +3,7 @@ ad_library {
 
     @author yon (yon@openforce.net)
     @creation-date 2002-03-15
-    @cvs-id $Id: membership-rel-procs.tcl,v 1.8 2007/01/10 21:22:12 gustafn Exp $
+    @cvs-id $Id: membership-rel-procs.tcl,v 1.8.12.1 2015/09/10 08:21:57 gustafn Exp $
 }
 
 namespace eval membership_rel {
@@ -110,3 +110,9 @@ namespace eval membership_rel {
     }
 
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
