@@ -1,7 +1,7 @@
 ad_library {
     Provides procedures to spit out the navigational parts of the site.
 
-    @cvs-id $Id: navigation-procs.tcl,v 1.30.2.4 2013/10/31 17:38:01 gustafn Exp $
+    @cvs-id $Id: navigation-procs.tcl,v 1.32.2.2 2015/09/18 07:33:49 gustafn Exp $
     @author philg@mit.edu
     @creation-date 11/5/98 (adapted originally from the Cognet server)     
 }
@@ -40,9 +40,9 @@ ad_proc -public ad_context_bar_html {
 
     set out {}
     foreach element [lrange $context 0 [llength $context]-2] { 
-        append out "<a href=\"[lindex $element 0]\">[lindex $element 1]</a> $separator "
+        append out [subst {<a href="[ns_quotehtml [lindex $element 0]]">[ns_quotehtml [lindex $element 1]]</a> $separator }]
     }
-    append out [lindex $context end]
+    append out [ns_quotehtml [lindex $context end]]
 
     return $out
 }
@@ -72,7 +72,7 @@ ad_proc ad_context_node_list {
             set node(instance_name) $node(name)
         }
 
-        set context [concat [list [list $node(url) [ad_quotehtml $node(instance_name)]]] $context]
+        set context [concat [list [list $node(url) [ns_quotehtml $node(instance_name)]]] $context]
 
         # We have the break here, so that 'from_node' itself is included
         if {$node_id eq $from_node} {
@@ -246,7 +246,7 @@ ad_proc -public ad_navbar args {
 } {
     set counter 0
     foreach arg $args {
-	lappend link_list "<a href=\"[lindex $arg 0]\">[lindex $arg 1]</a>"
+        lappend link_list [subst {<a href="[ns_quotehtml [lindex $element 0]]">[ns_quotehtml [lindex $element 1]]</a>}]
 	incr counter
     }
     if { $counter } {
@@ -267,9 +267,9 @@ ad_proc -public ad_choice_bar { items links values {default ""} } {
 
     foreach value $values {
 	if { $default eq $value  } {
-	        lappend return_list "<strong>[lindex $items $count]</strong>"
+	    lappend return_list "<strong>[lindex $items $count]</strong>"
 	} else {
-	        lappend return_list "<a href=\"[lindex $links $count]\">[lindex $items $count]</a>"
+	    lappend return_list [subst {<a href="[ns_quotehtml [lindex $links $count]]">[ns_quotehtml [lindex $items $count]]</a>}]
 	}
 
 	incr count
@@ -645,3 +645,9 @@ proc ad_menu_footer {{section ""}} {
     return $return_string
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
