@@ -4,7 +4,7 @@ ad_library {
 
     @creation-date 30 May 2000
     @author Jon Salz [jsalz@arsdigita.com]
-    @cvs-id $Id: request-processor-init.tcl,v 1.15.2.3 2014/09/10 18:17:20 gustafn Exp $
+    @cvs-id $Id: request-processor-init.tcl,v 1.17.2.2 2015/09/10 08:21:59 gustafn Exp $
 }
 
 # These procedures are dynamically defined at startup to alleviate
@@ -173,8 +173,15 @@ ad_after_server_initialization procs_register {
 	}
 
 	ns_log Notice "ns_register_proc $noinherit_switch [list $method $path rp_invoke_proc [list $proc_index $debug_p $arg_count $proc $arg]]"
-	eval ns_register_proc $noinherit_switch \
-		[list $method $path rp_invoke_proc [list $proc_index $debug_p $arg_count $proc $arg]]
+	ns_register_proc {*}$noinherit_switch \
+	    $method $path rp_invoke_proc [list $proc_index $debug_p $arg_count $proc $arg]
     }
 }
 
+
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
