@@ -5,7 +5,7 @@ ad_library {
 
     @author Jon Salz (jsalz@arsdigita.com)
     @creation-date 15 May 2000
-    @cvs-id $Id: request-processor-procs.tcl,v 1.113.2.31 2014/09/09 16:39:23 gustafn Exp $
+    @cvs-id $Id: request-processor-procs.tcl,v 1.118.2.7 2015/11/16 13:10:29 gustafn Exp $
 }
 
 #####
@@ -225,13 +225,13 @@ ad_proc -public ad_register_proc {
         # Shortcut to allow registering filter for all methods. Just
         # call ad_register_proc again, with each of the three methods.
         foreach method { GET POST HEAD } {
-                                          ad_register_proc -debug $debug -noinherit $noinherit $method $path $proc $arg
-                                      }
+            ad_register_proc -debug $debug -noinherit $noinherit $method $path $proc $arg
+        }
         return
     }
 
-    if {$method ni { GET POST HEAD }} {
-        error "Method passed to ad_register_proc must be one of GET, POST, or HEAD"
+    if {$method ni { GET POST HEAD PUT DELETE }} {
+        error "Method passed to ad_register_proc must be one of GET, POST, HEAD, PUT and DELETE"
     }
 
     set proc_info [list $method $path $proc $arg $debug $noinherit $description [info script]]
@@ -339,7 +339,7 @@ ad_proc -private rp_invoke_proc { conn argv } {
 ad_proc -private rp_finish_serving_page {} {
     global doc_properties
     if { [info exists doc_properties(body)] } {
-        rp_debug "Returning page:[info level [expr {[info level] - 1}]]: [ad_quotehtml [string range $doc_properties(body) 0 100]]"
+        rp_debug "Returning page:[info level [expr {[info level] - 1}]]: [ns_quotehtml [string range $doc_properties(body) 0 100]]"
         doc_return 200 text/html $doc_properties(body)
     }
 }
@@ -427,14 +427,14 @@ ad_proc -private rp_html_directory_listing { dir } {
     # Create the table header.
     set list "
 <table>
-<tr align=left><th>File</th><th>Size</th><th>Date</th></tr>
-<tr align=left><td colspan=3><a href=../>..</a></td></tr>
+<tr align='left'><th>File</th><th>Size</th><th>Date</th></tr>
+<tr align='left'><td colspan='3'><a href='../'>..</a></td></tr>
 "
 
     # Loop through the files, adding a row to the table for each.
     foreach file [lsort [glob -nocomplain $dir/*]] {
-        set tail [file tail $file]
-        set link "<a href=$tail>$tail</a>"
+        set tailHtml [ns_quotethml [file tail $file]]
+        set link "<a href=\"$tailHtml\">$tailHtml</a>"
 
         # Build the stat array containing information about the file.
         file stat $file stat
@@ -443,7 +443,7 @@ ad_proc -private rp_html_directory_listing { dir } {
         set time [clock format $mtime -format "%d-%h-%Y %H:%M"]
 
         # Write out the row.
-        append list "<tr align=left><td>$link</td><td>$size</td><td>$time</td></tr>\n"
+        append list "<tr align='left'><td>$link</td><td>$size</td><td>$time</td></tr>\n"
     }
     append list "</table>"
     return $list
@@ -488,6 +488,22 @@ ad_proc -private rp_serve_resource_file { path } {
     if { ![rp_file_can_be_public_p $path] } {
         ad_raise notfound
     }
+    set expireTime [parameter::get -package_id [ad_acs_kernel_id] -parameter ResourcesExpireInterval -default 0]
+    if {$expireTime != 0} {
+        if {![string is integer -strict $expireTime]} {
+            if {[regexp {^(\d)+d} $expireTime _ t]} {
+                set expireTime [expr {60*60*24*$t}]
+            } elseif {[regexp {^(\d)+h} $expireTime _ t]} {
+                set expireTime [expr {60*60*$t}]
+            } elseif {[regexp {^(\d)+m} $expireTime _ t]} {
+                set expireTime [expr {60*$t}]
+            } else {
+                ns_log error "invalid expire time '$expireTime' specified"
+                set expireTime 0
+            }
+        }
+        ns_setexpires $expireTime
+    }
     ns_returnfile 200 [ns_guesstype $path] $path
     return filter_return
 }
@@ -499,10 +515,11 @@ ad_proc -private rp_resources_filter { why } {
     maximize throughput for resource files.  We just ns_returnfile the file, no
     permissions are checked, the ad_conn structure is not initialized, etc.
 
-    There are two mapping possibilities:
+    There are three mapping possibilities:
 
     /resources/package-key/* maps to root/packages/package-key/www/resources/*
 
+    If that fails, we map to root/packages/acs-subsite/www/resources/*
     If that fails, we map to root/www/resources/*
 
     If the file doesn't exist we'll log an error and return filter_ok, which will allow
@@ -518,12 +535,17 @@ ad_proc -private rp_resources_filter { why } {
         return [rp_serve_resource_file $path]
     }
 
-    set path "$::acs::rootdir/www/resources/[join [lrange [ns_conn urlv] 1 end] /]"
+    set path $::acs::rootdir/www/[ns_conn url]
+    if { [file isfile $path] } {
+        return [rp_serve_resource_file $path]
+    }
+    
+    set path [acs_package_root_dir acs-subsite]/www/[ns_conn url]
     if { [file isfile $path] } {
         return [rp_serve_resource_file $path]
     } 
 
-    ns_log Error "rp_sources_filter: file \"$path\" does not exists trying to serve as a normal request"
+    ns_log Warning "rp_sources_filter: file \"$path\" does not exists trying to serve as a normal request"
     return filter_ok
 }
 
@@ -759,13 +781,12 @@ ad_proc rp_report_error {
 
     Writes an error to the connection.
 
-    @param message The message to write (pulled from <code>$errorInfo</code> if none is specified).
+    @param message The message to write (pulled from <code>$::errorInfo</code> if none is specified).
 
 } {
     if { ![info exists message] } {
-        global errorInfo
-        # We need 'message' to be a copy, because errorInfo will get overridden by some of the template parsing below
-        set message $errorInfo
+                # We need 'message' to be a copy, because errorInfo will get overridden by some of the template parsing below
+        set message $::errorInfo
     }
     set error_url "[ad_url][ad_conn url]?[export_entire_form_as_url_vars]"
     #    set error_file [template::util::url_to_file $error_url]
@@ -811,11 +832,7 @@ ad_proc rp_report_error {
 
     ns_return 500 text/html $rendered_page
 
-    set headers [ns_conn headers]
-    ns_log Error "[ns_conn method] http://[ns_set iget $headers host][ns_conn url]?[ns_conn query]
-referred by \"[ns_set iget $headers referer]\"
-$error_message"
-
+    ad_log error $error_message
 }
 
 ad_proc -private rp_path_prefixes {path} {
@@ -1231,7 +1248,7 @@ ad_proc -public ad_acs_kernel_id {} {
 ad_proc -public ad_conn {args} {
 
     Returns a property about the connection. See the <a
-    href="/doc/request-processor.html">request
+    href="/doc/request-processor">request
     processor documentation</a> for an (almost complete) list of allowable values. 
 
     <p>
