@@ -6,7 +6,7 @@ ad_library {
     @creation-date 16 Feb 2000
     @author Jon Salz (jsalz@arsdigita.com)
     @author Richard Li (richardl@arsdigita.com)
-    @cvs-id $Id: security-init.tcl,v 1.5 2008/12/23 12:23:00 gustafn Exp $
+    @cvs-id $Id: security-init.tcl,v 1.5.10.1 2015/09/10 08:21:59 gustafn Exp $
 
 }
 
@@ -39,3 +39,9 @@ proc sec_login_timeout {} "
     return \"[parameter::get -package_id [ad_acs_kernel_id] -parameter LoginTimeout -default 28800]\"
 "
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
