@@ -7,7 +7,7 @@ ad_library {
     @author Jon Salz (jsalz@arsdigita.com)
     @author Richard Li (richardl@arsdigita.com)
     @author Archit Shah (ashah@arsdigita.com)
-    @cvs-id $Id: security-procs.tcl,v 1.74.2.21 2014/10/19 19:46:13 gustafn Exp $
+    @cvs-id $Id: security-procs.tcl,v 1.78.2.5 2015/10/20 08:01:05 gustafn Exp $
 }
 
 namespace eval security {}
@@ -276,7 +276,7 @@ ad_proc -public ad_user_login {
     } elseif { $prev_user_id != $user_id } {
         # Hose the secure login token if this user is different 
         # from the previous one.
-        ad_set_cookie -max_age 0 ad_user_login_secure ""
+        ad_unset_cookie -secure t ad_user_login_secure
     }
     
     ns_log Debug "ad_user_login: Setting new ad_user_login cookie with max_age $max_age"
@@ -331,10 +331,10 @@ ad_proc -public ad_user_logout {} {
 } {
     set domain [parameter::get -parameter CookieDomain -package_id [ad_acs_kernel_id]]
 
-    ad_set_cookie -replace t -max_age 0 -domain $domain ad_session_id ""
-    ad_set_cookie -replace t -max_age 0 -domain $domain ad_secure_token ""
-    ad_set_cookie -replace t -max_age 0 -domain $domain ad_user_login ""
-    ad_set_cookie -replace t -max_age 0 -domain $domain ad_user_login_secure ""
+    ad_unset_cookie -domain $domain -secure t ad_session_id
+    ad_unset_cookie -domain $domain -secure t ad_secure_token
+    ad_unset_cookie -domain $domain -secure t ad_user_login
+    ad_unset_cookie -domain $domain -secure t ad_user_login_secure
 }
 
 ad_proc -public ad_check_password { 
@@ -550,12 +550,13 @@ ad_proc -private ad_login_page {} {
     Returns 1 if the page is used for logging in, 0 otherwise. 
 
 } {
-
     set url [ad_conn url]
-    if { [string match "*register/*" $url] || [string match "/index*" $url] || \
-             [string match "/index*" $url] || \
-             "/" eq $url || \
-             [string match "*password-update*" $url] } {
+    if { [string match "*register/*" $url]
+         || [string match "/index*" $url]
+         || [string match "/index*" $url]
+         || "/" eq $url
+         || [string match "*password-update*" $url]
+     } {
         return 1
     }
 
@@ -912,6 +913,9 @@ ad_proc -private __ad_verify_signature {
         if { $token_id eq "" } {
             ns_log Debug "__ad_verify_signature: Neither secret, nor token_id supplied"
             return 0
+        } elseif {![string is integer -strict $token_id]} {
+            ns_log Warning "__ad_verify_signature: token_id <$token_id> is not an integer"
+            return 0
         }
         set secret_token [sec_get_token $token_id]
 
@@ -983,7 +987,7 @@ ad_proc -public ad_get_signed_cookie {
     lassign $cookie_value value signature
     ns_log Debug "ad_get_signed_cookie: Got signed cookie $name with value $value, signature $signature."
 
-    if { [ad_verify_signature $value $signature] } {
+    if { [ad_verify_signature -secret $secret $value $signature] } {
         ns_log Debug "ad_get_signed_cookie: Verification of cookie $name OK"
         return $value
     }
@@ -1013,7 +1017,7 @@ ad_proc -public ad_get_signed_cookie_with_expr {
     }
 
     lassign $cookie_value value signature
-    set expr_time [ad_verify_signature_with_expr $value $signature]
+    set expr_time [ad_verify_signature_with_expr -secret $secret $value $signature]
 
     ns_log Debug "Security: Done calling get_cookie $cookie_value for $name; received $expr_time expiration, getting $value and $signature."
 
@@ -1027,7 +1031,9 @@ ad_proc -public ad_get_signed_cookie_with_expr {
 ad_proc -public ad_set_signed_cookie {
     {-replace f}
     {-secure f}
+    {-expire f}    
     {-discard f}
+    {-scriptable f}
     {-max_age ""}
     {-signature_max_age ""}
     {-domain ""}
@@ -1055,6 +1061,8 @@ ad_proc -public ad_set_signed_cookie {
 
     @param token_id allows the caller to specify a token_id.
 
+    @param scriptable allow access to the cookie from JavaScript
+
     @param value the value for the cookie. This is automatically
     url-encoded.
 
@@ -1075,10 +1083,18 @@ ad_proc -public ad_set_signed_cookie {
     }
 
     set cookie_value [ad_sign -secret $secret -token_id $token_id -max_age $signature_max_age $value]
-
     set data [ns_urlencode [list $value $cookie_value]]
 
-    ad_set_cookie -replace $replace -secure $secure -discard $discard -max_age $max_age -domain $domain -path $path $name $data
+    ad_set_cookie \
+        -replace $replace \
+        -secure $secure \
+        -discard $discard \
+        -scriptable $scriptable \
+        -expire $expire \
+        -max_age $max_age \
+        -domain $domain \
+        -path $path \
+        $name $data    
 }
 
 
@@ -1233,8 +1249,9 @@ ad_proc -private sec_lookup_property {
 } { 
 
     Used as a helper procedure for util_memoize to look up a
-    particular property from the database. Returns
-    [list $property_value $secure_p].
+    particular property from the database.
+
+    @return empty, when no property is recorded or a list containing property_value and secure_p
 
 } {
     if {
@@ -1272,7 +1289,7 @@ ad_proc -public ad_get_client_property {
     Looks up a property for a session. If $cache is true, will use the
     cached value if available. If $cache_only is true, will never
     incur a database hit (i.e., will only return a value if
-                          cached). If the property is secure, we must be on a validated session
+    cached). If the property is secure, we must be on a validated session
     over SSL.
 
     @param session_id controls which session is used
@@ -1293,7 +1310,7 @@ ad_proc -public ad_get_client_property {
     set cmd [list sec_lookup_property $id $module $name]
 
     if { $cache_only == "t" && ![util_memoize_cached_p $cmd] } {
-        return ""
+        return $default
     }
 
     if { $cache != "t" } {
@@ -1307,7 +1324,7 @@ ad_proc -public ad_get_client_property {
     lassign $property value secure_p
     
     if { $secure_p != "f" && ![security::secure_conn_p] } {
-        return ""
+        return $default
     }
 
     return $value
@@ -1349,30 +1366,38 @@ ad_proc -public ad_set_client_property {
         
         set last_hit [ns_time]
 
-        db_transaction {
+        if { $clob == "t" } {
 
-            # DRB: Older versions of this code did a delete/insert pair in an attempt
-            # to guard against duplicate insertions.  This didn't work if there was
-            # no value for this property in the table and two transactions ran in
-            # parallel.  The problem is that without an existing row the delete had
-            # nothing to lock on, thus allowing the two inserts to conflict.  This
-            # was discovered on a page built of frames, where the two requests from
-            # the browser spawned two AOLserver threads to service them.
+            db_transaction {
 
-            # Oracle doesn't allow a RETURNING clause on an insert with a
-            # subselect, so this code first inserts a dummy value if none exists
-            # (ensuring it does exist afterwards) then updates it with the real
-            # value.  Ugh.  
+                # DRB: Older versions of this code did a delete/insert pair in an attempt
+                # to guard against duplicate insertions.  This didn't work if there was
+                # no value for this property in the table and two transactions ran in
+                # parallel.  The problem is that without an existing row the delete had
+                # nothing to lock on, thus allowing the two inserts to conflict.  This
+                # was discovered on a page built of frames, where the two requests from
+                # the browser spawned two AOLserver threads to service them.
 
-            set clob_update_dml [db_map prop_update_dml_clob]
+                # Oracle doesn't allow a RETURNING clause on an insert with a
+                # subselect, so this code first inserts a dummy value if none exists
+                # (ensuring it does exist afterwards) then updates it with the real
+                # value.  Ugh.  
 
-            db_dml prop_insert_dml ""
+                set clob_update_dml [db_map prop_update_dml_clob]
 
-            if { $clob == "t" && $clob_update_dml ne "" } {
-                db_dml prop_update_dml_clob "" -clobs [list $value]
-            } else {
-                db_dml prop_update_dml ""
+                db_dml prop_insert_dml ""
+                
+                if { $clob_update_dml ne "" } {
+                    db_dml prop_update_dml_clob "" -clobs [list $value]
+                } else {
+                    db_dml prop_update_dml ""
+                }
             }
+        } else {
+            #
+            # Perform an upsert operation via stored procedure
+            #
+            db_exec_plsql prop_upsert {}
         }
     }
 
@@ -1393,7 +1418,7 @@ ad_proc -public security::https_available_p {} {
 
     @author Peter Marklund
 } {
-    return [expr {[get_https_port] ne ""}]
+    return [expr {[get_https_port] ni {"" 0}}]
 }
 
 ad_proc -public security::secure_conn_p {} { 
@@ -1694,8 +1719,8 @@ ad_proc -public security::locations {} {
     set host_post ""
 
     # set host_name
-    if {![regexp {(http://|https://)(.*?):(.*?)/?} [util_current_location] discard host_protocol host_name host_port]} {
-        regexp {(http://|https://)(.*?)/?} [util_current_location] discard host_protocol host_name
+    if {![regexp {(http://|https://)(.*?):(.*?)/?} [util_current_location] . host_protocol host_name host_port]} {
+        regexp {(http://|https://)(.*?)/?} [util_current_location] . host_protocol host_name
     }
 
     set driver_section [ns_driversection -driver $driver]
@@ -1704,7 +1729,7 @@ ad_proc -public security::locations {} {
     # not same as from config.tcl, may help with proxy issues etc
     set config_hostname [ns_config $driver_section hostname]
     if { $config_hostname ne $host_name } {
-        ns_log Warning "security::locations hostname '[ns_config $driver_section hostname]' from config.tcl does not match from util_current_location: $host_name"
+        ns_log notice "security::locations hostname '[ns_config $driver_section hostname]' from config.tcl does not match from util_current_location: $host_name"
     }
 
     # insecure locations
@@ -1762,7 +1787,7 @@ ad_proc -public security::locations {} {
                                       get_node_host_names "select host from host_node_map"]
     # fastest place for handling this special case:
     if { $config_hostname ne $host_name } {
-        ns_log Notice "security::locations adding $config_hostname since utl_current_location different than config.tcl."
+        #ns_log Notice "security::locations adding $config_hostname since utl_current_location different than config.tcl."
         lappend host_node_map_hosts_list $config_hostname
     }
     if { [llength $host_node_map_hosts_list] > 0 } {
