@@ -1,162 +1,13 @@
 ad_library {
     This is the table, dimensional bar and sort tools.
     an example of their use can be found in /acs-examples
-    @cvs-id $Id: table-display-procs.tcl,v 1.20.8.13 2014/09/09 17:34:33 gustafn Exp $
+    @cvs-id $Id: table-display-procs.tcl,v 1.23.2.4 2015/09/18 07:33:49 gustafn Exp $
 }
     
-# Dimensional selection bars.
-#
-ad_proc ad_dimensional {
-    option_list 
-    {url {}} 
-    {options_set ""} 
-    {optionstype url}
-} {
-    Generate an option bar as in the ticket system; 
-    <ul>
-      <li> option_list -- the structure with the option data provided 
-      <li> url -- url target for select (if blank we set it to ad_conn url).
-      <li> options_set -- if not provided defaults to [ns_getform], for hilite of selected options.
-      <li> optionstype -- only url is used now, was thinking about extending 
-            so we get radio buttons and a form since with a slow select updating one 
-            thing at a time would be stupid.
-    </ul>
-    
-    <p>
-    option_list structure is 
-    <pre>
-    { 
-        {variable "Title" defaultvalue
-            {
-                {value "Text" {key clause}}
-                ...
-            }
-        }
-        ...
-    }
 
-    an example:
 
-    set dimensional_list {
-        {visited "Last Visit" 1w {
-            {never "Never" {where "last_visit is null"}}
-            {1m "Last Month" {where "last_visit + 30 > sysdate"}}
-            {1w "Last Week" {where "last_visit + 7 > sysdate"}}
-            {1d "Today" {where "last_visit > trunc(sysdate)"}}
-        }}
-        ..(more of the same)..
-    }
-    </pre>
-} {
-    set html {}
 
-    if {$option_list eq ""} {
-        return
-    }
-
-    if {$options_set eq ""} {
-        set options_set [ns_getform]
-    }
-    
-    if {$url eq ""} {
-        set url [ad_conn url]
-    }
-
-    append html "<table border=\"0\" cellspacing=\"0\" cellpadding=\"3\" width=\"100%\">\n<tr>\n"
-
-    foreach option $option_list { 
-        append html " <th style=\"background-color: #ECECEC\">[lindex $option 1]</th>\n"
-    }
-    append html "</tr>\n"
-
-    append html "<tr>\n"
-
-    foreach option $option_list { 
-        append html " <td align=\"center\">\["
-
-        # find out what the current option value is.
-        # check if a default is set otherwise the first value is used
-        set option_key [lindex $option 0]
-        set option_val {}
-        if { $options_set ne ""} {
-            set option_val [ns_set get $options_set $option_key]
-        }
-        if { $option_val eq "" } {
-            set option_val [lindex $option 2]
-        }
-        
-        set first_p 1
-        foreach option_value [lindex $option 3] { 
-            set thisoption [lindex $option_value 0]
-            if { $first_p } {
-                set first_p 0
-            } else {
-                append html " | "
-            } 
-            
-            if {$option_val eq $thisoption } {
-                append html "<strong>[lindex $option_value 1]</strong>"
-            } else {
-                append html "<a href=\"$url?[export_ns_set_vars "url" $option_key $options_set][ad_quotehtml &][ns_urlencode $option_key]=[ns_urlencode $thisoption]\">[lindex $option_value 1]</a>"
-            }
-        }
-        append html "\]</td>\n"
-    }
-    append html "</tr>\n</table>\n"
-}
-
-ad_proc ad_dimensional_sql {
-    option_list 
-    {what "where"} 
-    {joiner "and"} 
-    {options_set ""}
-} {
-    see ad_dimensional for the format of option_list
-    <p>
-    Given what clause we are asking for and the joiner this returns 
-    the sql fragment
-} {
-    set out {}
-
-    if {$option_list eq ""} {
-        return
-    }
-
-    if {$options_set eq ""} {
-        set options_set [ns_getform]
-    }
-
-    foreach option $option_list { 
-        # find out what the current option value is.
-        # check if a default is set otherwise the first value is used
-        set option_key [lindex $option 0]
-        set option_val {}
-        # get the option from the form
-        if { $options_set ne ""} {
-            set option_val [ns_set get $options_set $option_key]
-        }
-        #otherwise get from default
-        if { $option_val eq "" } {
-            set option_val [lindex $option 2]
-        }
-        
-        foreach option_value [lindex $option 3] { 
-            set thisoption [lindex $option_value 0]
-            if {$option_val eq $thisoption } {
-                set code [lindex $option_value 2]
-                if {$code ne ""} {
-                    if {[lindex $code 0] eq $what } {
-                        append out " $joiner [uplevel [list subst [lindex $code 1]]]"
-                    }
-                }
-            }
-        }
-    }
-
-    return $out
-}
-
-ad_proc ad_dimensional_set_variables {option_list {options_set ""}} {
+ad_proc -deprecated ad_dimensional_set_variables {option_list {options_set ""}} {
     set the variables defined in option_list from the form provided 
     (form defaults to ad_conn form) or to default value from option_list if 
     not in the form data.
@@ -362,8 +213,10 @@ ad_proc -deprecated ad_table {
 		} else {
 		    set Tasord {}
 		}
-		append Theader " <th><a href=\"$Tsort_url[ns_urlencode [ad_new_sort_by [lindex $Tcol 0] $Torderby]]\">\n"
-		append Theader "[lindex $Tcol 1]</a>&nbsp;$Tasord</th>\n"
+		set href $Tsort_url[ns_urlencode [ad_new_sort_by [lindex $Tcol 0] $Torderby]]
+		append Theader \
+		    [subst { <th><a href="[ns_urlencode $href]">}] \
+		    "\n[lindex $Tcol 1]</a>&nbsp;$Tasord</th>\n"
 	    }
 	}
 	append Theader "</tr>\n"
@@ -812,7 +665,7 @@ ad_proc -deprecated ad_table_sort_form {
     return $html
 }
 
-ad_proc ad_order_by_from_sort_spec {sort_by tabledef} {
+ad_proc -deprecated ad_order_by_from_sort_spec {sort_by tabledef} {
     Takes a sort_by spec, and translates it into into an "order by" clause
     with each sort_by key dictated by the sort info in tabledef
 } {
@@ -880,17 +733,18 @@ ad_proc -deprecated ad_new_sort_by {key keys} {
     }
 }
 
-ad_proc ad_same_page_link {variable value text {form ""}} {
+ad_proc -deprecated ad_same_page_link {variable value text {form ""}} {
     Makes a link to this page, with a new value for "variable".
 } {
     if { $form eq "" } {
         set form [ns_getform]
     }
     set url_vars [export_ns_set_vars url $variable $form]
-    return "<a href=\"[ad_conn url]?$variable=[ns_urlencode $value]$url_vars\">$text</a>"
+    set href "[ad_conn url]?$variable=[ns_urlencode $value]$url_vars"
+    return [subst {<a href="[ns_quotehtml $href]">[ns_quotehtml $text]</a>}]
 }
 
-ad_proc ad_reverse order { 
+ad_proc -deprecated ad_reverse order { 
     returns the opposite sort order from the
     one it is given.  Mostly for columns whose natural 
     sort order is not the default.
@@ -902,7 +756,7 @@ ad_proc ad_reverse order {
     return $order
 }
 
-ad_proc ad_custom_load {user_id item_group item item_type} {
+ad_proc -deprecated ad_custom_load {user_id item_group item item_type} {
     load a persisted user customization as saved by 
     for example table-custom.tcl.
 } { 
@@ -922,7 +776,7 @@ ad_proc ad_custom_load {user_id item_group item item_type} {
     return $value
 }
     
-ad_proc ad_custom_list {user_id item_group item_set item_type target_url custom_url {new_string "new view"}} {
+ad_proc -deprecated ad_custom_list {user_id item_group item_set item_type target_url custom_url {new_string "new view"}} {
     Generates the html fragment for choosing, editing and creating
     user customized data
 } {
@@ -935,21 +789,21 @@ ad_proc ad_custom_list {user_id item_group item_set item_type target_url custom_
     }]
     
     set break {}
-    foreach item $items { 
+    foreach item $items {
         if {$item_set eq $item } {
-            append html "$break<strong>$item</strong>&nbsp;(<a href=\"$custom_url$item\">edit</a>)"
+            append html "$break<strong>$item</strong>&nbsp;(<a href=\"[ns_quotehtml $custom_url$item]\">edit</a>)"
         } else { 
-            append html "$break<a href=\"$target_url$item\">$item</a>"
+            append html "$break<a href=\"[ns_quotehtml $target_url$item]\">$item</a>"
         }
         set break " | "
     }
-    append html "$break (<a href=\"${custom_url}CreateNewCustom\">$new_string</a>)\n"
+    append html "$break (<a href=\"[ns_quotehtml ${custom_url}CreateNewCustom]\">$new_string</a>)\n"
     
     return $html
 }
     
 
-ad_proc ad_custom_page_defaults {defaults} { 
+ad_proc -deprecated ad_custom_page_defaults {defaults} { 
     set the page defaults. If the form is 
     empty do a returnredirect with the defaults set
 } {
@@ -977,7 +831,7 @@ ad_proc ad_custom_page_defaults {defaults} {
     }
 }
 
-ad_proc ad_custom_form {return_url item_group item} { 
+ad_proc -deprecated ad_custom_form {return_url item_group item} { 
     sets up the head of a form to feed to /tools/form-custom.tcl
 } {
     append html "<form method=\"get\" action=\"/tools/form-custom\">\n" 
@@ -992,7 +846,7 @@ ad_proc ad_custom_form {return_url item_group item} {
     append html "<input type=\"submit\" value=\"Save settings\">"
 }
 
-ad_proc ad_dimensional_settings {define current} {
+ad_proc -deprecated ad_dimensional_settings {define current} {
     given a dimensional slider definition this routine returns a form to set the 
     defaults for the given slider.
 
@@ -1010,9 +864,9 @@ ad_proc ad_dimensional_settings {define current} {
 	}
         foreach val [lindex $opt 3] { 
             if {$picked eq [lindex $val 0] } { 
-                append html "<option selected=\"selected\" value=\"[ad_quotehtml [lindex $val 0]]\">[lindex $val 1]</option>\n"
+                append html "<option selected=\"selected\" value=\"[ns_quotehtml [lindex $val 0]]\">[lindex $val 1]</option>\n"
             } else { 
-                append html "<option value=\"[ad_quotehtml [lindex $val 0]]\">[lindex $val 1]</option>\n"
+                append html "<option value=\"[ns_quotehtml [lindex $val 0]]\">[lindex $val 1]</option>\n"
             }
         }
         append html "</select></td></tr>\n"
@@ -1035,3 +889,9 @@ ad_proc -deprecated ad_table_orderby_sql {datadef orderby order} {
     return $orderclause
 }        
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
