@@ -3,7 +3,7 @@ ad_library {
 
     @author Jeff Davis
     @creation-date 2005-02-28
-    @cvs-id $Id: file-test-procs.tcl,v 1.9.4.2 2013/10/16 19:49:10 gustafn Exp $
+    @cvs-id $Id: file-test-procs.tcl,v 1.10.2.2 2015/09/18 07:33:49 gustafn Exp $
 }
 
 aa_register_case -cats {smoke production_safe} files__tcl_file_syntax_errors {
@@ -217,7 +217,7 @@ aa_register_case -cats {smoke} files__check_xql_files {
 
         if { [catch {set parse [xml_parse $data]} errMsg] } {
             ns_log warning "acs_tcl__check_xql_files: failed parse $file $errMsg"
-            aa_log_result fail "XML Parse Error: $file [ad_quotehtml $errMsg]"
+            aa_log_result fail "XML Parse Error: $file [ns_quotehtml $errMsg]"
         } else {
             # lets walk the nodes and check they are what we want to see.
 
@@ -301,3 +301,9 @@ aa_register_case -cats {smoke} files__check_xql_files {
     }
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
