@@ -4,7 +4,7 @@ ad_library {
 
     @creation-date 02 October 2000
     @author Bryan Quinn
-    @cvs-id $Id: utilities-init.tcl,v 1.9 2010/03/11 14:36:51 victorg Exp $
+    @cvs-id $Id: utilities-init.tcl,v 1.9.8.1 2015/09/10 08:22:01 gustafn Exp $
 }
 
 # initialize the random number generator
@@ -20,3 +20,9 @@ if { $logmaxbackup } {
     ad_schedule_proc -all_servers t -schedule_proc ns_schedule_daily \
 	[list 00 00] util::roll_server_log
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
