@@ -5,7 +5,7 @@ ad_library {
     @author Peter Marklund
     @author Lars Pind
     @creation-date 03 October 2003
-    @cvs-id $Id: whos-online-procs.tcl,v 1.4 2007/01/10 21:22:12 gustafn Exp $
+    @cvs-id $Id: whos-online-procs.tcl,v 1.4.12.1 2015/09/10 08:22:01 gustafn Exp $
 }
 
 # TODO: Count anonymous users based on their IP, just to have the number
@@ -197,3 +197,9 @@ ad_proc -public whos_online::all_invisible_user_ids {} {
 } {   
     return [nsv_array names invisible_users]
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
