@@ -3,7 +3,7 @@ ad_library {
     
     @creation-date 2003-09-22
     @author Lars Pind (lars@collaboraid.biz)
-    @cvs-id $Id: apm-callback-procs.tcl,v 1.6 2010/10/17 21:06:09 donb Exp $
+    @cvs-id $Id: apm-callback-procs.tcl,v 1.6.6.1 2015/09/10 08:22:05 gustafn Exp $
 }
 
 namespace eval template {}
@@ -107,3 +107,9 @@ ad_proc -private template::apm::after_upgrade {
             }
         }
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
