@@ -3,7 +3,7 @@
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Author: Stanislav Freidin (sfreidin@arsdigita.com)
 #
-# $Id: date-procs.tcl,v 1.48.4.7 2014/09/09 08:32:01 gustafn Exp $
+# $Id: date-procs.tcl,v 1.49.2.2 2015/09/18 07:31:48 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -1287,11 +1287,11 @@ ad_proc -public template::widget::textdate { element_reference tag_attributes }
   }
 
   if {$element(mode) eq "edit"} {
-      append output "<input type=\"text\" name=\"$element(id)\" size=\"10\" maxlength=\"10\" id=\"$element(id)_input_field\" value=\"[ad_quotehtml $textdate]\" >"
+      append output "<input type=\"text\" name=\"$element(id)\" size=\"10\" maxlength=\"10\" id=\"$element(id)_input_field\" value=\"[ns_quotehtml $textdate]\" >"
       append output "<input type=\"button\" style=\"border-width: 0px; height: 17px; width: 19px; background-image: url('/resources/acs-templating/calendar.gif'); background-repeat: no-repeat; cursor: pointer;\" onclick=\"return showCalendarWithDefault('$element(id)_input_field', '$javascriptdate', '[template::util::textdate_localized_format]');\" >"
   } else {
       append output $textdate
-      append output "<input type=\"hidden\" name=\"$element(id)\" value=\"[ad_quotehtml $textdate]\">"
+      append output "<input type=\"hidden\" name=\"$element(id)\" value=\"[ns_quotehtml $textdate]\">"
   }
       
   return $output
@@ -1416,3 +1416,9 @@ ad_proc -public template::widget::time_of_day { element_reference tag_attributes
     return [template::widget::date element $tag_attributes]
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
