@@ -3,7 +3,7 @@
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Authors: Simon Huynh (shuynh@arsdigita.com)
 
-# $Id: doc-tcl-procs.tcl,v 1.10.10.3 2014/09/10 18:17:20 gustafn Exp $
+# $Id: doc-tcl-procs.tcl,v 1.11.2.2 2015/09/24 07:10:24 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -175,8 +175,7 @@ ad_proc -private -deprecated template::util::display_value { ref } {
     @see use simple "ns_log ...." instead
 } {
     upvar $ref value
-    ns_log notice "$ref: $value
-"
+    ns_log notice "$ref: $value"
 }
 
 
@@ -606,13 +605,13 @@ ad_proc -private doc::parse_tcl_library { dir_list } {
 
   foreach dir $dir_list {
 
-  #debug
-  #template::util::display_value dir
+      #debug
+      #template::util::display_value dir
 
-  # using this lame hack since most aD servers are running an earlier version of Tcl than 8.3,
-  # which supports the -directory switch that this hack emulates
-  append file_list [glob -nocomplain $dir/*.tcl $dir/*/*.tcl $dir/*/*/*.tcl $dir/*/*/*/*.tcl ]
-  append file_list " "
+      # using this lame hack since most aD servers are running an earlier version of Tcl than 8.3,
+      # which supports the -directory switch that this hack emulates
+      append file_list [glob -nocomplain $dir/*.tcl $dir/*/*.tcl $dir/*/*/*.tcl $dir/*/*/*/*.tcl ]
+      append file_list " "
   }
 
   #debugging
@@ -634,3 +633,9 @@ ad_proc -private doc::parse_tcl_library { dir_list } {
 
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
