@@ -3,7 +3,7 @@
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Authors: Karl Goldstein    (karlg@arsdigita.com)
 
-# $Id: filter-procs.tcl,v 1.15.10.3 2013/10/16 19:56:14 gustafn Exp $
+# $Id: filter-procs.tcl,v 1.16.2.4 2015/09/18 07:31:48 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -77,7 +77,6 @@ ad_proc -public cmp_page_filter { why } {
         regsub {.cmp} $url {} url_stub
         regexp {^/([^/]*)(.*)} $url_stub all package_key rest
         set file_stub "$::acs::rootdir/packages/$package_key/www$rest"
-
         set beginTime [clock clicks -milliseconds]
 
         set output "<pre>[ns_quotehtml [template::adp_compile -file $file_stub.adp]]</pre>"
@@ -86,8 +85,7 @@ ad_proc -public cmp_page_filter { why } {
         ns_log debug "cmp_page_filter: Time elapsed: $timeElapsed"
 
     } errMsg] } {
-        global errorInfo
-        set output <html><body><pre>[ad_quotehtml $errorInfo]</pre></body></html>
+        set output <html><body><pre>[ns_quotehtml $::errorInfo]</pre></body></html>
     }
 
     ns_return 200 text/html $output
@@ -103,10 +101,9 @@ ad_proc -public dat_page_filter { why } {
         regsub {.dat} $url {} url_stub
         regexp {^/([^/]*)(.*)} $url_stub all package_key rest
         set code_stub "$::acs::rootdir/packages/$package_key/www$rest"
-
         set beginTime [clock clicks -milliseconds]
 
-        set file_stub [template::get_resource_path]/messages/datasources
+	set file_stub [template::resource_path -type messages -style $datasources]
 
         set output [template::adp_parse $file_stub [list code_stub $code_stub]]
 
@@ -114,8 +111,7 @@ ad_proc -public dat_page_filter { why } {
         ns_log debug " dat_page_filter: Time elapsed: $timeElapsed"
 
     } errMsg] } {
-        global errorInfo
-        set output <html><body><pre>$errorInfo</pre></body></html>
+        set output <html><body><pre>$::errorInfo</pre></body></html>
     }
 
     ns_return 200 text/html $output
@@ -153,7 +149,6 @@ ad_proc -private frm_page_filter { why } {
     Return the form data for a request for .frm
 } {
     if { [catch {
-
         set beginTime [clock clicks -milliseconds]
 
         set output [template::frm_page_handler]
@@ -162,11 +157,16 @@ ad_proc -private frm_page_filter { why } {
         ns_log debug "frm_page_filter: Time elapsed: $timeElapsed"
 
     } errMsg] } {
-        global errorInfo
-        set output $errorInfo
+        set output $::errorInfo
     }
 
     ns_return 200 text/html "<html><body><pre>[ns_quotehtml $output]</pre></body></html>"
 
     return filter_return
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
