@@ -3,7 +3,7 @@
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Authors: Karl Goldstein    (karlg@arsdigita.com)
 
-# $Id: paginator-procs.tcl,v 1.19.2.7 2014/09/10 14:06:24 gustafn Exp $
+# $Id: paginator-procs.tcl,v 1.22.2.2 2015/11/18 08:34:09 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -38,7 +38,7 @@ ad_proc -public template::paginator { command args } {
   paginator::$command {*}$args
 }
 
-ad_proc -public template::paginator::create { statement_name name query args } {
+ad_proc -public template::paginator::create { statement_name name query count_query args } {
     Creates a paginator object.  Performs an initial query to get the complete
     list of rows in the query result and caches the result for subsequent
     queries.
@@ -97,6 +97,9 @@ ad_proc -public template::paginator::create { statement_name name query args } {
 
   set cache_key	$name:$query
   set row_ids [cache get $cache_key:row_ids]
+  
+  # full number of rows returned by original paginator query
+  set full_row_count [cache get $cache_key:full_row_count]
 
     #
     # GN: In the following line, we had instead of [::cache exists
@@ -110,12 +113,13 @@ ad_proc -public template::paginator::create { statement_name name query args } {
     # recommended. Unfortunately, several places in OpenACS have this
     # problem.
     #
-    if { ($row_ids eq {} && ![::cache exists $cache_key]) || ([info exists opts(flush_p)] && $opts(flush_p) == "t") } {
+    if { ($row_ids eq {} && ![::cache exists $cache_key])
+	 || ([info exists opts(flush_p)] && $opts(flush_p) == "t") } {
       if { [info exists opts(printing_prefs)] && $opts(printing_prefs) ne "" } {
 	  set title [lindex $opts(printing_prefs) 0]
 	  set stylesheet [lindex $opts(printing_prefs) 1]
 	  if { $stylesheet ne "" } {
-	      set css_link "<link rel=\"stylesheet\" href=\"$stylesheet\" type=\"text/css\">"
+	      set css_link [subst {<link rel="stylesheet" href="[ns_quotehtml $stylesheet]" type="text/css">}]
 	  } else {
 	      set css_link ""
 	  }
@@ -152,15 +156,14 @@ $css_link
 	      #if { [llength $opts(row_ids)]==0 } {
 	      #	  nsv_set __template_cache_timeout $cache_key $opts(timeout)
 	      #}
-	      ns_write "
-          <SCRIPT type=\"text/javascript\">
+	      ns_write [subst {
+          <script type="text/javascript">
           <!-- Begin
-          document.location.href=\"$return_url\";
+	  document.location.href="[ns_quotehtml $return_url]";
           // End -->
           </script>
-          <noscript>
-          <a href=\"$return_url\">Click here to Continue</a>
-          </noscript>"
+	  <noscript><a href="[ns_quotehtml $return_url]">Click here to continue.</a></noscript>
+	      }]
 	  }
 	  ad_script_abort
       } else {
@@ -168,6 +171,7 @@ $css_link
       }
   } else {
     set opts(row_ids) $row_ids
+    set opts(full_row_count) $full_row_count
     set opts(context_ids) [cache get $cache_key:context_ids]
   }
 
@@ -186,17 +190,42 @@ ad_proc -private template::paginator::init { statement_name name query {print_p
 
   upvar 2 __paginator_ids ids
   set ids [list]
+  
+  set full_statement_name [uplevel 2 "db_qd_get_fullname $statement_name"]
+  
+  # Antonio Pisano 2015-11-17: to get the full rowcount of the records,
+  # we need to wrap the original query into a count(*). The problem comes
+  # with template::list, that builds the paginator query tampering with
+  # the original one, so if we come here from a template::list we cannot
+  # retrieve the real count anymore. I had to come out with a solution
+  # that wouldn't break existing contract for public procs, or this would
+  # have caused unpredictable regressions. Below is the strategy to get
+  # the original query.
+  
+  # If query comes from an xql we get it from there...
+  set original_query [db_map $full_statement_name]
+  # ...otherwise we try to see if we come from a template::list...
+  if {$original_query eq ""} {
+      # ...which was slightly modified to keep the original query untampered.
+      set list_name [lindex [split $name ,] 0]
+      if {![catch {template::list::get_reference -name $list_name}]} {
+          set original_query $list_properties(page_query_original)
+      }
+  }
+  # If any of the previous fail, we go for the explicit query
+  if {$original_query eq ""} {
+      set original_query $query
+  }
+      
 
   if { [info exists properties(contextual)] } {
 
       # query contains two columns, one for ID and one for context cue
 
       uplevel 2 "
-      set full_statement_name \[db_qd_get_fullname $statement_name\]
-
       # Can't use db_foreach here, since we need to use the ns_set directly.
       db_with_handle db {
-	set selection \[db_exec select \$db \$full_statement_name {$query}\]
+	set selection \[db_exec select \$db $full_statement_name {$query}\]
  
         set __paginator_ids \[list\]
         set total_so_far 1
@@ -282,6 +311,11 @@ ad_proc -private template::paginator::init { statement_name name query {print_p
       set properties(row_ids) $ids
       cache set $name:$query:row_ids $ids $properties(timeout)
   }
+  
+  # Get full number of rows retrieved by original paginator query
+  set full_row_count [uplevel 3 [list db_string query [db_map count_query]]]
+  set properties(full_row_count) $full_row_count
+  cache set $name:$query:full_row_count $full_row_count $properties(timeout)
 }
 
 ad_proc -public template::paginator::get_page { name rownum } {
@@ -559,6 +593,20 @@ ad_proc -public template::paginator::get_row_count { name } {
   return $properties(row_count)
 }
 
+ad_proc -public template::paginator::get_full_row_count { name } {
+    Gets the total number of records returned by the original 
+    paginator query. This is the 'true' row_count, which won't
+    be limited to number_of_pages * rows_per_page.
+
+    @param name    The reference to the paginator object.
+
+    @return A number representing the full row count.
+} {
+  get_reference
+
+  return $properties(full_row_count)
+}
+
 ad_proc -public template::paginator::get_page_count { name } {
     Gets the total number of pages in the paginated query
 
@@ -813,3 +861,9 @@ ad_proc -private template::paginator::get_reference {} {
   }
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
