@@ -5,7 +5,7 @@ ad_library {
     @creation-date 29 September 2000
     @author Karl Goldstein (karlg@arsdigita.com)
             Stanislav Freidin (sfreidin@arsdigita.com)
-    @cvs-id $Id: query-procs.tcl,v 1.33.2.2 2014/08/25 09:40:06 gustafn Exp $
+    @cvs-id $Id: query-procs.tcl,v 1.34.2.2 2015/09/10 07:54:15 gustafn Exp $
 
 }
 
@@ -17,7 +17,7 @@ namespace eval template::query {}
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Authors: Karl Goldstein (karlg@arsdigita.com)
 #          Stanislav Freidin (sfreidin@arsdigita.com)
-# $Id: query-procs.tcl,v 1.33.2.2 2014/08/25 09:40:06 gustafn Exp $
+# $Id: query-procs.tcl,v 1.34.2.2 2015/09/10 07:54:15 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -872,8 +872,7 @@ ad_proc -public template::multirow {
           }
           1 {
             # TCL_ERROR
-            global errorInfo errorCode
-            error $error $errorInfo $errorCode
+            error $error $::errorInfo $::errorCode
           }
           2 {
             # TCL_RETURN
@@ -1163,6 +1162,8 @@ ad_proc -public cache { command cache_key args } {
   return $result
 }
 
-# Local Variables:
-# tcl-indent-level: 2
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
 # End:
