@@ -3,7 +3,7 @@
 # Copyright (C) 1999-2000 ArsDigita Corporation
 # Authors: Karl Goldstein    (karlg@arsdigita.com)
 #          
-# $Id: request-procs.tcl,v 1.7.10.2 2014/08/25 09:40:06 gustafn Exp $
+# $Id: request-procs.tcl,v 1.8.2.2 2015/09/10 08:22:06 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -157,29 +157,35 @@ ad_proc -public template::request::is_valid { { url "" } } {
 
     @return 1 if no error conditions exist, 0 otherwise.
 } {
-  set level [template::adp_level]
-  upvar #$level request:error requesterror
+    set level [template::adp_level]
+    upvar #$level request:error requesterror
 
-  if { [info exists requesterror] } {
+    if { [info exists requesterror] } {
 
-    # set requesterror as a data source
-    uplevel #$level "upvar 0 request:error requesterror"
+	# set requesterror as a data source
+	uplevel #$level "upvar 0 request:error requesterror"
 
-    if { $url ne "self" } {
+	if { $url ne "self" } {
 
-      if {$url eq {}} { 
-	set file_stub [template::get_resource_path]/messages/request-error
-      } else {
-	set file_stub [ns_url2file $url]
-      }
-      template::set_file $file_stub
+	    if {$url eq {}} { 
+		set file_stub [template::resource_path -type messages -style request-error]
+	    } else {
+		set file_stub [ns_url2file $url]
+	    }
+	    template::set_file $file_stub
+	}
+
+	return 0
+
+    } else {
+
+	return 1
     }
-
-    return 0
-
-  } else {
-
-    return 1
-  }
 }
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
