@@ -3,7 +3,7 @@ ad_library {
 
     @author Ola Hansson (ola@polyxena.net)
     @creation-date 2003-09-21
-    @cvs-id $Id: spellcheck-procs.tcl,v 1.21.2.4 2013/10/16 19:56:15 gustafn Exp $
+    @cvs-id $Id: spellcheck-procs.tcl,v 1.22.2.3 2015/12/02 09:34:43 gustafn Exp $
 }
 
 namespace eval template {}
@@ -61,7 +61,8 @@ ad_proc -public template::data::transform::spellcheck {
     # case 2, submission of the page showing errors: returns the corrected text.
     set merge_text [template::util::spellcheck::merge_text $element(id)]
 
-    if { [set richtext_p $element(datatype) eq "richtext"] } {
+    set richtext_p [expr {$element(datatype) eq "richtext"}]
+    if { $richtext_p } {
 	# special treatment for the "richtext" datatype.
     	set format [template::util::richtext::get_property format [lindex $values 0]]
 	if { $merge_text ne "" } {
@@ -342,7 +343,7 @@ ad_proc -public template::util::spellcheck::get_element_formtext {
     regsub -all {<a [^<]*>} $formtext_to_display "<u>" formtext_to_display
     regsub -all {</a>} $formtext_to_display "</u>" formtext_to_display
 
-    append formtext_to_display "<input type=\"hidden\" name=\"${var_to_spellcheck}.merge_text\" value=\"[ad_quotehtml $processed_text]\" >"
+    append formtext_to_display "<input type=\"hidden\" name=\"${var_to_spellcheck}.merge_text\" value=\"[ns_quotehtml $processed_text]\" >"
 
 
     ####
@@ -439,3 +440,9 @@ ad_proc -public template::util::spellcheck::spellcheck_properties {
 
     return [array get spellcheck]
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
