@@ -5,7 +5,7 @@
 #          Stanislav Freidin      (sfreidin@arsdigita.com)
 #          Christian Brechbuehler (chrisitan@arsdigita.com)
 
-# $Id: tag-procs.tcl,v 1.18.2.3 2014/09/07 18:40:30 gustafn Exp $
+# $Id: tag-procs.tcl,v 1.20.2.3 2015/10/04 15:00:45 gustafn Exp $
 
 # This is free software distributed under the terms of the GNU Public
 # License.  Full text of the license is available from the GNU Project:
@@ -96,7 +96,7 @@ ad_proc -private template_tag_subst_reference {arg} {
     substitute variable references
     @return variable name 
 } {
-    if { [regsub {^"@([a-zA-Z0-9_]+)\.([a-zA-Z0-9_.]+)@"$} $arg {\1(\2)} arg1] } {
+    if { [regsub {^"@([a-zA-Z0-9_]+)\.([a-zA-Z0-9_.-]+)@"$} $arg {\1(\2)} arg1] } {
     } elseif { [regsub {^"@([a-zA-Z0-9_:]+)@"$} $arg {\1} arg1] } { 
     } else {
         set arg1 ""
@@ -117,13 +117,13 @@ ad_proc -public template_tag_if_interp_expr {} {
 
     if { $op eq "not" } {
         #
-        # Optimize common case "@arg@ no nil"
+        # Optimize common case "@arg@ not nil"
         #
         set op [lindex $args 2]
         set arg1 \"[lindex $args 0]\"
         if {$op eq "nil" && [string first @ $arg1] > -1} {
             set arg1 [template_tag_subst_reference $arg1]
-            append condition "\[info exists $arg1\] && \${$arg1} ne {}"
+            append condition "(\[info exists $arg1\] && \${$arg1} ne {})"
             set args [lrange $args 3 end]
             return
         } else {
@@ -168,8 +168,7 @@ ad_proc -public template_tag_if_interp_expr {} {
         }
 
         in { 
-            set expr "^([join [lrange $args $i end] "|"])\$"
-            append condition "\[regexp \"$expr\" $arg1\] " 
+            append condition "$arg1 in { [lrange $args 2 end] } "
             set next [llength $args]
         }
 
@@ -189,20 +188,17 @@ ad_proc -public template_tag_if_interp_expr {} {
                 if {$arg eq ""} {
                     error "IF tag nil test uses string not variable for $arg1"
                 }
-                #append condition "\[template::util::is_nil $arg\]"
-                append condition "!\[info exists $arg\] || \${$arg} eq {}"
+                append condition "(!\[info exists $arg\] || \${$arg} eq {})"
             }
             set next $i
         }
 
         defined {
-            # substitute variable references
-            if { ! ( [regsub {^"@([a-zA-Z0-9_]+)\.([a-zA-Z0-9_.]+)@"$} $arg1 {\1(\2)} arg1]
-                     || [regsub {^"@([a-zA-Z0-9_:]+)@"$} $arg1 {\1} arg1] )} { 
-                error "IF tag defined test uses string not variable for $arg1"
+            set arg [template_tag_subst_reference $arg1]
+            if {$arg eq ""} {
+                error "IF tag nil test uses string not variable for $arg1"
             }
-
-            append condition "\[info exists $arg1\]"
+            append condition "\[info exists $arg\]"
             set next $i
         }
 
@@ -217,7 +213,8 @@ ad_proc -public template_tag_if_interp_expr {} {
         }
         
         true {
-            append condition "\[template::util::is_true $arg1\]"
+            #append condition "\[template::util::is_true $arg1\]"
+            append condition "\[string is true -strict $arg1\]"
             set next $i
         }
         
@@ -228,7 +225,8 @@ ad_proc -public template_tag_if_interp_expr {} {
 
         default { 
             # treat <if @foo_p@> as a shortcut for <if @foo_p@ true>
-            append condition "\[template::util::is_true $arg1\]"
+            #append condition "\[template::util::is_true $arg1\]"
+            append condition "\[string is true -strict $arg1\]"
             set next [expr {$i - 1}]
         }
     }
