@@ -7,7 +7,7 @@ ad_library {
     @author Dave Bauer (dave@thedesignexperience.org)
     @creation-date 2005-10-13
     @arch-tag: b5d458b6-bd22-4b87-8c4e-6a8c23fcca9e
-    @cvs-id $Id: date-procs.tcl,v 1.2 2006/06/04 00:45:48 donb Exp $
+    @cvs-id $Id: date-procs.tcl,v 1.2.14.1 2015/09/10 08:22:08 gustafn Exp $
 }
 
 
@@ -24,4 +24,9 @@ aa_register_case sql_date {
                 aa_true "to_timestamp for Oracle 9i and PostgreSQL" [string match "to_timestamp*" $sql_date]
             }
         }
-}
\ No newline at end of file
+}
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
