@@ -1,5 +1,5 @@
 ad_page_contract {
-  @cvs-id $Id: contract-2.tcl,v 1.2 2002/09/10 22:22:16 jeffd Exp $
+  @cvs-id $Id: contract-2.tcl,v 1.3.12.1 2015/09/10 08:22:09 gustafn Exp $
 } {
   count:naturalnum
   noun:notnull,nohtml
@@ -16,7 +16,7 @@ ad_page_contract {
   phrase:onevalue
 } -return_errors error_list
 
-if [info exists error_list] {
+if {[info exists error_list]} {
   # divert to error-handling page
   ad_return_template "contract-err"
 } else {
@@ -25,9 +25,15 @@ if [info exists error_list] {
   if {$count == 1} {
     append phrase "one $noun"
   } else {
-    if {[empty_string_p $plural]} {
+    if {$plural eq ""} {
       set plural "${noun}s"
     }
     append phrase "$count $plural"
   }
 }
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
