@@ -1,5 +1,5 @@
 ad_page_contract {
-  @cvs-id $Id: grid.tcl,v 1.2 2002/09/10 22:22:16 jeffd Exp $
+  @cvs-id $Id: grid.tcl,v 1.2.28.1 2015/09/10 08:22:10 gustafn Exp $
 } -properties {
   users:multirow
 }
@@ -31,3 +31,9 @@ db_multirow users users_query $query
 
 
 
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
