@@ -1,5 +1,5 @@
 ad_page_contract {
-  @cvs-id $Id: if.tcl,v 1.3 2002/09/10 22:22:16 jeffd Exp $
+  @cvs-id $Id: if.tcl,v 1.3.28.1 2015/09/10 08:22:11 gustafn Exp $
 } -properties {
   users:multirow
 }
@@ -18,3 +18,9 @@ set bool_1_p 1
 
 set bool_f_p f
 set bool_0_p 0
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
