@@ -4,7 +4,7 @@ ad_page_contract {
 
   @author rhs@mit.edu
   @creation-date 2000-10-23
-  @cvs-id $Id: index.tcl,v 1.1 2006/02/04 19:09:15 jiml Exp $
+  @cvs-id $Id: index.tcl,v 1.1.14.1 2015/09/10 08:22:13 gustafn Exp $
 } -properties {
   notes:multirow
 }
@@ -23,3 +23,9 @@ template::list::create -name notes \
     }
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
