@@ -1,7 +1,7 @@
 # suppose this template was obtained from a database query
 set template "
   @name@ ordered
-  <ul><list name=food><li>@food:item@</list></li>\n</ul>"
+  <ul><list name='food'><li>@food:item@</list></li>\n</ul>"
 
 set code [adp_compile -string $template]; 	# compile the template
 
@@ -14,3 +14,9 @@ set name Jill
 set food [list "chilled sea food" "soup"]
 adp_eval code;			        	# run compiled template again
 lappend body $__adp_output
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
