@@ -1,7 +1,7 @@
 ad_page_contract {
 	
 } {
-	textarea_id:notnull
+	textarea_id:naturalnum,notnull
 	community_id:naturalnum,notnull
 } 
 
@@ -20,3 +20,9 @@ switch [lang::user::language -site_wide] {
 
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
