@@ -2,11 +2,11 @@ ad_page_contract {
   @author Guenter Ernst guenter.ernst@wu-wien.ac.at
   @author Gustaf Neumann neumann@wu-wien.ac.at
   @creation-date 13.10.2005
-  @cvs-id $Id: file-selector.tcl,v 1.4.8.3 2014/07/29 11:24:00 gustafn Exp $
+  @cvs-id $Id: file-selector.tcl,v 1.6.2.1 2015/09/10 08:22:17 gustafn Exp $
 } {	
   {fs_package_id:naturalnum,notnull,optional}
   {folder_id:naturalnum,optional}
-  {orderby:optional}
+  {orderby:token,optional}
   {selector_type "image"}
   {file_types "*"}
 } 
@@ -302,3 +302,9 @@ switch $selector_type {
 
 
 ad_return_template
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
