@@ -8,7 +8,7 @@ ad_page_contract {
 set package_id [ad_conn package_id]
 
 if { $num == 0 } {
-    set num [ad_parameter -package_id $package_id LimitDefault]
+    set num [parameter::get -package_id $package_id -parameter LimitDefault]
 }
 
 set title "Advanced Search"
@@ -16,4 +16,9 @@ set context "advanced search"
 set context_bar [ad_context_bar $title]
 
 
-ad_return_template
\ No newline at end of file
+ad_return_template
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
