@@ -4,7 +4,7 @@ ad_library {
     @author Dave Bauer (dave@thedesignexperience.org)
     @creation-date 2004-06-05
     @arch-tag: 49a5102d-7c06-4245-8b8d-15a3b12a8cc5
-    @cvs-id $Id: tsearch2-driver-procs.tcl,v 1.29.2.4 2014/08/21 11:12:40 gustafn Exp $
+    @cvs-id $Id: tsearch2-driver-procs.tcl,v 1.32 2015/06/29 18:46:49 gustafn Exp $
 }
 
 namespace eval tsearch2 {}
@@ -133,6 +133,10 @@ ad_proc -callback search::search -impl tsearch2-driver {
     # clean up query for tsearch2
     set query [tsearch2::build_query -query $query]
 
+    set where_clauses ""
+    set from_clauses ""
+    if {![info exists user_id]} {set user_id 0}
+
     # don't use bind vars since pg7.3 yacks for '1' (which is what comes out of bind vars)
     set limit_clause ""
     set offset_clause ""
@@ -147,11 +151,11 @@ ad_proc -callback search::search -impl tsearch2-driver {
     set base_query [db_map base_query]
     if {$df ne ""} {
         set need_acs_objects 1
-        lappend where_clauses " and o.creation_date > :df"
+        lappend where_clauses "o.creation_date > :df"
     }
     if {$dt ne ""} {
         set need_acs_objects 1
-        lappend where_clauses " and o.creation_date < :dt"
+        lappend where_clauses "o.creation_date < :dt"
     }
 
     foreach {arg value} $extra_args {
@@ -160,7 +164,7 @@ ad_proc -callback search::search -impl tsearch2-driver {
 	    lappend from_clauses $arg_clauses(from_clause)
 	}
 	if {[info exists arg_clauses(where_clause)] && $arg_clauses(where_clause) ne ""} {
-	    lappend where_clauses "$arg_clauses(where_clause)"
+	    lappend where_clauses $arg_clauses(where_clause)
 	}
     }
     if {[llength $extra_args]} {
