@@ -56,7 +56,7 @@ ad_page_contract {
           Lee Denison (lee@xarg.co.uk)
   @creation-date 14 Sept 2000
 
-  $Id: blank-master.tcl,v 1.52.4.2 2013/10/17 07:41:03 gustafn Exp $
+  $Id: blank-master.tcl,v 1.56.2.5 2015/12/01 14:38:54 gustafn Exp $
 }
 
 if {![info exists doc(type)]} { 
@@ -73,7 +73,21 @@ template::head::add_meta \
     
 # Add standard javascript
 #
-template::head::add_javascript -src "/resources/acs-subsite/core.js"
+# Include core.js inclusion to the bottom of the body.
+# The only function needed alread onload is acs_Focus()
+#
+template::add_body_script -type "text/javascript" -src "/resources/acs-subsite/core.js"
+
+template::head::add_javascript -script {
+  function acs_Focus(form_name, element_name) {
+    if (document.forms == null) return;
+    if (document.forms[form_name] == null) return;
+    if (document.forms[form_name].elements[element_name] == null) return;
+    if (document.forms[form_name].elements[element_name].type == 'hidden') return;
+
+    document.forms[form_name].elements[element_name].focus();
+  }
+}
 
 # The following (forms, list and xinha) should
 # be done in acs-templating.
@@ -82,24 +96,43 @@ template::head::add_javascript -src "/resources/acs-subsite/core.js"
 # Add css for the current subsite, defaulting to the old list/form css which was
 # hard-wired in previous versions of OpenACS.
 
-set css [parameter::get -package_id [ad_conn subsite_id] -parameter ThemeCSS -default ""]
-if { $css ne "" } {
+set cssList [parameter::get -package_id [ad_conn subsite_id] -parameter ThemeCSS -default ""]
+if {![string is list $cssList]} {
+    ns_log error "ignore value in ThemeCSS, since it is not a valid list: $cssList"
+} elseif { [llength $cssList] > 0 } {
 
     # DRB: Need to handle two cases, the lame first attempt and the more complete current
     # attempt which allows you to specify all of the parameters to template::head::add_css
     # (sigh, remove this kludge for 5.5.1).  We need to handle the old case so upgrades
     # to 5.5 for mgh and various of my sites work correctly.
+    #
+    # The following syntaxes are supported
+    #
+    # 1) pairs:                       {/resources/acs-templating/lists.css all} ...
+    # 2) nested list of pairs:        {{href /resources/acs-templating/lists.css} {media all} ... } ...
+    # 3) flat list of -att val pairs: {-href /resources/acs-templating/lists.css -media all ... } ...
+    #
 
-    foreach css $css {
-        if { [llength $css] == 2 && [llength [lindex $css 0]] == 1 } {
-            template::head::add_css -href [lindex $css 0] -media [lindex $css 1]
-        } else {
+    foreach css $cssList {
+	set first [lindex $css 0]
+        if { [llength $css] == 2 && [llength $first] == 1 && [string range $first 0 0] ne "-"} {
+            template::head::add_css -href $first -media [lindex $css 1]
+        } elseif {[llength $first] == 2} {
 	    set params [list]
             foreach param $css {
                 lappend params -[lindex $param 0] [lindex $param 1]
             }
-            template::head::add_css {*}$params
-        }
+	    if {[catch {template::head::add_css {*}$params} errorMsg]} {
+		ns_log error $errorMsg
+	    }
+        } else {
+	    if {![string match -* [lindex $css 0]]} {
+		error "CSS specification '$css' is incorrect"
+	    }
+	    if {[catch {template::head::add_css {*}$css} errorMsg]} {
+		ns_log error $errorMsg
+	    }
+	}	    
     }
 
 } else {
@@ -111,6 +144,22 @@ if { $css ne "" } {
         -media "all"
 }
 
+#
+# Add js files via ThemeJS for the current subsite, similar to
+# ThemeCSS.  Syntax is the flat list syntax (3) from ThemeCSS, valid
+# parameters are determined by template::add_script. It is possible to
+# add head and body scripts.
+
+set jsSpecs [parameter::get -package_id [ad_conn subsite_id] -parameter ThemeJS -default ""]
+if {![string is list $jsSpecs]} {
+    ns_log error "ignore value in ThemeJS since it is not a valid list: $jsSpecs"
+} else {
+    foreach jsSpec $jsSpecs {
+	if {[catch {template::add_script {*}$jsSpec} errorMsg]} {
+	    ns_log error $errorMsg
+	}
+    }
+}
 #
 # Temporary (?) fix to get xinha working
 #
@@ -159,11 +208,15 @@ if {[info exists ::acs_blank_master(xinha)]} {
       "
 
   template::add_body_handler -event onload -script "xinha_init();"
+  # Antonio Pisano 2015-03-27: including big javascripts in head is discouraged by current best practices for web.
+  # We should consider moving every inclusion like this in the body. As consequences are non-trivial, just warn for now. 
   template::head::add_javascript -src ${::xinha_dir}XinhaCore.js
 }
 
 if { [info exists ::acs_blank_master(tinymce)] } {
     # we are using TinyMCE
+    # Antonio Pisano 2015-03-27: including big javascripts in head is discouraged by current best practices for web.
+    # We should consider moving every inclusion like this in the body. As consequences are non-trivial, just warn for now. 
     template::head::add_javascript -src "/resources/acs-templating/tinymce/jscripts/tiny_mce/tiny_mce_src.js" -order tinymce0
     # get the textareas where we apply tinymce
     set tinymce_elements [list]
@@ -187,17 +240,23 @@ if { [info exists ::acs_blank_master(tinymce)] } {
     }
 
     # TODO : each element should have it's own init
+    # Antonio Pisano 2015-03-27: including big javascripts in head is discouraged by current best practices for web.
+    # We should consider moving every inclusion like this in the body. As consequences are non-trivial, just warn for now. 
     template::head::add_javascript -script "
         tinyMCE.init(\{language: \"$tinymce_lang\", $tinymce_config\});
 	" -order tinymceZ
 }
 
+if { [info exists ::acs_blank_master(ckeditor4)] } {
+    template::head::add_javascript -src "//cdn.ckeditor.com/4.5.2/standard/ckeditor.js"
+}
+
 if {![info exists doc(title)]} {
     set doc(title) "[ad_conn instance_name]"
     ns_log warning "[ad_conn url] has no doc(title) set."
 }
 # AG: Markup in <title> tags doesn't render well.
-set doc(title) [ns_striphtml $doc(title)]
+#set doc(title) [ns_striphtml $doc(title)]
 
 if {![info exists doc(charset)]} {
     set doc(charset) [ns_config ns/parameters OutputCharset [ad_conn charset]]
@@ -206,6 +265,15 @@ if {![info exists doc(charset)]} {
 template::head::add_meta \
     -content "text/html; charset=$doc(charset)" \
     -http_equiv "content-type"
+#
+# The following meta tags are unknwon for HTML5, therefore discouraged
+#
+# template::head::add_meta \
+#     -content "text/css" \
+#     -http_equiv "Content-Style-Type"
+# template::head::add_meta \
+#     -content "text/javascript" \
+#     -http_equiv "Content-Script-Type"
 
 # The document language is always set from [ad_conn lang] which by default 
 # returns the language setting for the current user.  This is probably
@@ -244,6 +312,11 @@ if {[info exists focus] && $focus ne ""} {
 # Retrieve headers and footers
 set header [template::get_header_html]
 set footer [template::get_footer_html]
-
 template::head::prepare_multirows
 set event_handlers [template::get_body_event_handlers]
+
+# Local variables:
+#    mode: tcl
+#    tcl-indent-level: 4
+#    indent-tabs-mode: nil
+# End:
